@@ -1,12 +1,13 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
-#include "level_zero/api/driver_experimental/public/zex_api.h"
 #include "level_zero/core/source/context/context.h"
+#include "level_zero/core/source/device/device.h"
+#include "level_zero/driver_experimental/zex_api.h"
 
 namespace L0 {
 
@@ -16,7 +17,7 @@ zexMemGetIpcHandles(
     const void *ptr,
     uint32_t *numIpcHandles,
     ze_ipc_mem_handle_t *pIpcHandles) {
-    return L0::Context::fromHandle(hContext)->getIpcMemHandles(ptr, numIpcHandles, pIpcHandles);
+    return L0::Context::fromHandle(toInternalType(hContext))->getIpcMemHandles(ptr, numIpcHandles, pIpcHandles);
 }
 
 ze_result_t ZE_APICALL
@@ -27,7 +28,7 @@ zexMemOpenIpcHandles(
     ze_ipc_mem_handle_t *pIpcHandles,
     ze_ipc_memory_flags_t flags,
     void **pptr) {
-    return L0::Context::fromHandle(hContext)->openIpcMemHandles(hDevice, numIpcHandles, pIpcHandles, flags, pptr);
+    return L0::Context::fromHandle(toInternalType(hContext))->openIpcMemHandles(toInternalType(hDevice), numIpcHandles, pIpcHandles, flags, pptr);
 }
 
 } // namespace L0
