@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -909,9 +909,9 @@ ze_result_t zesVFManagementGetVFCapabilitiesExp(
     zes_vf_handle_t hVFhandle,
     zes_vf_exp_capabilities_t *pCapability) {
     if (L0::sysmanInitFromCore) {
-        return L0::VfManagement::fromHandle(hVFhandle)->vfGetCapabilities(pCapability);
+        return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
     } else if (L0::Sysman::sysmanOnlyInit) {
-        return L0::Sysman::VfManagement::fromHandle(hVFhandle)->vfGetCapabilities(pCapability);
+        return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
     } else {
         return ZE_RESULT_ERROR_UNINITIALIZED;
     }
@@ -943,6 +943,18 @@ ze_result_t zesVFManagementGetVFEngineUtilizationExp2(
     }
 }
 
+ze_result_t zesVFManagementGetVFCapabilitiesExp2(
+    zes_vf_handle_t hVFhandle,
+    zes_vf_exp2_capabilities_t *pCapability) {
+    if (L0::sysmanInitFromCore) {
+        return L0::VfManagement::fromHandle(hVFhandle)->vfGetCapabilities(pCapability);
+    } else if (L0::Sysman::sysmanOnlyInit) {
+        return L0::Sysman::VfManagement::fromHandle(hVFhandle)->vfGetCapabilities(pCapability);
+    } else {
+        return ZE_RESULT_ERROR_UNINITIALIZED;
+    }
+}
+
 ze_result_t zesDeviceEnumMemoryModules(
     zes_device_handle_t hDevice,
     uint32_t *pCount,
@@ -2129,6 +2141,12 @@ ZE_APIEXPORT ze_result_t ZE_APICALL zesVFManagementGetVFEngineUtilizationExp2(
     return L0::zesVFManagementGetVFEngineUtilizationExp2(hVFhandle, pCount, pEngineUtil);
 }
 
+ZE_APIEXPORT ze_result_t ZE_APICALL zesVFManagementGetVFCapabilitiesExp2(
+    zes_vf_handle_t hVFhandle,
+    zes_vf_exp2_capabilities_t *pCapability) {
+    return L0::zesVFManagementGetVFCapabilitiesExp2(hVFhandle, pCapability);
+}
+
 ZE_APIEXPORT ze_result_t ZE_APICALL zesVFManagementSetVFTelemetryModeExp(
     zes_vf_handle_t hVFhandle,
     zes_vf_info_util_exp_flags_t flags,
