@@ -57,8 +57,12 @@ enum class ImageBuiltin : uint32_t {
     copyBufferToImage3d2BytesHeapless,
     copyBufferToImage3d4Bytes,
     copyBufferToImage3d4BytesHeapless,
+    copyBufferToImage3d3To4Bytes,
+    copyBufferToImage3d3To4BytesHeapless,
     copyBufferToImage3d8Bytes,
     copyBufferToImage3d8BytesHeapless,
+    copyBufferToImage3d6To8Bytes,
+    copyBufferToImage3d6To8BytesHeapless,
     copyBufferToImage3dBytes,
     copyBufferToImage3dBytesHeapless,
     copyImage3dToBuffer16Bytes,
@@ -69,10 +73,14 @@ enum class ImageBuiltin : uint32_t {
     copyImage3dToBuffer3BytesHeapless,
     copyImage3dToBuffer4Bytes,
     copyImage3dToBuffer4BytesHeapless,
+    copyImage3dToBuffer4To3Bytes,
+    copyImage3dToBuffer4To3BytesHeapless,
     copyImage3dToBuffer6Bytes,
     copyImage3dToBuffer6BytesHeapless,
     copyImage3dToBuffer8Bytes,
     copyImage3dToBuffer8BytesHeapless,
+    copyImage3dToBuffer8To6Bytes,
+    copyImage3dToBuffer8To6BytesHeapless,
     copyImage3dToBufferBytes,
     copyImage3dToBufferBytesHeapless,
     copyImageRegion,
@@ -200,14 +208,18 @@ constexpr ImageBuiltin adjustImageBuiltinType(const bool isHeapless) {
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyBufferToImage3d16Bytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyBufferToImage3d2Bytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyBufferToImage3d4Bytes);
+DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyBufferToImage3d3To4Bytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyBufferToImage3d8Bytes);
+DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyBufferToImage3d6To8Bytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyBufferToImage3dBytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyImage3dToBuffer16Bytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyImage3dToBuffer2Bytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyImage3dToBuffer3Bytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyImage3dToBuffer4Bytes);
+DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyImage3dToBuffer4To3Bytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyImage3dToBuffer6Bytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyImage3dToBuffer8Bytes);
+DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyImage3dToBuffer8To6Bytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyImage3dToBufferBytes);
 DEFINE_ADJUST_IMAGE_BUILTIN_TYPE(ImageBuiltin::copyImageRegion);
 
