@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -10,5 +10,5 @@
 #include "level_zero/core/source/compiler_interface/l0_reg_path.h"
 
 namespace NEO {
-DebugSettingsManager<globalDebugFunctionalityLevel> DebugManager(L0::registryPath);
+DebugSettingsManager<globalDebugFunctionalityLevel> debugManager(L0::registryPath);
 }
