@@ -23,6 +23,7 @@ class Device;
 class MemoryManager;
 class SVMAllocsManager;
 class GraphicsAllocation;
+class StagingBufferManager;
 struct SvmAllocationData;
 } // namespace NEO
 
@@ -59,6 +60,7 @@ struct DriverHandle : BaseDriver, NEO::NonCopyableAndNonMovableClass {
                                                                              bool *allocationRangeCovered) = 0;
 
     virtual NEO::SVMAllocsManager *getSvmAllocsManager() = 0;
+    virtual NEO::StagingBufferManager *getStagingBufferManager() = 0;
     virtual ze_result_t sysmanEventsListen(uint32_t timeout, uint32_t count, zes_device_handle_t *phDevices,
                                            uint32_t *pNumDeviceEvents, zes_event_type_flags_t *pEvents) = 0;
     virtual ze_result_t sysmanEventsListenEx(uint64_t timeout, uint32_t count, zes_device_handle_t *phDevices,
@@ -78,8 +80,11 @@ struct DriverHandle : BaseDriver, NEO::NonCopyableAndNonMovableClass {
 
     virtual ze_result_t loadRTASLibrary() = 0;
     virtual ze_result_t createRTASBuilder(const ze_rtas_builder_exp_desc_t *desc, ze_rtas_builder_exp_handle_t *phBuilder) = 0;
+    virtual ze_result_t createRTASBuilderExt(const ze_rtas_builder_ext_desc_t *desc, ze_rtas_builder_ext_handle_t *phBuilder) = 0;
     virtual ze_result_t createRTASParallelOperation(ze_rtas_parallel_operation_exp_handle_t *phParallelOperation) = 0;
+    virtual ze_result_t createRTASParallelOperationExt(ze_rtas_parallel_operation_ext_handle_t *phParallelOperation) = 0;
     virtual ze_result_t formatRTASCompatibilityCheck(ze_rtas_format_exp_t rtasFormatA, ze_rtas_format_exp_t rtasFormatB) = 0;
+    virtual ze_result_t formatRTASCompatibilityCheckExt(ze_rtas_format_ext_t rtasFormatA, ze_rtas_format_ext_t rtasFormatB) = 0;
 
     virtual int setErrorDescription(const std::string &str) = 0;
     virtual ze_result_t getErrorDescription(const char **ppString) = 0;
