@@ -1,16 +1,15 @@
 /*
- * Copyright (C) 2021-2022 Intel Corporation
+ * Copyright (C) 2021-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #include "shared/source/gen12lp/hw_cmds_adlp.h"
+#include "shared/source/gen12lp/hw_info_adlp.h"
 
 #include "level_zero/core/source/cmdqueue/cmdqueue_hw.inl"
-#include "level_zero/core/source/cmdqueue/cmdqueue_hw_base.inl"
-
-#include "cmdqueue_extended.inl"
+#include "level_zero/core/source/cmdqueue/cmdqueue_hw_skl_to_tgllp.inl"
 
 namespace L0 {
 template struct CommandQueueHw<IGFX_GEN12LP_CORE>;
