@@ -116,6 +116,8 @@ class L0GfxCoreHelper : public NEO::ApiGfxCoreHelper {
     virtual uint64_t getOaTimestampValidBits() const = 0;
     virtual CopyOffloadMode getDefaultCopyOffloadMode(bool additionalBlitPropertiesSupported) const = 0;
     virtual bool isDefaultCmdListWithCopyOffloadSupported(bool additionalBlitPropertiesSupported) const = 0;
+    virtual bool bcsSplitAggregatedModeEnabled() const = 0;
+    virtual bool supportMetricsAggregation() const = 0;
 
   protected:
     L0GfxCoreHelper() = default;
@@ -174,6 +176,8 @@ class L0GfxCoreHelperHw : public L0GfxCoreHelper {
     uint64_t getOaTimestampValidBits() const override;
     CopyOffloadMode getDefaultCopyOffloadMode(bool additionalBlitPropertiesSupported) const override;
     bool isDefaultCmdListWithCopyOffloadSupported(bool additionalBlitPropertiesSupported) const override;
+    bool bcsSplitAggregatedModeEnabled() const override;
+    bool supportMetricsAggregation() const override;
 
   protected:
     L0GfxCoreHelperHw() = default;
