@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021 Intel Corporation
+ * Copyright (C) 2021-2022 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -9,6 +9,6 @@
 
 namespace NEO {
 namespace ImplicitScaling {
-bool apiSupport = false;
-}
+bool apiSupport = true;
+} // namespace ImplicitScaling
 } // namespace NEO
