@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2020 Intel Corporation
+ * Copyright (C) 2020-2021 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -32,10 +32,9 @@ Sampler *Sampler::create(uint32_t productFamily, Device *device, const ze_sample
     SamplerImp *sampler = nullptr;
     if (allocator) {
         sampler = static_cast<SamplerImp *>((*allocator)());
-        if (sampler->initialize(device, desc)) {
-            delete sampler;
-            DEBUG_BREAK_IF(true);
-            return nullptr;
+        if (sampler->initialize(device, desc) != ZE_RESULT_SUCCESS) {
+            sampler->destroy();
+            sampler = nullptr;
         }
     }
 
