@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -17,7 +17,15 @@ BOOL APIENTRY DllMain(HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved) {
         L0::globalDriverSetup();
     }
     if (fdwReason == DLL_PROCESS_DETACH) {
-        L0::globalDriverTeardown();
+        /* If lpvReserved is non-NULL with DLL_PROCESS_DETACH, the process is terminating,
+         * clean up should be skipped according to the DllMain spec. */
+        bool processTermination = lpvReserved != nullptr;
+        L0::globalDriverTeardown(processTermination);
+
+        if (processTermination) {
+            return TRUE;
+        }
+
         if (L0::globalOsSysmanDriver != nullptr) {
             delete L0::globalOsSysmanDriver;
             L0::globalOsSysmanDriver = nullptr;
