@@ -19,6 +19,12 @@
 #endif
 
 namespace LevelZeroBlackBoxTests {
+decltype(&zerDriverGetDefaultContext) zerDriverGetDefaultContextFunc = nullptr;
+decltype(&zeDeviceSynchronize) zeDeviceSynchronizeFunc = nullptr;
+decltype(&zeCommandListAppendLaunchKernelWithArguments) zeCommandListAppendLaunchKernelWithArgumentsFunc = nullptr;
+decltype(&zerIdentifierTranslateToDeviceHandle) zerIdentifierTranslateToDeviceHandleFunc = nullptr;
+decltype(&zerDeviceTranslateToIdentifier) zerDeviceTranslateToIdentifierFunc = nullptr;
+decltype(&zerDriverGetLastErrorDescription) zerDriverGetLastErrorDescriptionFunc = nullptr;
 
 struct LoadedDriverExtensions {
     std::vector<ze_driver_extension_properties_t> extensions;
@@ -260,7 +266,7 @@ void getErrorMax(int argc, char *argv[]) {
     overrideErrorMax = getParamValue(argc, argv, "-em", "--errorMax", 0);
 }
 
-void printResult(bool aubMode, bool outputValidationSuccessful, const std::string &blackBoxName, const std::string &currentTest) {
+void printResult(bool aubMode, bool outputValidationSuccessful, const std::string_view blackBoxName, const std::string_view currentTest) {
     std::cout << std::endl
               << blackBoxName;
     if (!currentTest.empty()) {
@@ -279,7 +285,7 @@ void printResult(bool aubMode, bool outputValidationSuccessful, const std::strin
     }
 }
 
-void printResult(bool aubMode, bool outputValidationSuccessful, const std::string &blackBoxName) {
+void printResult(bool aubMode, bool outputValidationSuccessful, const std::string_view blackBoxName) {
     std::string currentTest{};
     printResult(aubMode, outputValidationSuccessful, blackBoxName, currentTest);
 }
@@ -451,8 +457,21 @@ std::vector<ze_device_handle_t> zelloInitContextAndGetDevices(ze_context_handle_
     }
 
     SUCCESS_OR_TERMINATE(zeDriverGet(&driverCount, &driverHandle));
-    ze_context_desc_t contextDesc = {ZE_STRUCTURE_TYPE_CONTEXT_DESC, nullptr, 0};
-    SUCCESS_OR_TERMINATE(zeContextCreate(driverHandle, &contextDesc, &context));
+
+    SUCCESS_OR_TERMINATE(zeDriverGetExtensionFunctionAddress(driverHandle, "zerDriverGetDefaultContext", reinterpret_cast<void **>(&zerDriverGetDefaultContextFunc)));
+    SUCCESS_OR_TERMINATE(zeDriverGetExtensionFunctionAddress(driverHandle, "zeDeviceSynchronize", reinterpret_cast<void **>(&zeDeviceSynchronizeFunc)));
+    SUCCESS_OR_TERMINATE(zeDriverGetExtensionFunctionAddress(driverHandle, "zeCommandListAppendLaunchKernelWithArguments", reinterpret_cast<void **>(&zeCommandListAppendLaunchKernelWithArgumentsFunc)));
+    SUCCESS_OR_TERMINATE(zeDriverGetExtensionFunctionAddress(driverHandle, "zerIdentifierTranslateToDeviceHandle", reinterpret_cast<void **>(&zerIdentifierTranslateToDeviceHandleFunc)));
+    SUCCESS_OR_TERMINATE(zeDriverGetExtensionFunctionAddress(driverHandle, "zerDeviceTranslateToIdentifier", reinterpret_cast<void **>(&zerDeviceTranslateToIdentifierFunc)));
+    SUCCESS_OR_TERMINATE(zeDriverGetExtensionFunctionAddress(driverHandle, "zerDriverGetLastErrorDescription", reinterpret_cast<void **>(&zerDriverGetLastErrorDescriptionFunc)));
+
+    context = zerDriverGetDefaultContextFunc();
+    if (!context) {
+        const char *description = nullptr;
+        SUCCESS_OR_TERMINATE(zeDriverGetLastErrorDescription(driverHandle, &description));
+        std::cerr << "Failed to get default context: " << (description ? description : "Unknown error") << "\n";
+        std::terminate();
+    }
 
     uint32_t deviceCount = 0;
     SUCCESS_OR_TERMINATE(zeDeviceGet(driverHandle, &deviceCount, nullptr));
@@ -500,9 +519,8 @@ bool checkImageSupport(ze_device_handle_t hDevice, bool test1D, bool test2D, boo
     return true;
 }
 
-void teardown(ze_context_handle_t context, ze_command_queue_handle_t cmdQueue) {
+void teardown(ze_command_queue_handle_t cmdQueue) {
     SUCCESS_OR_TERMINATE(zeCommandQueueDestroy(cmdQueue));
-    SUCCESS_OR_TERMINATE(zeContextDestroy(context));
 }
 
 void printDeviceProperties(const ze_device_properties_t &props) {
