@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -13,17 +13,9 @@
 
 #include <cstring>
 #include <ctime>
-#include <fstream>
 #include <iomanip>
 #include <iostream>
 #include <limits>
-#include <memory>
-
-#ifdef _WIN64
-#include <windows.h>
-#else
-#include <stdlib.h>
-#endif
 
 struct UserTracerData {
     uint32_t tracerData;
@@ -80,7 +72,7 @@ void onExitInit(
     UserInstanceData *instanceData = reinterpret_cast<UserInstanceData *>(*tracerInstanceUserData);
     SUCCESS_OR_WARNING_BOOL(instanceData->allocCount = initCount);
     float time = 1000.f * (endTime - instanceData->startTime) / CLOCKS_PER_SEC;
-    if (verbose) {
+    if (LevelZeroBlackBoxTests::verbose) {
         std::cout << "zeInit event " << instanceData->allocCount << " " << time << std::endl;
     }
     delete instanceData;
@@ -135,7 +127,7 @@ void onExitDriverGet(
     UserInstanceData *instanceData = reinterpret_cast<UserInstanceData *>(*tracerInstanceUserData);
     SUCCESS_OR_WARNING_BOOL(instanceData->allocCount = initCount);
     float time = 1000.f * (endTime - instanceData->startTime) / CLOCKS_PER_SEC;
-    if (verbose) {
+    if (LevelZeroBlackBoxTests::verbose) {
         std::cout << "zeDriverGet event " << instanceData->allocCount << " " << time << std::endl;
     }
     delete instanceData;
@@ -203,7 +195,7 @@ void onExitMemAllocDevice(
     UserInstanceData *instanceData = reinterpret_cast<UserInstanceData *>(*tracerInstanceUserData);
     SUCCESS_OR_WARNING_BOOL(instanceData->allocCount == memAllocDeviceCount);
     float time = 1000.f * (endTime - instanceData->startTime) / CLOCKS_PER_SEC;
-    if (verbose) {
+    if (LevelZeroBlackBoxTests::verbose) {
         std::cout << "zeDriverAllocDeviceMem event " << instanceData->allocCount << " " << time << std::endl;
     }
     delete instanceData;
@@ -268,7 +260,7 @@ void onExitMemAllocHost(
     UserInstanceData *instanceData = reinterpret_cast<UserInstanceData *>(*tracerInstanceUserData);
     SUCCESS_OR_WARNING_BOOL(instanceData->allocCount == memAllocHostCount);
     float time = 1000.f * (endTime - instanceData->startTime) / CLOCKS_PER_SEC;
-    if (verbose) {
+    if (LevelZeroBlackBoxTests::verbose) {
         std::cout << "zeMemAllocHost event " << instanceData->allocCount << " " << time << std::endl;
     }
     delete instanceData;
@@ -340,7 +332,7 @@ void onExitMemAllocShared(
     UserInstanceData *instanceData = reinterpret_cast<UserInstanceData *>(*tracerInstanceUserData);
     SUCCESS_OR_WARNING_BOOL(instanceData->allocCount == memAllocSharedCount);
     float time = 1000.f * (endTime - instanceData->startTime) / CLOCKS_PER_SEC;
-    if (verbose) {
+    if (LevelZeroBlackBoxTests::verbose) {
         std::cout << "zeMemAllocShared event " << instanceData->allocCount << " " << time << std::endl;
     }
     delete instanceData;
@@ -362,7 +354,7 @@ void testAppendMemoryCopy0(ze_context_handle_t &context, ze_device_handle_t &dev
     uint32_t numQueueGroups = 0;
     SUCCESS_OR_TERMINATE(deviceDdiTable.pfnGetCommandQueueGroupProperties(device, &numQueueGroups, nullptr));
     if (numQueueGroups == 0) {
-        std::cout << "No queue groups found!\n";
+        std::cerr << "No queue groups found!\n";
         std::terminate();
     }
     std::vector<ze_command_queue_group_properties_t> queueProperties(numQueueGroups);
@@ -415,8 +407,8 @@ void testAppendMemoryCopy0(ze_context_handle_t &context, ze_device_handle_t &dev
     SUCCESS_OR_TERMINATE(cmdQueueDdiTable.pfnExecuteCommandLists(cmdQueue, 1, &cmdList, nullptr));
     SUCCESS_OR_TERMINATE(cmdQueueDdiTable.pfnSynchronize(cmdQueue, std::numeric_limits<uint64_t>::max()));
 
-    // Validate stack and xe buffers have the original data from heapBuffer
-    validRet = (0 == memcmp(heapBuffer, stackBuffer, allocSize));
+    // Validate stack and ze buffers have the original data from heapBuffer
+    validRet = LevelZeroBlackBoxTests::validate(heapBuffer, stackBuffer, allocSize);
 
     delete[] heapBuffer;
     SUCCESS_OR_TERMINATE(memDdiTable.pfnFree(context, zeBuffer));
@@ -438,7 +430,7 @@ void testAppendMemoryCopy1(ze_context_handle_t &context, ze_device_handle_t &dev
     uint32_t numQueueGroups = 0;
     SUCCESS_OR_TERMINATE(deviceDdiTable.pfnGetCommandQueueGroupProperties(device, &numQueueGroups, nullptr));
     if (numQueueGroups == 0) {
-        std::cout << "No queue groups found!\n";
+        std::cerr << "No queue groups found!\n";
         std::terminate();
     }
     std::vector<ze_command_queue_group_properties_t> queueProperties(numQueueGroups);
@@ -496,8 +488,8 @@ void testAppendMemoryCopy1(ze_context_handle_t &context, ze_device_handle_t &dev
     SUCCESS_OR_TERMINATE(cmdQueueDdiTable.pfnExecuteCommandLists(cmdQueue, 1, &cmdList, nullptr));
     SUCCESS_OR_TERMINATE(cmdQueueDdiTable.pfnSynchronize(cmdQueue, std::numeric_limits<uint64_t>::max()));
 
-    // Validate stack and xe buffers have the original data from hostBuffer
-    validRet = (0 == memcmp(hostBuffer, stackBuffer, allocSize));
+    // Validate stack and ze buffers have the original data from hostBuffer
+    validRet = LevelZeroBlackBoxTests::validate(hostBuffer, stackBuffer, allocSize);
 
     SUCCESS_OR_TERMINATE(memDdiTable.pfnFree(context, hostBuffer));
     SUCCESS_OR_TERMINATE(memDdiTable.pfnFree(context, zeBuffer));
@@ -516,7 +508,7 @@ void testAppendMemoryCopy2(ze_context_handle_t &context, ze_device_handle_t &dev
     uint32_t numQueueGroups = 0;
     SUCCESS_OR_TERMINATE(deviceDdiTable.pfnGetCommandQueueGroupProperties(device, &numQueueGroups, nullptr));
     if (numQueueGroups == 0) {
-        std::cout << "No queue groups found!\n";
+        std::cerr << "No queue groups found!\n";
         std::terminate();
     }
     std::vector<ze_command_queue_group_properties_t> queueProperties(numQueueGroups);
@@ -546,21 +538,21 @@ void testAppendMemoryCopy2(ze_context_handle_t &context, ze_device_handle_t &dev
     SUCCESS_OR_TERMINATE(cmdListDdiTable.pfnCreate(context, device, &cmdListDesc, &cmdList));
 
     void *dstBuffer = nullptr;
-    uint32_t dstWidth = verbose ? 16 : 1024; // width of the dst 2D buffer in bytes
-    uint32_t dstHeight = verbose ? 32 : 512; // height of the dst 2D buffer in bytes
-    uint32_t dstOriginX = verbose ? 8 : 128; // Offset in bytes
-    uint32_t dstOriginY = verbose ? 8 : 144; // Offset in rows
-    uint32_t dstSize = dstHeight * dstWidth; // Size of the dst buffer
+    uint32_t dstWidth = LevelZeroBlackBoxTests::verbose ? 16 : 1024; // width of the dst 2D buffer in bytes
+    uint32_t dstHeight = LevelZeroBlackBoxTests::verbose ? 32 : 512; // height of the dst 2D buffer in bytes
+    uint32_t dstOriginX = LevelZeroBlackBoxTests::verbose ? 8 : 128; // Offset in bytes
+    uint32_t dstOriginY = LevelZeroBlackBoxTests::verbose ? 8 : 144; // Offset in rows
+    uint32_t dstSize = dstHeight * dstWidth;                         // Size of the dst buffer
 
     void *srcBuffer = nullptr;
-    uint32_t srcWidth = verbose ? 24 : 256;  // width of the src 2D buffer in bytes
-    uint32_t srcHeight = verbose ? 16 : 384; // height of the src 2D buffer in bytes
-    uint32_t srcOriginX = verbose ? 4 : 64;  // Offset in bytes
-    uint32_t srcOriginY = verbose ? 4 : 128; // Offset in rows
-    uint32_t srcSize = srcHeight * srcWidth; // Size of the src buffer
+    uint32_t srcWidth = LevelZeroBlackBoxTests::verbose ? 24 : 256;  // width of the src 2D buffer in bytes
+    uint32_t srcHeight = LevelZeroBlackBoxTests::verbose ? 16 : 384; // height of the src 2D buffer in bytes
+    uint32_t srcOriginX = LevelZeroBlackBoxTests::verbose ? 4 : 64;  // Offset in bytes
+    uint32_t srcOriginY = LevelZeroBlackBoxTests::verbose ? 4 : 128; // Offset in rows
+    uint32_t srcSize = srcHeight * srcWidth;                         // Size of the src buffer
 
-    uint32_t width = verbose ? 8 : 144;  // width of the region to copy
-    uint32_t height = verbose ? 12 : 96; // height of the region to copy
+    uint32_t width = LevelZeroBlackBoxTests::verbose ? 8 : 144;  // width of the region to copy
+    uint32_t height = LevelZeroBlackBoxTests::verbose ? 12 : 96; // height of the region to copy
     const ze_copy_region_t dstRegion = {dstOriginX, dstOriginY, 0, width, height, 0};
     const ze_copy_region_t srcRegion = {srcOriginX, srcOriginY, 0, width, height, 0};
 
@@ -600,7 +592,7 @@ void testAppendMemoryCopy2(ze_context_handle_t &context, ze_device_handle_t &dev
     SUCCESS_OR_TERMINATE(cmdQueueDdiTable.pfnSynchronize(cmdQueue, std::numeric_limits<uint64_t>::max()));
 
     uint8_t *dstBufferChar = reinterpret_cast<uint8_t *>(dstBuffer);
-    if (verbose) {
+    if (LevelZeroBlackBoxTests::verbose) {
         std::cout << "stackBuffer\n";
         for (uint32_t i = 0; i < srcHeight; i++) {
             for (uint32_t j = 0; j < srcWidth; j++) {
@@ -637,20 +629,12 @@ void testAppendMemoryCopy2(ze_context_handle_t &context, ze_device_handle_t &dev
     SUCCESS_OR_TERMINATE(cmdQueueDdiTable.pfnDestroy(cmdQueue));
 }
 
-void setEnvironmentVariable(const char *variableName, const char *variableValue) {
-#ifdef _WIN64
-    SetEnvironmentVariableA(variableName, variableValue);
-#else
-    setenv(variableName, variableValue, 1);
-#endif
-}
-
 int main(int argc, char *argv[]) {
     const std::string blackBoxName = "Zello Copy Tracing";
-    verbose = isVerbose(argc, argv);
-    bool aubMode = isAubMode(argc, argv);
+    LevelZeroBlackBoxTests::verbose = LevelZeroBlackBoxTests::isVerbose(argc, argv);
+    bool aubMode = LevelZeroBlackBoxTests::isAubMode(argc, argv);
 
-    setEnvironmentVariable("ZET_ENABLE_API_TRACING_EXP", "1");
+    LevelZeroBlackBoxTests::setEnvironmentVariable("ZET_ENABLE_API_TRACING_EXP", "1");
 
     ze_api_version_t apiVersion = ZE_API_VERSION_CURRENT;
 
@@ -679,8 +663,10 @@ int main(int argc, char *argv[]) {
 
     uint32_t driverCount = 0;
     SUCCESS_OR_TERMINATE(driverDdiTable.pfnGet(&driverCount, nullptr));
-    if (driverCount == 0)
+    if (driverCount == 0) {
+        std::cerr << "No driver handle found!" << std::endl;
         std::terminate();
+    }
 
     ze_driver_handle_t driver;
     driverCount = 1;
@@ -688,8 +674,10 @@ int main(int argc, char *argv[]) {
 
     uint32_t deviceCount = 0;
     SUCCESS_OR_TERMINATE(deviceDdiTable.pfnGet(driver, &deviceCount, nullptr));
-    if (deviceCount == 0)
+    if (deviceCount == 0) {
+        std::cerr << "No device found!" << std::endl;
         std::terminate();
+    }
 
     ze_device_handle_t device;
     deviceCount = 1;
@@ -730,7 +718,7 @@ int main(int argc, char *argv[]) {
 
     ze_device_properties_t deviceProperties = {ZE_STRUCTURE_TYPE_DEVICE_PROPERTIES};
     SUCCESS_OR_TERMINATE(deviceDdiTable.pfnGetProperties(device, &deviceProperties));
-    printDeviceProperties(deviceProperties);
+    LevelZeroBlackBoxTests::printDeviceProperties(deviceProperties);
 
     bool outputValidationSuccessful;
     testAppendMemoryCopy0(context, device, outputValidationSuccessful,
@@ -748,7 +736,7 @@ int main(int argc, char *argv[]) {
     SUCCESS_OR_TERMINATE(zetTracerExpSetEnabled(tracer, false));
     SUCCESS_OR_TERMINATE(zetTracerExpDestroy(tracer));
 
-    if (verbose) {
+    if (LevelZeroBlackBoxTests::verbose) {
         std::cout << "initCount: " << initCount
                   << " initPrologCount: " << initPrologCount
                   << " initEpilogCount: " << initEpilogCount
@@ -788,7 +776,7 @@ int main(int argc, char *argv[]) {
 
     SUCCESS_OR_TERMINATE(contextDdiTable.pfnDestroy(context));
 
-    printResult(aubMode, outputValidationSuccessful, blackBoxName);
+    LevelZeroBlackBoxTests::printResult(aubMode, outputValidationSuccessful, blackBoxName);
 
     int resultOnFailure = aubMode ? 0 : 1;
     return outputValidationSuccessful ? 0 : resultOnFailure;
