@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -11,6 +11,7 @@
 #include "shared/source/os_interface/os_interface.h"
 
 #include "level_zero/core/source/context/context_imp.h"
+#include "level_zero/core/test/unit_tests/mocks/mock_cmdlist.h"
 
 #include "gtest/gtest.h"
 
@@ -20,7 +21,8 @@ MultiTileCommandListAppendLaunchKernelFixture::MultiTileCommandListAppendLaunchK
 MultiTileImmediateCommandListAppendLaunchKernelFixture::MultiTileImmediateCommandListAppendLaunchKernelFixture() : backupApiSupport({&NEO::ImplicitScaling::apiSupport, true}), backupLocalMemory({&NEO::OSInterface::osEnableLocalMemory, true}) {}
 
 void MultiTileCommandListAppendLaunchKernelFixture::setUp() {
-    DebugManager.flags.EnableImplicitScaling.set(1);
+    debugManager.flags.EnableImplicitScaling.set(1);
+    debugManager.flags.SelectCmdListHeapAddressModel.set(0);
 
     MultiDeviceFixture::numRootDevices = 1u;
     MultiDeviceFixture::numSubDevices = 4u;
@@ -38,7 +40,7 @@ void MultiTileCommandListAppendLaunchKernelFixture::setUp() {
     contextImp = static_cast<ContextImp *>(Context::fromHandle(hContext));
 
     ze_result_t returnValue;
-    commandList = whiteboxCast(CommandList::create(productFamily, device, NEO::EngineGroupType::RenderCompute, 0u, returnValue));
+    commandList = CommandList::whiteboxCast(CommandList::create(productFamily, device, NEO::EngineGroupType::renderCompute, 0u, returnValue, false));
     EXPECT_EQ(ZE_RESULT_SUCCESS, returnValue);
 }
 
@@ -50,7 +52,8 @@ void MultiTileCommandListAppendLaunchKernelFixture::tearDown() {
 }
 
 void MultiTileImmediateCommandListAppendLaunchKernelFixture::setUp() {
-    DebugManager.flags.EnableImplicitScaling.set(1);
+    debugManager.flags.EnableImplicitScaling.set(1);
+    debugManager.flags.SelectCmdListHeapAddressModel.set(0);
 
     MultiDeviceFixture::numRootDevices = 1u;
     MultiDeviceFixture::numSubDevices = 2u;
