@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,17 +7,16 @@
 
 #pragma once
 
-#include "shared/test/common/helpers/variable_backup.h"
-
 #include "level_zero/core/test/unit_tests/fixtures/module_fixture.h"
-#include "level_zero/core/test/unit_tests/mocks/mock_cmdlist.h"
-#include "level_zero/core/test/unit_tests/mocks/mock_module.h"
 
 namespace L0 {
 struct ContextImp;
 struct Device;
+struct CommandListImp;
 
 namespace ult {
+template <typename Type>
+struct WhiteBox;
 
 struct MultiTileCommandListAppendLaunchKernelFixture : public MultiDeviceModuleFixture {
     MultiTileCommandListAppendLaunchKernelFixture();
@@ -25,7 +24,7 @@ struct MultiTileCommandListAppendLaunchKernelFixture : public MultiDeviceModuleF
     void tearDown();
 
     ContextImp *contextImp = nullptr;
-    WhiteBox<::L0::CommandList> *commandList = nullptr;
+    WhiteBox<::L0::CommandListImp> *commandList = nullptr;
     L0::Device *device = nullptr;
     VariableBackup<bool> backup;
 };
