@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -54,6 +54,16 @@ TEST(zeCommandListAppendMemoryFill, whenCalledThenRedirectedToObject) {
     ASSERT_EQ(ZE_RESULT_SUCCESS, res);
 }
 
+TEST(zeCommandListAppendMemoryFill, whenPatternSizeNotPowerOf2ThenReturnError) {
+    MockCommandList commandList;
+    size_t bufferSize = 4096u;
+
+    int value = 0;
+    auto res = zeCommandListAppendMemoryFill(&commandList, reinterpret_cast<void *>(0x1000), reinterpret_cast<void *>(&value),
+                                             3u, bufferSize, nullptr, 0, nullptr);
+    ASSERT_EQ(ZE_RESULT_ERROR_INVALID_SIZE, res);
+}
+
 TEST(zeCommandListAppendWaitOnEvent, whenCalledThenRedirectedToObject) {
     MockCommandList commandList;
     ze_event_handle_t event = reinterpret_cast<ze_event_handle_t>(0x2000);
@@ -71,7 +81,7 @@ TEST(zeCommandListAppendWriteGlobalTimestamp, whenCalledThenRedirectedToObject)
 
 TEST(zeCommandListAppendLaunchKernel, whenCalledThenRedirectedToObject) {
     MockCommandList commandList;
-    Mock<::L0::Kernel> kernel;
+    Mock<::L0::KernelImp> kernel;
     ze_group_count_t dispatchKernelArguments;
 
     auto result =
