@@ -432,8 +432,8 @@ HWTEST_F(CommandQueueIndirectAllocations, givenDebugModeToTreatIndirectAllocatio
     ASSERT_NE(nullptr, gpuAlloc);
 
     createKernel();
-    kernel->unifiedMemoryControls.indirectDeviceAllocationsAllowed = true;
-    kernel->kernelHasIndirectAccess = true;
+    kernel->state.unifiedMemoryControls.indirectDeviceAllocationsAllowed = true;
+    kernel->state.kernelHasIndirectAccess = true;
 
     EXPECT_TRUE(kernel->getUnifiedMemoryControls().indirectDeviceAllocationsAllowed);
 
@@ -497,8 +497,8 @@ HWTEST_F(CommandQueueIndirectAllocations, givenDeviceThatSupportsSubmittingIndir
     ASSERT_NE(nullptr, gpuAlloc);
 
     createKernel();
-    kernel->unifiedMemoryControls.indirectDeviceAllocationsAllowed = true;
-    kernel->kernelHasIndirectAccess = true;
+    kernel->state.unifiedMemoryControls.indirectDeviceAllocationsAllowed = true;
+    kernel->state.kernelHasIndirectAccess = true;
     EXPECT_TRUE(kernel->getUnifiedMemoryControls().indirectDeviceAllocationsAllowed);
 
     ze_group_count_t groupCount{1, 1, 1};
@@ -560,8 +560,8 @@ HWTEST_F(CommandQueueIndirectAllocations, givenDeviceThatSupportsSubmittingIndir
     ASSERT_NE(nullptr, gpuAlloc);
 
     createKernel();
-    kernel->unifiedMemoryControls.indirectDeviceAllocationsAllowed = true;
-    kernel->kernelHasIndirectAccess = true;
+    kernel->state.unifiedMemoryControls.indirectDeviceAllocationsAllowed = true;
+    kernel->state.kernelHasIndirectAccess = true;
     EXPECT_TRUE(kernel->getUnifiedMemoryControls().indirectDeviceAllocationsAllowed);
 
     static_cast<MockMemoryManager *>(driverHandle->getMemoryManager())->overrideAllocateAsPackReturn = 1u;
@@ -614,8 +614,8 @@ HWTEST_F(CommandQueueIndirectAllocations,
     ASSERT_NE(nullptr, gpuAlloc);
 
     createKernel();
-    kernel->unifiedMemoryControls.indirectDeviceAllocationsAllowed = true;
-    kernel->kernelHasIndirectAccess = true;
+    kernel->state.unifiedMemoryControls.indirectDeviceAllocationsAllowed = true;
+    kernel->state.kernelHasIndirectAccess = true;
     EXPECT_TRUE(kernel->getUnifiedMemoryControls().indirectDeviceAllocationsAllowed);
 
     static_cast<MockMemoryManager *>(driverHandle->getMemoryManager())->overrideAllocateAsPackReturn = 1u;
@@ -672,7 +672,7 @@ HWTEST_F(CommandQueueIndirectAllocations, givenImmediateCommandListAndFlushTaskW
     ASSERT_NE(nullptr, gpuAlloc);
 
     createKernel();
-    kernel->unifiedMemoryControls.indirectDeviceAllocationsAllowed = true;
+    kernel->state.unifiedMemoryControls.indirectDeviceAllocationsAllowed = true;
     EXPECT_TRUE(kernel->getUnifiedMemoryControls().indirectDeviceAllocationsAllowed);
 
     static_cast<MockMemoryManager *>(driverHandle->getMemoryManager())->overrideAllocateAsPackReturn = 1u;
