@@ -12,7 +12,7 @@
 #include "gtest/gtest.h"
 
 namespace NEO {
-struct PhyicalDevicePciSpeedInfo;
+struct PhysicalDevicePciSpeedInfo;
 struct UltDeviceFactory;
 class ExecutionEnvironment;
 } // namespace NEO
@@ -21,11 +21,11 @@ namespace L0 {
 namespace ult {
 
 struct PciSpeedInfoTest : public ::testing::Test {
-    std::unique_ptr<NEO::UltDeviceFactory> createDevices(uint32_t numSubDevices, const NEO::PhyicalDevicePciSpeedInfo &pciSpeedInfo);
+    std::unique_ptr<NEO::UltDeviceFactory> createDevices(uint32_t numSubDevices, const NEO::PhysicalDevicePciSpeedInfo &pciSpeedInfo);
     DebugManagerStateRestore restorer;
 
   private:
-    void setPciSpeedInfo(NEO::ExecutionEnvironment *executionEnvironment, const NEO::PhyicalDevicePciSpeedInfo &pciSpeedInfo);
+    void setPciSpeedInfo(NEO::ExecutionEnvironment *executionEnvironment, const NEO::PhysicalDevicePciSpeedInfo &pciSpeedInfo);
 };
 
 } // namespace ult
