@@ -7,9 +7,14 @@
 
 #include "shared/source/built_ins/sip.h"
 #include "shared/source/helpers/aligned_memory.h"
+#include "shared/source/memory_manager/unified_memory_manager.h"
+#include "shared/test/common/mocks/mock_device.h"
 #include "shared/test/common/mocks/mock_memory_manager.h"
+#include "shared/test/common/mocks/mock_memory_operations_handler.h"
 #include "shared/test/common/test_macros/test.h"
 
+#include "level_zero/core/source/context/context.h"
+#include "level_zero/core/source/device/device.h"
 #include "level_zero/core/source/driver/driver_handle_imp.h"
 #include "level_zero/core/test/unit_tests/fixtures/host_pointer_manager_fixture.h"
 #include "level_zero/core/test/unit_tests/mocks/mock_host_pointer_manager.h"
@@ -80,7 +85,7 @@ TEST_F(HostPointerManagerTest, givenPointerRegisteredWhenSvmAllocationExistsThen
     size_t usmSize = MemoryConstants::pageSize;
     void *usmBuffer = hostDriverHandle->getMemoryManager()->allocateSystemMemory(usmSize, usmSize);
     NEO::GraphicsAllocation *usmAllocation = hostDriverHandle->getMemoryManager()->allocateGraphicsMemoryWithProperties(
-        {device->getRootDeviceIndex(), false, usmSize, NEO::AllocationType::BUFFER_HOST_MEMORY, false, neoDevice->getDeviceBitfield()},
+        {device->getRootDeviceIndex(), false, usmSize, NEO::AllocationType::bufferHostMemory, false, neoDevice->getDeviceBitfield()},
         usmBuffer);
     ASSERT_NE(nullptr, usmAllocation);
 
@@ -88,7 +93,7 @@ TEST_F(HostPointerManagerTest, givenPointerRegisteredWhenSvmAllocationExistsThen
     allocData.gpuAllocations.addAllocation(usmAllocation);
     allocData.cpuAllocation = nullptr;
     allocData.size = usmSize;
-    allocData.memoryType = InternalMemoryType::NOT_SPECIFIED;
+    allocData.memoryType = InternalMemoryType::notSpecified;
     allocData.device = nullptr;
     hostDriverHandle->getSvmAllocsManager()->insertSVMAlloc(allocData);
 
@@ -110,7 +115,7 @@ TEST_F(HostPointerManagerTest, givenSvmAllocationExistsWhenGettingExistingAlloca
     size_t usmSize = MemoryConstants::pageSize;
     void *usmBuffer = hostDriverHandle->getMemoryManager()->allocateSystemMemory(usmSize, usmSize);
     NEO::GraphicsAllocation *usmAllocation = hostDriverHandle->getMemoryManager()->allocateGraphicsMemoryWithProperties(
-        {device->getRootDeviceIndex(), false, usmSize, NEO::AllocationType::BUFFER_HOST_MEMORY, false, neoDevice->getDeviceBitfield()},
+        {device->getRootDeviceIndex(), false, usmSize, NEO::AllocationType::bufferHostMemory, false, neoDevice->getDeviceBitfield()},
         usmBuffer);
     ASSERT_NE(nullptr, usmAllocation);
 
@@ -118,7 +123,7 @@ TEST_F(HostPointerManagerTest, givenSvmAllocationExistsWhenGettingExistingAlloca
     allocData.gpuAllocations.addAllocation(usmAllocation);
     allocData.cpuAllocation = nullptr;
     allocData.size = usmSize;
-    allocData.memoryType = InternalMemoryType::NOT_SPECIFIED;
+    allocData.memoryType = InternalMemoryType::notSpecified;
     allocData.device = nullptr;
     hostDriverHandle->getSvmAllocsManager()->insertSVMAlloc(allocData);
 
@@ -389,8 +394,8 @@ TEST_F(HostPointerManagerTest, givenNoPointerRegisteredWhenAllocationCreationFai
 TEST_F(HostPointerManagerTest, givenHostAllocationImportedWhenMakingResidentAddressThenAllocationMadeResident) {
     void *testPtr = heapPointer;
 
-    mockMemoryInterface->makeResidentResult = NEO::MemoryOperationsStatus::SUCCESS;
-    mockMemoryInterface->evictResult = NEO::MemoryOperationsStatus::SUCCESS;
+    mockMemoryInterface->makeResidentResult = NEO::MemoryOperationsStatus::success;
+    mockMemoryInterface->evictResult = NEO::MemoryOperationsStatus::success;
 
     auto result = context->makeMemoryResident(device, testPtr, MemoryConstants::pageSize);
     EXPECT_EQ(ZE_RESULT_ERROR_INVALID_ARGUMENT, result);
