@@ -1,22 +1,22 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #include "shared/source/compiler_interface/compiler_options.h"
-#include "shared/source/helpers/aligned_memory.h"
-#include "shared/source/helpers/file_io.h"
-#include "shared/test/common/helpers/test_files.h"
+#include "shared/test/common/mocks/mock_command_stream_receiver.h"
+#include "shared/test/common/mocks/mock_device.h"
 #include "shared/test/common/mocks/mock_modules_zebin.h"
 #include "shared/test/common/test_macros/test.h"
 
-#include "level_zero/core/source/image/image.h"
 #include "level_zero/core/source/kernel/kernel.h"
 #include "level_zero/core/source/module/module_build_log.h"
 #include "level_zero/core/test/unit_tests/fixtures/device_fixture.h"
+#include "level_zero/core/test/unit_tests/mocks/mock_device.h"
 #include "level_zero/core/test/unit_tests/mocks/mock_module.h"
+
 namespace L0 {
 namespace ult {
 
@@ -24,7 +24,7 @@ class ModuleOnlineCompiled : public DeviceFixture, public testing::Test {
   public:
     void SetUp() override {
         DeviceFixture::setUp();
-        DebugManager.flags.FailBuildProgramWithStatefulAccess.set(0);
+        debugManager.flags.FailBuildProgramWithStatefulAccess.set(0);
 
         auto zebinData = std::make_unique<ZebinTestData::ZebinWithL0TestCommonModule>(device->getHwInfo());
         const auto &src = zebinData->storage;
@@ -34,7 +34,7 @@ class ModuleOnlineCompiled : public DeviceFixture, public testing::Test {
         modDesc.inputSize = static_cast<uint32_t>(src.size());
         modDesc.pInputModule = reinterpret_cast<const uint8_t *>(src.data());
         ze_result_t result = ZE_RESULT_SUCCESS;
-        module.reset(whiteboxCast(Module::create(device, &modDesc, nullptr, ModuleType::User, &result)));
+        module.reset(whiteboxCast(Module::create(device, &modDesc, nullptr, ModuleType::user, &result)));
         ASSERT_NE(nullptr, module);
     }
 
@@ -49,7 +49,7 @@ class ModuleOnlineCompiled : public DeviceFixture, public testing::Test {
 using ModuleTests = Test<DeviceFixture>;
 
 TEST_F(ModuleTests, WhenCreatingBuildOptionsThenOptionsParsedCorrectly) {
-    auto module = new ModuleImp(device, nullptr, ModuleType::User);
+    auto module = new ModuleImp(device, nullptr, ModuleType::user);
     ASSERT_NE(nullptr, module); // NOLINT(clang-analyzer-cplusplus.NewDeleteLeaks)
 
     std::string buildOptions;
@@ -64,7 +64,7 @@ TEST_F(ModuleTests, WhenCreatingBuildOptionsThenOptionsParsedCorrectly) {
 }
 
 TEST_F(ModuleTests, whenCreatingAutoGrfBuildOptionsThenOptionsParsedCorrectly) {
-    ModuleImp module(device, nullptr, ModuleType::User);
+    ModuleImp module(device, nullptr, ModuleType::user);
 
     std::string buildOptions;
     std::string internalBuildOptions;
@@ -74,6 +74,67 @@ TEST_F(ModuleTests, whenCreatingAutoGrfBuildOptionsThenOptionsParsedCorrectly) {
     EXPECT_TRUE(NEO::CompilerOptions::contains(internalBuildOptions, NEO::CompilerOptions::autoGrf));
 }
 
+TEST(ModuleDestroyTest, givenIsaAllocationWhenIsModuleDestroyedThenRequireInstructionCacheFlushInCsrThatUsedTheAllocation) {
+    EnvironmentWithCsrWrapper environment;
+    environment.setCsrType<MockCommandStreamReceiver>();
+    const uint32_t rootDeviceIndex = 0u;
+    NEO::HardwareInfo hwInfo = *NEO::defaultHwInfo.get();
+    auto *neoMockDevice = NEO::MockDevice::createWithNewExecutionEnvironment<NEO::MockDevice>(&hwInfo, rootDeviceIndex);
+
+    auto mockCommandStreamReceiver = static_cast<MockCommandStreamReceiver *>(&neoMockDevice->getGpgpuCommandStreamReceiver());
+    mockCommandStreamReceiver->makeResidentParentCall = true;
+
+    MockDeviceImp deviceImp(neoMockDevice);
+
+    auto module = new MockModule{&deviceImp, nullptr, ModuleType::user};
+    module->translationUnit.reset(new MockModuleTranslationUnit{&deviceImp});
+
+    auto kernelInfo = new KernelInfo{};
+    kernelInfo->heapInfo.pKernelHeap = reinterpret_cast<const void *>(0xdeadbeef0000);
+    kernelInfo->heapInfo.kernelHeapSize = static_cast<uint32_t>(0x40);
+    module->translationUnit->programInfo.kernelInfos.push_back(kernelInfo);
+
+    module->initializeKernelImmutableDatas();
+    auto &kernelImmDatas = module->getKernelImmutableDataVector();
+    auto csr = deviceImp.getNEODevice()->getEngine(0).commandStreamReceiver;
+    csr->makeResident(*kernelImmDatas[0]->getIsaParentAllocation());
+
+    module->destroy();
+
+    EXPECT_TRUE(mockCommandStreamReceiver->requiresInstructionCacheFlush);
+}
+
+TEST(ModuleDestroyTest, givenKernelImmutableDataWithNullIsaAllocationWhenIsModuleDestroyedThenRequiresInstructionCacheFlushIsNotSetInCsr) {
+    EnvironmentWithCsrWrapper environment;
+    environment.setCsrType<MockCommandStreamReceiver>();
+    const uint32_t rootDeviceIndex = 0u;
+    NEO::HardwareInfo hwInfo = *NEO::defaultHwInfo.get();
+    auto *neoMockDevice = NEO::MockDevice::createWithNewExecutionEnvironment<NEO::MockDevice>(&hwInfo, rootDeviceIndex);
+
+    auto mockCommandStreamReceiver = static_cast<MockCommandStreamReceiver *>(&neoMockDevice->getGpgpuCommandStreamReceiver());
+    mockCommandStreamReceiver->makeResidentParentCall = true;
+
+    MockDeviceImp deviceImp(neoMockDevice);
+
+    auto module = new MockModule{&deviceImp, nullptr, ModuleType::user};
+    module->translationUnit.reset(new MockModuleTranslationUnit{&deviceImp});
+
+    auto kernelInfo = new KernelInfo{};
+    kernelInfo->heapInfo.pKernelHeap = reinterpret_cast<const void *>(0xdeadbeef0000);
+    kernelInfo->heapInfo.kernelHeapSize = static_cast<uint32_t>(0x40);
+    module->translationUnit->programInfo.kernelInfos.push_back(kernelInfo);
+
+    module->initializeKernelImmutableDatas();
+    auto &kernelImmDatas = module->getKernelImmutableDataVector();
+    for (auto &kernelImmData : kernelImmDatas) {
+        kernelImmData->setIsaParentAllocation(nullptr);
+    }
+
+    module->destroy();
+
+    EXPECT_FALSE(mockCommandStreamReceiver->requiresInstructionCacheFlush);
+}
+
 TEST(ModuleBuildLog, WhenCreatingModuleBuildLogThenNonNullPointerReturned) {
     auto moduleBuildLog = ModuleBuildLog::create();
     ASSERT_NE(nullptr, moduleBuildLog);
@@ -187,7 +248,7 @@ TEST_F(ModuleOnlineCompiled, WhenCreatingFromNativeBinaryThenGenBinaryIsReturned
     modDesc.inputSize = binarySize;
     modDesc.pInputModule = reinterpret_cast<const uint8_t *>(storage.get());
     ze_result_t initResult = ZE_RESULT_SUCCESS;
-    L0::Module *moduleFromNativeBinary = Module::create(device, &modDesc, nullptr, ModuleType::User, &initResult);
+    L0::Module *moduleFromNativeBinary = Module::create(device, &modDesc, nullptr, ModuleType::user, &initResult);
     EXPECT_NE(nullptr, moduleFromNativeBinary);
 
     delete moduleFromNativeBinary;
@@ -286,7 +347,7 @@ TEST_F(ModuleOnlineCompiled, GivenKernelThenCorrectAttributesAreReturned) {
 
 TEST_F(ModuleTests, givenLargeGrfFlagSetWhenCreatingModuleThenOverrideInternalFlags) {
     DebugManagerStateRestore restorer;
-    DebugManager.flags.ForceLargeGrfCompilationMode.set(true);
+    debugManager.flags.ForceLargeGrfCompilationMode.set(true);
 
     auto pMockCompilerInterface = new MockCompilerInterface;
     auto &rootDeviceEnvironment = this->neoDevice->executionEnvironment->rootDeviceEnvironments[this->neoDevice->getRootDeviceIndex()];
@@ -302,7 +363,7 @@ TEST_F(ModuleTests, givenLargeGrfFlagSetWhenCreatingModuleThenOverrideInternalFl
 
     auto mockTranslationUnit = new MockModuleTranslationUnit(device);
     mockTranslationUnit->processUnpackedBinaryCallBase = false;
-    Module module(device, nullptr, ModuleType::User);
+    Module module(device, nullptr, ModuleType::user);
 
     module.translationUnit.reset(mockTranslationUnit);
 
@@ -317,7 +378,7 @@ TEST_F(ModuleTests, givenLargeGrfFlagSetWhenCreatingModuleThenOverrideInternalFl
 
 TEST_F(ModuleTests, givenAutoGrfFlagSetWhenCreatingModuleThenOverrideInternalFlags) {
     DebugManagerStateRestore restorer;
-    DebugManager.flags.ForceAutoGrfCompilationMode.set(1);
+    debugManager.flags.ForceAutoGrfCompilationMode.set(1);
 
     auto pMockCompilerInterface = new MockCompilerInterface;
     auto &rootDeviceEnvironment = this->neoDevice->executionEnvironment->rootDeviceEnvironments[this->neoDevice->getRootDeviceIndex()];
@@ -333,7 +394,7 @@ TEST_F(ModuleTests, givenAutoGrfFlagSetWhenCreatingModuleThenOverrideInternalFla
 
     auto mockTranslationUnit = new MockModuleTranslationUnit(device);
     mockTranslationUnit->processUnpackedBinaryCallBase = false;
-    Module module(device, nullptr, ModuleType::User);
+    Module module(device, nullptr, ModuleType::user);
 
     module.translationUnit.reset(mockTranslationUnit);
 
@@ -348,7 +409,7 @@ TEST_F(ModuleTests, givenAutoGrfFlagSetWhenCreatingModuleThenOverrideInternalFla
 
 TEST_F(ModuleTests, givenDefaultGrfFlagSetWhenCreatingModuleThenOverrideInternalFlags) {
     DebugManagerStateRestore restorer;
-    DebugManager.flags.ForceDefaultGrfCompilationMode.set(true);
+    debugManager.flags.ForceDefaultGrfCompilationMode.set(true);
 
     auto pMockCompilerInterface = new MockCompilerInterface;
     auto &rootDeviceEnvironment = this->neoDevice->executionEnvironment->rootDeviceEnvironments[this->neoDevice->getRootDeviceIndex()];
@@ -364,7 +425,7 @@ TEST_F(ModuleTests, givenDefaultGrfFlagSetWhenCreatingModuleThenOverrideInternal
 
     auto mockTranslationUnit = new MockModuleTranslationUnit(device);
     mockTranslationUnit->processUnpackedBinaryCallBase = false;
-    Module module(device, nullptr, ModuleType::User);
+    Module module(device, nullptr, ModuleType::user);
 
     module.translationUnit.reset(mockTranslationUnit);
 
@@ -390,7 +451,7 @@ TEST_F(ModuleTests, givenFP64EmulationDisabledWhenCreatingModuleThenEnableFP64Ge
 
     ModuleBuildLog *moduleBuildLog = nullptr;
 
-    auto module = std::unique_ptr<L0::ModuleImp>(new L0::ModuleImp(device, moduleBuildLog, ModuleType::Builtin));
+    auto module = std::unique_ptr<L0::ModuleImp>(new L0::ModuleImp(device, moduleBuildLog, ModuleType::builtin));
     ASSERT_NE(nullptr, module.get());
     module->initialize(&moduleDesc, device->getNEODevice());
 
@@ -410,7 +471,7 @@ TEST_F(ModuleTests, givenFP64EmulationEnabledWhenCreatingModuleThenEnableFP64Gen
 
     ModuleBuildLog *moduleBuildLog = nullptr;
 
-    auto module = std::unique_ptr<L0::ModuleImp>(new L0::ModuleImp(device, moduleBuildLog, ModuleType::Builtin));
+    auto module = std::unique_ptr<L0::ModuleImp>(new L0::ModuleImp(device, moduleBuildLog, ModuleType::builtin));
     ASSERT_NE(nullptr, module.get());
     module->initialize(&moduleDesc, device->getNEODevice());
 
