@@ -12,7 +12,7 @@ namespace ult {
 
 TEST_F(ZeApiTracingRuntimeTests, WhenCallingInitTracingWrapperWithOneSetOfPrologEpilogsThenReturnSuccess) {
     ze_result_t result = ZE_RESULT_SUCCESS;
-    driverDdiTable.coreDdiTable.Global.pfnInit = [](ze_init_flags_t flags) { return ZE_RESULT_SUCCESS; };
+    driverDdiTable.coreDdiTable.Global.pfnInit = [](ze_init_flags_t flags) -> ze_result_t { return ZE_RESULT_SUCCESS; };
 
     prologCbs.Global.pfnInitCb = genericPrologCallbackPtr;
     epilogCbs.Global.pfnInitCb = genericEpilogCallbackPtr;
