@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2021 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,9 +7,10 @@
 
 #pragma once
 
-#include <level_zero/zet_api.h>
+#include "level_zero/core/source/helpers/api_handle_helper.h"
 
-struct _zet_tracer_exp_handle_t {};
+struct _zet_tracer_exp_handle_t : BaseHandle {};
+static_assert(IsCompliantWithDdiHandlesExt<_zet_tracer_exp_handle_t>);
 
 namespace L0 {
 
@@ -26,10 +27,4 @@ struct APITracer : _zet_tracer_exp_handle_t {
 
 ze_result_t createAPITracer(zet_context_handle_t hContext, const zet_tracer_exp_desc_t *desc, zet_tracer_exp_handle_t *phTracer);
 
-struct APITracerContext {
-    virtual ~APITracerContext() = default;
-    virtual void *getActiveTracersList() = 0;
-    virtual void releaseActivetracersList() = 0;
-};
-
 } // namespace L0
