@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,6 +7,7 @@
 
 #pragma once
 
+#include "level_zero/ddi/ze_ddi_tables.h"
 #include "level_zero/experimental/source/tracing/tracing.h"
 #include "level_zero/experimental/source/tracing/tracing_barrier_imp.h"
 #include "level_zero/experimental/source/tracing/tracing_cmdlist_imp.h"
@@ -24,8 +25,6 @@
 #include "level_zero/experimental/source/tracing/tracing_sampler_imp.h"
 #include <level_zero/ze_api.h>
 
-#include "ze_ddi_tables.h"
-
 #include <atomic>
 #include <chrono>
 #include <list>
@@ -86,18 +85,18 @@ class ThreadPrivateTracerData {
     ThreadPrivateTracerData &operator=(const ThreadPrivateTracerData &);
 };
 
-struct APITracerContextImp : APITracerContext {
+struct APITracerContextImp {
   public:
     APITracerContextImp() {
         activeTracerArray.store(&emptyTracerArray, std::memory_order_relaxed);
     };
 
-    ~APITracerContextImp() override;
+    ~APITracerContextImp();
 
     static void apiTracingEnable(ze_init_flag_t flag);
 
-    void *getActiveTracersList() override;
-    void releaseActivetracersList() override;
+    void *getActiveTracersList();
+    void releaseActivetracersList();
 
     ze_result_t enableTracingImp(struct APITracerImp *newTracer, ze_bool_t enable);
     ze_result_t finalizeDisableImpTracingWait(struct APITracerImp *oldTracer);
