@@ -9,7 +9,7 @@
 #include "shared/source/helpers/non_copyable_or_moveable.h"
 
 #include "level_zero/sysman/source/api/diagnostics/sysman_os_diagnostics.h"
-#include "level_zero/sysman/source/windows/zes_os_sysman_imp.h"
+#include "level_zero/sysman/source/shared/windows/zes_os_sysman_imp.h"
 
 namespace L0 {
 namespace Sysman {
