@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023 Intel Corporation
+ * Copyright (C) 2023-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -9,13 +9,13 @@
 #include "shared/source/helpers/non_copyable_or_moveable.h"
 
 #include "level_zero/sysman/source/api/fan/sysman_os_fan.h"
-#include "level_zero/sysman/source/windows/zes_os_sysman_imp.h"
+#include "level_zero/sysman/source/shared/windows/zes_os_sysman_imp.h"
 
 namespace L0 {
 namespace Sysman {
 
 class KmdSysManager;
-class WddmFanImp : public OsFan, NEO::NonCopyableOrMovableClass {
+class WddmFanImp : public OsFan, NEO::NonCopyableAndNonMovableClass {
   public:
     ze_result_t getProperties(zes_fan_properties_t *pProperties) override;
     ze_result_t getConfig(zes_fan_config_t *pConfig) override;
