@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -10,17 +10,22 @@
 
 #include "level_zero/sysman/source/api/firmware/sysman_firmware_imp.h"
 #include "level_zero/sysman/source/api/firmware/sysman_os_firmware.h"
-#include "level_zero/sysman/source/linux/zes_os_sysman_imp.h"
+#include "level_zero/sysman/source/shared/linux/zes_os_sysman_imp.h"
 
 namespace L0 {
 namespace Sysman {
 
 class FirmwareUtil;
+class SysFsAccessInterface;
 
-class LinuxFirmwareImp : public OsFirmware, NEO::NonCopyableOrMovableClass {
+class LinuxFirmwareImp : public OsFirmware, NEO::NonCopyableAndNonMovableClass {
   public:
     void osGetFwProperties(zes_firmware_properties_t *pProperties) override;
     ze_result_t osFirmwareFlash(void *pImage, uint32_t size) override;
+    ze_result_t osGetFirmwareFlashProgress(uint32_t *pCompletionPercent) override;
+    ze_result_t osGetSecurityVersion(char *pVersion) override;
+    ze_result_t osSetSecurityVersion() override;
+    ze_result_t osGetConsoleLogs(size_t *pSize, char *pFirmwareLog) override;
     ze_result_t getFirmwareVersion(std::string fwType, zes_firmware_properties_t *pProperties);
     LinuxFirmwareImp() = default;
     LinuxFirmwareImp(OsSysman *pOsSysman, const std::string &fwType);
@@ -28,7 +33,7 @@ class LinuxFirmwareImp : public OsFirmware, NEO::NonCopyableOrMovableClass {
 
   protected:
     FirmwareUtil *pFwInterface = nullptr;
-    SysfsAccess *pSysfsAccess = nullptr;
+    SysFsAccessInterface *pSysfsAccess = nullptr;
     std::string osFwType;
 };
 
