@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -18,10 +18,14 @@ namespace Sysman {
 
 class OsFirmware;
 
-class FirmwareImp : public Firmware, NEO::NonCopyableOrMovableClass {
+class FirmwareImp : public Firmware, NEO::NonCopyableAndNonMovableClass {
   public:
     ze_result_t firmwareGetProperties(zes_firmware_properties_t *pProperties) override;
     ze_result_t firmwareFlash(void *pImage, uint32_t size) override;
+    ze_result_t firmwareGetFlashProgress(uint32_t *pCompletionPercent) override;
+    ze_result_t firmwareGetSecurityVersion(char *pVersion) override;
+    ze_result_t firmwareSetSecurityVersion() override;
+    ze_result_t firmwareGetConsoleLogs(size_t *pSize, char *pFirmwareLog) override;
     FirmwareImp() = default;
     FirmwareImp(OsSysman *pOsSysman, const std::string &fwType);
     ~FirmwareImp() override;
