@@ -9,7 +9,7 @@
 
 #include "shared/source/helpers/debug_helpers.h"
 
-#include "level_zero/sysman/source/sysman_device_imp.h"
+#include "level_zero/sysman/source/device/sysman_device_imp.h"
 
 namespace L0 {
 namespace Sysman {
