@@ -10,8 +10,8 @@
 #include "shared/source/debug_settings/debug_settings_manager.h"
 #include "shared/source/os_interface/linux/engine_info.h"
 
+#include "level_zero/sysman/source/shared/linux/kmd_interface/sysman_kmd_interface.h"
 #include "level_zero/sysman/source/shared/linux/sysman_fs_access_interface.h"
-#include "level_zero/sysman/source/shared/linux/sysman_kmd_interface.h"
 #include "level_zero/sysman/source/shared/linux/zes_os_sysman_imp.h"
 #include "level_zero/sysman/source/sysman_const.h"
 
@@ -40,7 +40,7 @@ static ze_result_t readSchedulerValueFromSysfs(SysfsName schedulerSysfsName,
         }
         result = pSysmanImp->getSysfsAccess().read(path, readValue);
         if (result == ZE_RESULT_SUCCESS) {
-            pSysmanKmdInterface->convertSysfsValueUnit(SysmanKmdInterface::micro,
+            pSysmanKmdInterface->convertSysfsValueUnit(SysfsValueUnit::micro,
                                                        pSysmanKmdInterface->getNativeUnit(schedulerSysfsName),
                                                        readValue, readValue);
             readValueVec[i] = readValue;
@@ -79,7 +79,7 @@ static ze_result_t writeSchedulerValueToSysfs(SysfsName schedulerSysfsName,
     auto pSysmanKmdInterface = pSysmanImp->getSysmanKmdInterface();
     auto sysfsName = pSysmanKmdInterface->getSysfsFilePath(schedulerSysfsName, subdeviceId, false);
     pSysmanKmdInterface->convertSysfsValueUnit(pSysmanKmdInterface->getNativeUnit(schedulerSysfsName),
-                                               SysmanKmdInterface::micro, writeValue, writeValue);
+                                               SysfsValueUnit::micro, writeValue, writeValue);
     auto engineBasePath = pSysmanKmdInterface->getEngineBasePath(subdeviceId);
     for (const auto &engineName : listOfEngines) {
         auto path = engineBasePath + "/" + engineName + "/" + sysfsName;
@@ -302,7 +302,7 @@ ze_result_t LinuxSchedulerImp::setTimesliceMode(zes_sched_timeslice_properties_t
 ze_result_t LinuxSchedulerImp::getProperties(zes_sched_properties_t &schedProperties) {
     schedProperties.onSubdevice = onSubdevice;
     schedProperties.subdeviceId = subdeviceId;
-    schedProperties.canControl = canControlScheduler();
+    schedProperties.canControl = true;
     schedProperties.engines = this->engineType;
     schedProperties.supportedModes = (1 << ZES_SCHED_MODE_TIMEOUT) | (1 << ZES_SCHED_MODE_TIMESLICE) | (1 << ZES_SCHED_MODE_EXCLUSIVE);
     return ZE_RESULT_SUCCESS;
@@ -350,10 +350,6 @@ ze_result_t LinuxSchedulerImp::setHeartbeatInterval(uint64_t heartbeat) {
                                       listOfEngines, engineType, heartbeat);
 }
 
-ze_bool_t LinuxSchedulerImp::canControlScheduler() {
-    return 1;
-}
-
 ze_result_t LinuxSchedulerImp::setComputeUnitDebugMode(ze_bool_t *pNeedReload) {
     *pNeedReload = false;
     return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
