@@ -17,9 +17,8 @@
 namespace L0 {
 namespace Sysman {
 
-class VfImp : public VfManagement, NEO::NonCopyableOrMovableClass {
+class VfImp : public VfManagement, NEO::NonCopyableAndNonMovableClass {
   public:
-    void init();
     ze_result_t vfGetCapabilities(zes_vf_exp2_capabilities_t *pCapability) override;
     ze_result_t vfGetMemoryUtilization(uint32_t *pCount, zes_vf_util_mem_exp2_t *pMemUtil) override;
     ze_result_t vfGetEngineUtilization(uint32_t *pCount, zes_vf_util_engine_exp2_t *pEngineUtil) override;
@@ -30,9 +29,6 @@ class VfImp : public VfManagement, NEO::NonCopyableOrMovableClass {
 
   protected:
     std::unique_ptr<OsVf> pOsVf;
-
-  private:
-    zes_vf_exp2_capabilities_t capability = {};
 };
 
 } // namespace Sysman
