@@ -202,6 +202,37 @@ ze_result_t SysmanProductHelperHw<gfxProduct>::getMemoryBandwidth(zes_mem_bandwi
     return result;
 }
 
+template <>
+ze_result_t SysmanProductHelperHw<gfxProduct>::getPowerEnergyCounter(zes_power_energy_counter_t *pEnergy, LinuxSysmanImp *pLinuxSysmanImp, zes_power_domain_t powerDomain, uint32_t subdeviceId) {
+
+    std::string telemDir = "";
+    std::string guid = "";
+    uint64_t telemOffset = 0;
+
+    if (!pLinuxSysmanImp->getTelemData(subdeviceId, telemDir, guid, telemOffset)) {
+        return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
+    }
+
+    std::map<std::string, uint64_t> keyOffsetMap;
+    if (!PlatformMonitoringTech::getKeyOffsetMap(this, guid, keyOffsetMap)) {
+        return ZE_RESULT_ERROR_UNKNOWN;
+    }
+
+    const std::string key("PACKAGE_ENERGY");
+    uint64_t energyCounter = 0;
+    constexpr uint64_t fixedPointToJoule = 1048576;
+    if (!PlatformMonitoringTech::readValue(keyOffsetMap, telemDir, key, telemOffset, energyCounter)) {
+        return ZE_RESULT_ERROR_NOT_AVAILABLE;
+    }
+
+    // PMT will return energy counter in Q20 format(fixed point representation) where first 20 bits(from LSB) represent decimal part
+    // and remaining integral part which is converted into joule by division with 1048576(2^20) and then converted into microjoules
+    pEnergy->energy = (energyCounter / fixedPointToJoule) * convertJouleToMicroJoule;
+    pEnergy->timestamp = SysmanDevice::getSysmanTimestamp();
+
+    return ZE_RESULT_SUCCESS;
+}
+
 template <>
 bool SysmanProductHelperHw<gfxProduct>::isEccConfigurationSupported() {
     return true;
@@ -212,6 +243,25 @@ bool SysmanProductHelperHw<gfxProduct>::isUpstreamPortConnected() {
     return true;
 }
 
+template <>
+bool SysmanProductHelperHw<gfxProduct>::isVfMemoryUtilizationSupported() {
+    return true;
+}
+
+template <>
+ze_result_t SysmanProductHelperHw<gfxProduct>::getVfLocalMemoryQuota(SysFsAccessInterface *pSysfsAccess, uint64_t &lMemQuota, const uint32_t &vfId) {
+
+    const std::string pathForLmemQuota = "/gt/lmem_quota";
+    std::string pathForDeviceMemQuota = "iov/vf" + std::to_string(vfId) + pathForLmemQuota;
+
+    auto result = pSysfsAccess->read(pathForDeviceMemQuota, lMemQuota);
+    if (result != ZE_RESULT_SUCCESS) {
+        NEO::printDebugString(NEO::debugManager.flags.PrintDebugMessages.get(), stderr, "Error@ %s(): Failed to read Local Memory Quota with error 0x%x \n", __FUNCTION__, result);
+        return result;
+    }
+    return ZE_RESULT_SUCCESS;
+}
+
 template class SysmanProductHelperHw<gfxProduct>;
 
 } // namespace Sysman
