@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Intel Corporation
+ * Copyright (C) 2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -9,16 +9,25 @@
 #include "shared/test/common/helpers/variable_backup.h"
 
 #include "level_zero/sysman/source/api/engine/linux/sysman_os_engine_imp.h"
-#include "level_zero/sysman/source/api/engine/sysman_engine_imp.h"
-#include "level_zero/sysman/source/shared/linux/zes_os_sysman_imp.h"
 #include "level_zero/sysman/test/unit_tests/sources/engine/linux/mock_engine_xe.h"
 #include "level_zero/sysman/test/unit_tests/sources/linux/mock_sysman_fixture.h"
 #include "level_zero/sysman/test/unit_tests/sources/shared/linux/kmd_interface/mock_sysman_kmd_interface_xe.h"
+#include "level_zero/sysman/test/unit_tests/sources/shared/linux/mock_pmu_interface.h"
 
 namespace L0 {
 namespace Sysman {
 namespace ult {
 
+static MapOfEngineInfo mockMapEngineInfo = {
+    {ZES_ENGINE_GROUP_ALL, {{0, 0}}},
+    {ZES_ENGINE_GROUP_COMPUTE_ALL, {{0, 0}}},
+    {ZES_ENGINE_GROUP_MEDIA_ALL, {{0, 0}}},
+    {ZES_ENGINE_GROUP_COPY_ALL, {{0, 0}}},
+    {ZES_ENGINE_GROUP_RENDER_ALL, {{0, 0}}},
+    {ZES_ENGINE_GROUP_RENDER_SINGLE, {{1, 0}}},
+    {ZES_ENGINE_GROUP_COPY_SINGLE, {{0, 0}}},
+    {ZES_ENGINE_GROUP_COMPUTE_SINGLE, {{1, 0}}}};
+
 class ZesEngineFixtureXe : public SysmanDeviceFixture {
   protected:
     L0::Sysman::SysmanDevice *device = nullptr;
@@ -44,72 +53,33 @@ class ZesEngineFixtureXe : public SysmanDeviceFixture {
         pLinuxSysmanImp->pSysmanKmdInterface->initFsAccessInterface(*pDrm);
 
         pPmuInterface = std::make_unique<MockPmuInterfaceImp>(pLinuxSysmanImp);
-        pPmuInterface->mockPmuFd = 10;
-        pPmuInterface->mockActiveTime = 987654321;
-        pPmuInterface->mockTimestamp = 87654321;
         pPmuInterface->pSysmanKmdInterface = pLinuxSysmanImp->pSysmanKmdInterface.get();
         pOriginalPmuInterface = pLinuxSysmanImp->pPmuInterface;
         pLinuxSysmanImp->pPmuInterface = pPmuInterface.get();
 
         pSysmanDeviceImp->pEngineHandleContext->handleList.clear();
-        pSysmanDeviceImp->getRootDeviceEnvironment().getMutableHardwareInfo()->capabilityTable.isIntegratedDevice = true;
-
-        getEngineHandles(0);
+        bool isIntegratedDevice = true;
+        pLinuxSysmanImp->pSysmanKmdInterface->setSysmanDeviceDirName(isIntegratedDevice);
     }
 
     void TearDown() override {
         pLinuxSysmanImp->pPmuInterface = pOriginalPmuInterface;
         SysmanDeviceFixture::TearDown();
     }
-
-    std::vector<zes_engine_handle_t> getEngineHandles(uint32_t count) {
-
-        VariableBackup<decltype(NEO::SysCalls::sysCallsPread)> mockPread(&NEO::SysCalls::sysCallsPread, [](int fd, void *buf, size_t count, off_t offset) -> ssize_t {
-            uint32_t mockReadVal = 23;
-            std::ostringstream oStream;
-            oStream << mockReadVal;
-            std::string value = oStream.str();
-            memcpy(buf, value.data(), count);
-            return count;
-        });
-
-        std::vector<zes_engine_handle_t> handles(count, nullptr);
-        EXPECT_EQ(zesDeviceEnumEngineGroups(device->toHandle(), &count, handles.data()), ZE_RESULT_SUCCESS);
-        return handles;
-    }
 };
 
-TEST_F(ZesEngineFixtureXe, GivenComponentCountZeroWhenCallingzesDeviceEnumEngineGroupsThenZeroCountIsReturnedAndVerifyCallSucceeds) {
+TEST_F(ZesEngineFixtureXe, GivenEngineImpInstanceForSingleComputeEngineAndGetPmuConfigsForSingleEnginesFailsWhenCallingIsEngineModuleSupportedThenFalseValueIsReturned) {
 
-    uint32_t count = 0;
-    EXPECT_EQ(ZE_RESULT_SUCCESS, zesDeviceEnumEngineGroups(device->toHandle(), &count, NULL));
-    EXPECT_EQ(count, 0u);
-
-    uint32_t testcount = count + 1;
-    EXPECT_EQ(ZE_RESULT_SUCCESS, zesDeviceEnumEngineGroups(device->toHandle(), &testcount, NULL));
-    EXPECT_EQ(testcount, 0u);
-
-    count = 0;
-    std::vector<zes_engine_handle_t> handles(count, nullptr);
-    EXPECT_EQ(zesDeviceEnumEngineGroups(device->toHandle(), &count, handles.data()), ZE_RESULT_SUCCESS);
-    EXPECT_EQ(count, 0u);
+    pPmuInterface->mockEventConfigReturnValue.push_back(-1);
+    auto pLinuxEngineImp = std::make_unique<L0::Sysman::LinuxEngineImp>(pOsSysman, mockMapEngineInfo, ZES_ENGINE_GROUP_COMPUTE_SINGLE, 0, 0, 0);
+    EXPECT_FALSE(pLinuxEngineImp->isEngineModuleSupported());
 }
 
-TEST_F(ZesEngineFixtureXe, GivenValidEngineHandleWhenCallingZesEngineGetActivityAndperfEventOpenFailsThenVerifyEngineGetActivityReturnsFailure) {
-
-    VariableBackup<decltype(NEO::SysCalls::sysCallsPread)> mockPread(&NEO::SysCalls::sysCallsPread, [](int fd, void *buf, size_t count, off_t offset) -> ssize_t {
-        uint32_t mockReadVal = 23;
-        std::ostringstream oStream;
-        oStream << mockReadVal;
-        std::string value = oStream.str();
-        memcpy(buf, value.data(), count);
-        return count;
-    });
-
-    pPmuInterface->mockPerfEventFailureReturnValue = -1;
-    EXPECT_EQ(-1, pPmuInterface->pmuInterfaceOpen(0, -1, 0));
+TEST_F(ZesEngineFixtureXe, GivenEngineImpInstanceForMediaGroupEngineAndSingleMediaEngineNotAvailableWhenCallingIsEngineModuleSupportedThenFalseValueIsReturned) {
+    auto pLinuxEngineImp = std::make_unique<L0::Sysman::LinuxEngineImp>(pOsSysman, mockMapEngineInfo, ZES_ENGINE_GROUP_MEDIA_ALL, 0, 0, 0);
+    EXPECT_FALSE(pLinuxEngineImp->isEngineModuleSupported());
 }
 
 } // namespace ult
 } // namespace Sysman
-} // namespace L0
+} // namespace L0
\ No newline at end of file
