@@ -5,6 +5,7 @@
  *
  */
 
+#include "level_zero/sysman/source/driver/sysman_os_driver.h"
 #include "level_zero/sysman/source/shared/linux/product_helper/sysman_product_helper_hw.h"
 #include "level_zero/sysman/test/unit_tests/sources/firmware/linux/mock_zes_sysman_firmware.h"
 
@@ -415,6 +416,61 @@ HWTEST2_F(ZesSysmanFirmwareFixture, GivenValidLateBindingFirmwareHandleWhenGetti
     }
 }
 
+using SysmanSurvivabilityDeviceTest = ::testing::Test;
+struct dirent mockSurvivabilityDevEntries[] = {
+    {0, 0, 0, 0, "0000:03:00.0"},
+    {0, 0, 0, 0, "0000:09:00.0"},
+};
+
+inline static int openMockReturnSuccess(const char *pathname, int flags) {
+    NEO::SysCalls::closeFuncCalled = 0;
+    return 0;
+}
+
+TEST_F(SysmanSurvivabilityDeviceTest, GivenSurvivabilityDeviceWhenFirmwareEnumerationApiIsCalledThenFirmwareHandlesAreReturned) {
+    const uint32_t numEntries = sizeof(mockSurvivabilityDevEntries) / sizeof(mockSurvivabilityDevEntries[0]);
+    VariableBackup<decltype(NEO::SysCalls::sysCallsOpendir)> mockOpendir(&NEO::SysCalls::sysCallsOpendir, [](const char *name) -> DIR * {
+        return reinterpret_cast<DIR *>(0xc001);
+    });
+
+    VariableBackup<decltype(NEO::SysCalls::sysCallsOpen)> openBackup{&NEO::SysCalls::sysCallsOpen, openMockReturnSuccess};
+    VariableBackup<decltype(NEO::SysCalls::sysCallsReaddir)> mockReaddir(
+        &NEO::SysCalls::sysCallsReaddir, [](DIR * dir) -> struct dirent * {
+            static uint32_t entryIndex = 0u;
+            if (entryIndex >= numEntries) {
+                entryIndex = 0;
+                return nullptr;
+            }
+            return &mockSurvivabilityDevEntries[entryIndex++];
+        });
+
+    VariableBackup<decltype(NEO::SysCalls::sysCallsClosedir)> mockClosedir(&NEO::SysCalls::sysCallsClosedir, [](DIR *dir) -> int {
+        return 0;
+    });
+
+    std::unique_ptr<OsDriver> pOsDriverInterface = OsDriver::create();
+    uint32_t driverCount = 0;
+    ze_result_t result;
+    auto sysmanDriverHandle = pOsDriverInterface->initSurvivabilityDevicesWithDriver(&result, &driverCount);
+    EXPECT_EQ(result, ZE_RESULT_SUCCESS);
+    EXPECT_TRUE(sysmanDriverHandle != nullptr);
+
+    SysmanDriverHandleImp *pSysmanDriverHandleImp = static_cast<SysmanDriverHandleImp *>(sysmanDriverHandle);
+    auto pSysmanDevice = pSysmanDriverHandleImp->sysmanDevices[0];
+    auto pSysmanDeviceImp = static_cast<L0::Sysman::SysmanDeviceImp *>(pSysmanDevice);
+    auto pOsSysman = pSysmanDeviceImp->pOsSysman;
+    auto pLinuxSysmanImp = static_cast<PublicLinuxSysmanImp *>(pOsSysman);
+    pLinuxSysmanImp->pFwUtilInterface = new MockFirmwareInterface();
+
+    uint32_t count = 0;
+    EXPECT_EQ(ZE_RESULT_SUCCESS, SysmanDevice::firmwareGet(pSysmanDevice->toHandle(), &count, nullptr));
+    EXPECT_EQ(count, mockFwHandlesCount);
+    delete pLinuxSysmanImp->pFwUtilInterface;
+    pLinuxSysmanImp->pFwUtilInterface = nullptr;
+    delete sysmanDriverHandle;
+    globalSysmanDriver = nullptr;
+}
+
 } // namespace ult
 } // namespace Sysman
 } // namespace L0
