@@ -10,7 +10,7 @@
 #include "shared/source/execution_environment/root_device_environment.h"
 #include "shared/source/os_interface/os_library.h"
 
-#include "level_zero/core/source/cmdlist/cmdlist.h"
+#include "level_zero/core/source/cmdlist/cmdlist_imp.h"
 #include "level_zero/core/source/device/device_imp.h"
 #include "level_zero/core/source/gfx_core_helpers/l0_gfx_core_helper.h"
 #include "level_zero/tools/source/metrics/metric.h"
@@ -116,6 +116,12 @@ bool OaMetricSourceImp::canDisable() {
     return !activationTracker->isAnyMetricGroupActivated();
 }
 
+void OaMetricSourceImp::initMetricScopes(MetricDeviceContext &metricDeviceContext) {
+    if (!metricDeviceContext.isComputeMetricScopesInitialized()) {
+        initComputeMetricScopes(metricDeviceContext);
+    }
+}
+
 MetricsLibrary &OaMetricSourceImp::getMetricsLibrary() {
     return *metricsLibrary;
 }
