@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -40,10 +40,4 @@ class MetricIpSamplingOsInterface : public MetricOsInterface {
     uint32_t unitReportSize = 64u;
 };
 
-class MetricOAOsInterface : public MetricOsInterface {
-  public:
-    ~MetricOAOsInterface() override = default;
-    static std::unique_ptr<MetricOAOsInterface> create(Device &device);
-};
-
 } // namespace L0
