@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2022 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -17,7 +17,7 @@ namespace L0 {
 
 class OsDiagnostics;
 
-class DiagnosticsImp : public Diagnostics, NEO::NonCopyableOrMovableClass {
+class DiagnosticsImp : public Diagnostics, NEO::NonCopyableAndNonMovableClass {
   public:
     ze_result_t diagnosticsGetProperties(zes_diag_properties_t *pProperties) override;
     ze_result_t diagnosticsGetTests(uint32_t *pCount, zes_diag_test_t *pTests) override;
