@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -20,8 +20,9 @@ using namespace std;
 class OsEngine {
   public:
     virtual ze_result_t getActivity(zes_engine_stats_t *pStats) = 0;
+    virtual ze_result_t getActivityExt(uint32_t *pCount, zes_engine_stats_t *pStats) = 0;
     virtual ze_result_t getProperties(zes_engine_properties_t &properties) = 0;
-    virtual bool isEngineModuleSupported() = 0;
+    virtual ze_result_t isEngineModuleSupported() = 0;
     static std::unique_ptr<OsEngine> create(OsSysman *pOsSysman, zes_engine_group_t engineType, uint32_t engineInstance, uint32_t subDeviceId, ze_bool_t onSubdevice);
     static ze_result_t getNumEngineTypeAndInstances(std::set<std::pair<zes_engine_group_t, EngineInstanceSubDeviceId>> &engineGroupInstance, OsSysman *pOsSysman);
     virtual ~OsEngine() = default;
