@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2021 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -11,9 +11,11 @@
 #include "events.h"
 #include "os_events.h"
 
+#include <mutex>
+
 namespace L0 {
 
-class EventsImp : public Events, NEO::NonCopyableOrMovableClass {
+class EventsImp : public Events, NEO::NonCopyableAndNonMovableClass {
   public:
     void init() override;
     ze_result_t eventRegister(zes_event_type_flags_t events) override;
@@ -26,6 +28,8 @@ class EventsImp : public Events, NEO::NonCopyableOrMovableClass {
 
   private:
     OsSysman *pOsSysman = nullptr;
+    std::once_flag initEventsOnce;
+    void initEvents();
 };
 
 } // namespace L0
