@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -27,6 +27,10 @@ ze_result_t FirmwareImp::firmwareFlash(void *pImage, uint32_t size) {
     return pOsFirmware->osFirmwareFlash(pImage, size);
 }
 
+ze_result_t FirmwareImp::firmwareGetFlashProgress(uint32_t *pCompletionPercent) {
+    return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
+}
+
 FirmwareImp::FirmwareImp(OsSysman *pOsSysman, const std::string &initalizedFwType) {
     pOsFirmware = OsFirmware::create(pOsSysman, initalizedFwType);
     fwType = initalizedFwType;
