@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2021 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -17,10 +17,11 @@ namespace L0 {
 
 class OsFirmware;
 
-class FirmwareImp : public Firmware, NEO::NonCopyableOrMovableClass {
+class FirmwareImp : public Firmware, NEO::NonCopyableAndNonMovableClass {
   public:
     ze_result_t firmwareGetProperties(zes_firmware_properties_t *pProperties) override;
     ze_result_t firmwareFlash(void *pImage, uint32_t size) override;
+    ze_result_t firmwareGetFlashProgress(uint32_t *pCompletionPercent) override;
     FirmwareImp() = default;
     FirmwareImp(OsSysman *pOsSysman, const std::string &fwType);
     ~FirmwareImp() override;
