@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,13 +8,13 @@
 #pragma once
 #include "shared/source/helpers/non_copyable_or_moveable.h"
 
-#include "sysman/frequency/frequency_imp.h"
-#include "sysman/frequency/os_frequency.h"
-#include "sysman/linux/fs_access.h"
+#include "level_zero/tools/source/sysman/frequency/frequency_imp.h"
+#include "level_zero/tools/source/sysman/frequency/os_frequency.h"
+#include "level_zero/tools/source/sysman/linux/fs_access.h"
 
 namespace L0 {
 
-class LinuxFrequencyImp : public OsFrequency, NEO::NonCopyableOrMovableClass {
+class LinuxFrequencyImp : public OsFrequency, NEO::NonCopyableAndNonMovableClass {
   public:
     ze_result_t osFrequencyGetProperties(zes_freq_properties_t &properties) override;
     double osFrequencyGetStepSize() override;
