@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,7 +7,9 @@
 
 #include "level_zero/tools/source/sysman/frequency/windows/os_frequency_imp.h"
 
+#include "level_zero/tools/source/sysman/frequency/frequency.h"
 #include "level_zero/tools/source/sysman/sysman_const.h"
+#include "level_zero/tools/source/sysman/windows/kmd_sys_manager.h"
 
 namespace L0 {
 
@@ -621,7 +623,7 @@ OsFrequency *OsFrequency::create(OsSysman *pOsSysman, ze_bool_t onSubdevice, uin
     return static_cast<OsFrequency *>(pWddmFrequencyImp);
 }
 
-uint16_t OsFrequency::getNumberOfFreqDoainsSupported(OsSysman *pOsSysman) {
+std::vector<zes_freq_domain_t> OsFrequency::getNumberOfFreqDomainsSupported(OsSysman *pOsSysman) {
     WddmSysmanImp *pWddmSysmanImp = static_cast<WddmSysmanImp *>(pOsSysman);
     KmdSysManager *pKmdSysManager = &pWddmSysmanImp->getKmdSysManager();
 
@@ -630,18 +632,22 @@ uint16_t OsFrequency::getNumberOfFreqDoainsSupported(OsSysman *pOsSysman) {
 
     request.commandId = KmdSysman::Command::Get;
     request.componentId = KmdSysman::Component::FrequencyComponent;
-    request.requestId = KmdSysman::Requests::Frequency::NumFrequencyDomains;
+    request.requestId = KmdSysman::Requests::Frequency::SupportedFreqDomains;
 
     ze_result_t status = pKmdSysManager->requestSingle(request, response);
-
+    std::vector<zes_freq_domain_t> freqDomains;
     if (status != ZE_RESULT_SUCCESS) {
-        return 0;
+        return freqDomains;
     }
 
-    uint32_t maxNumEnginesSupported = 0;
-    memcpy_s(&maxNumEnginesSupported, sizeof(uint32_t), response.dataBuffer, sizeof(uint32_t));
-
-    return static_cast<uint16_t>(maxNumEnginesSupported);
+    uint32_t supportedFreqDomains = 0;
+    memcpy_s(&supportedFreqDomains, sizeof(uint32_t), response.dataBuffer, sizeof(uint32_t));
+    for (uint16_t i = ZES_FREQ_DOMAIN_GPU; i <= ZES_FREQ_DOMAIN_MEDIA; i++) {
+        if (supportedFreqDomains & 1 << i) {
+            freqDomains.push_back(static_cast<zes_freq_domain_t>(i));
+        }
+    }
+    return freqDomains;
 }
 
 } // namespace L0
