@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,12 +7,7 @@
 
 #pragma once
 #include "shared/source/helpers/non_copyable_or_moveable.h"
-#include "shared/source/memory_manager/memory_manager.h"
 
-#include "level_zero/core/source/device/device.h"
-#include <level_zero/zet_api.h>
-
-#include "os_pci.h"
 #include "pci.h"
 
 #include <mutex>
@@ -20,7 +15,9 @@
 
 namespace L0 {
 
-class PciImp : public Pci, NEO::NonCopyableOrMovableClass {
+class OsPci;
+struct OsSysman;
+class PciImp : public Pci, NEO::NonCopyableAndNonMovableClass {
   public:
     void init() override;
     ze_result_t pciStaticProperties(zes_pci_properties_t *pProperties) override;
@@ -28,7 +25,6 @@ class PciImp : public Pci, NEO::NonCopyableOrMovableClass {
     ze_result_t pciGetState(zes_pci_state_t *pState) override;
     void pciGetStaticFields();
 
-    PciImp() = default;
     PciImp(OsSysman *pOsSysman) : pOsSysman(pOsSysman){};
     ~PciImp() override;
     OsPci *pOsPci = nullptr;
