@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2021 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -15,7 +15,7 @@
 
 namespace L0 {
 
-class StandbyImp : public Standby, NEO::NonCopyableOrMovableClass {
+class StandbyImp : public Standby, NEO::NonCopyableAndNonMovableClass {
   public:
     ze_result_t standbyGetProperties(zes_standby_properties_t *pProperties) override;
     ze_result_t standbyGetMode(zes_standby_promo_mode_t *pMode) override;
@@ -24,7 +24,7 @@ class StandbyImp : public Standby, NEO::NonCopyableOrMovableClass {
     StandbyImp() = default;
     StandbyImp(OsSysman *pOsSysman, ze_device_handle_t handle);
     ~StandbyImp() override;
-    OsStandby *pOsStandby = nullptr;
+    std::unique_ptr<OsStandby> pOsStandby = nullptr;
 
     void init();
 
