@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -20,6 +20,7 @@
 #include "level_zero/tools/source/sysman/global_operations/global_operations_imp.h"
 #include "level_zero/tools/source/sysman/pci/pci_imp.h"
 #include "level_zero/tools/source/sysman/sysman.h"
+#include "level_zero/tools/source/sysman/vf_management/vf_management.h"
 
 #include <vector>
 
@@ -46,6 +47,7 @@ SysmanDeviceImp::SysmanDeviceImp(ze_device_handle_t hDevice) {
     pDiagnosticsHandleContext = new DiagnosticsHandleContext(pOsSysman);
     pPerformanceHandleContext = new PerformanceHandleContext(pOsSysman);
     pEcc = new EccImp(pOsSysman);
+    pVfManagementHandleContext = new VfManagementHandleContext(pOsSysman);
 }
 
 SysmanDeviceImp::~SysmanDeviceImp() {
@@ -66,6 +68,7 @@ SysmanDeviceImp::~SysmanDeviceImp() {
     freeResource(pFrequencyHandleContext);
     freeResource(pPowerHandleContext);
     freeResource(pEcc);
+    freeResource(pVfManagementHandleContext);
     freeResource(pOsSysman);
 }
 
@@ -106,6 +109,12 @@ ze_result_t SysmanDeviceImp::init() {
     updateSubDeviceHandlesLocally();
 
     auto result = pOsSysman->init();
+    if (result == ZE_RESULT_SUCCESS) {
+        ze_bool_t driverModelSupported = pOsSysman->isDriverModelSupported();
+        if (!driverModelSupported) {
+            return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
+        }
+    }
     return result;
 }
 
@@ -137,6 +146,10 @@ bool SysmanDeviceImp::deviceEventListen(zes_event_type_flags_t &pEvent, uint64_t
     return pEvents->eventListen(pEvent, timeout);
 }
 
+ze_result_t SysmanDeviceImp::deviceResetExt(zes_reset_properties_t *pProperties) {
+    return pGlobalOperations->resetExt(pProperties);
+}
+
 ze_result_t SysmanDeviceImp::deviceGetState(zes_device_state_t *pState) {
     return pGlobalOperations->deviceGetState(pState);
 }
@@ -226,4 +239,8 @@ ze_result_t SysmanDeviceImp::deviceSetEccState(const zes_device_ecc_desc_t *newS
     return pEcc->setEccState(newState, pState);
 }
 
+ze_result_t SysmanDeviceImp::deviceEnumEnabledVF(uint32_t *pCount, zes_vf_handle_t *phVFhandle) {
+    return pVfManagementHandleContext->vfManagementGet(pCount, phVFhandle);
+}
+
 } // namespace L0
