@@ -1,11 +1,13 @@
 /*
- * Copyright (C) 2020-2021 Intel Corporation
+ * Copyright (C) 2020-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
-#include "sysman/temperature/windows/os_temperature_imp.h"
+#include "level_zero/tools/source/sysman/temperature/windows/os_temperature_imp.h"
+
+#include "level_zero/tools/source/sysman/windows/kmd_sys_manager.h"
 
 namespace L0 {
 
@@ -30,7 +32,7 @@ ze_result_t WddmTemperatureImp::getProperties(zes_temp_properties_t *pProperties
         request.paramInfo = KmdSysman::TemperatureDomainsType::TemperatureDomainDGPU;
         break;
     case ZES_TEMP_SENSORS_MEMORY:
-        request.paramInfo = KmdSysman::TemperatureDomainsType::TemperatureDomainPackage;
+        request.paramInfo = KmdSysman::TemperatureDomainsType::TemperatureDomainHBM;
         break;
     default:
         return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
@@ -113,10 +115,37 @@ ze_result_t WddmTemperatureImp::getSensorTemperature(double *pTemperature) {
     return status;
 }
 
+uint32_t WddmTemperatureImp::getNumTempDomainsSupported() {
+    ze_result_t status = ZE_RESULT_SUCCESS;
+    KmdSysman::RequestProperty request;
+    KmdSysman::ResponseProperty response = {};
+    uint32_t value = 0;
+
+    request.paramInfo = static_cast<uint32_t>(type);
+    request.commandId = KmdSysman::Command::Get;
+    request.componentId = KmdSysman::Component::TemperatureComponent;
+    request.requestId = KmdSysman::Requests::Temperature::NumTemperatureDomains;
+
+    status = pKmdSysManager->requestSingle(request, response);
+
+    if (status == ZE_RESULT_SUCCESS) {
+        if (response.returnCode == KmdSysman::KmdSysmanSuccess) {
+            memcpy_s(&value, sizeof(uint32_t), response.dataBuffer, sizeof(uint32_t));
+        }
+    }
+
+    return value;
+}
+
 bool WddmTemperatureImp::isTempModuleSupported() {
     if ((type == ZES_TEMP_SENSORS_GLOBAL_MIN) || (type == ZES_TEMP_SENSORS_GPU_MIN)) {
         return false;
     }
+
+    if (getNumTempDomainsSupported() == 0) {
+        return false;
+    }
+
     KmdSysman::RequestProperty request;
     KmdSysman::ResponseProperty response;
 
@@ -142,5 +171,4 @@ std::unique_ptr<OsTemperature> OsTemperature::create(OsSysman *pOsSysman, ze_boo
     pWddmTemperatureImp->setSensorType(sensorType);
     return std::move(pWddmTemperatureImp);
 }
-
-} // namespace L0
\ No newline at end of file
+} // namespace L0
