@@ -16,7 +16,7 @@
 
 namespace L0 {
 
-class VfImp : public VfManagement, NEO::NonCopyableOrMovableClass {
+class VfImp : public VfManagement, NEO::NonCopyableAndNonMovableClass {
   public:
     void init();
     ze_result_t vfGetCapabilities(zes_vf_exp2_capabilities_t *pCapability) override;
