@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -10,7 +10,6 @@
 #include "level_zero/tools/test/black_box_tests/zello_metrics/zello_metrics.h"
 
 #include <cstring>
-#include <getopt.h>
 #include <iomanip>
 #include <mutex>
 #include <thread>
@@ -25,12 +24,14 @@ void createL0() {
 
 ze_driver_handle_t getDriver() {
     uint32_t driverCount = 0;
-    ze_driver_handle_t driverHandle = {};
+    std::vector<ze_driver_handle_t> driverHandles = {};
     // Obtain driver.
     VALIDATECALL(zeDriverGet(&driverCount, nullptr));
     EXPECT(driverCount > 0);
-    VALIDATECALL(zeDriverGet(&driverCount, &driverHandle));
-    return driverHandle;
+    driverHandles.resize(driverCount);
+
+    VALIDATECALL(zeDriverGet(&driverCount, driverHandles.data()));
+    return driverHandles[0];
 }
 
 ze_context_handle_t createContext(ze_driver_handle_t &driverHandle) {
@@ -256,7 +257,7 @@ void sleep(uint32_t milliseconds) {
 }
 
 zet_metric_group_handle_t findMetricGroup(const char *groupName,
-                                          const zet_metric_group_sampling_type_flag_t samplingType,
+                                          const zet_metric_group_sampling_type_flags_t samplingType,
                                           ze_device_handle_t deviceHandle) {
 
     uint32_t metricGroupCount = 0;
@@ -446,6 +447,38 @@ void obtainCalculatedMetrics(zet_metric_group_handle_t metricGroup, uint8_t *raw
     }
 }
 
+inline bool isParamEnabled(int argc, char *argv[], const char *shortName, const char *longName, int *optind) {
+    if (argc < 2) {
+        return false;
+    }
+    int index = 1;
+    char **arg = &argv[1];
+    char **argE = &argv[argc];
+
+    for (; arg != argE; ++arg) {
+        if ((0 == strcmp(*arg, shortName)) || (0 == strcmp(*arg, longName))) {
+            *optind = index;
+            return true;
+        }
+        index++;
+    }
+
+    return false;
+}
+
+inline std::string copyArg(int argc, char *argv[], int optind) {
+    std::string valToReturn;
+    char *optarg = nullptr;
+    optind = optind + 1;
+    if (optind < argc) {
+        optarg = argv[optind];
+    }
+    if (optarg != nullptr) {
+        valToReturn = optarg;
+    }
+    return valToReturn;
+}
+
 void TestSettings::readMetricNames(char *optArg) {
     std::string args = optArg;
     std::string delim(",");
@@ -466,24 +499,18 @@ void TestSettings::readMetricNames(char *optArg) {
     }
 }
 
+bool isEnvVariableSet(const char *name) {
+    const char *env = getenv(name);
+    if ((nullptr == env) || (0 == strcmp("0", env)))
+        return false;
+    return (0 == strcmp("1", env));
+}
+
 ////////////////
 // Test Settings
 ////////////////
 void TestSettings::parseArguments(int argc, char *argv[]) {
-    int opt;
-
-    struct option longOpts[] = {
-        {"help", no_argument, nullptr, 'h'},
-        {"test", required_argument, nullptr, 't'},
-        {"device", required_argument, nullptr, 'd'},
-        {"subdevice", required_argument, nullptr, 's'},
-        {"verboseLevel", required_argument, nullptr, 'v'},
-        {"metricGroupName", required_argument, nullptr, 'M'},
-        {"metricName", required_argument, nullptr, 'm'},
-        {"eventNReports", required_argument, nullptr, 'e'},
-        {"showSystemInfo", no_argument, nullptr, 'y'},
-        {0, 0, 0, 0},
-    };
+    int optind = 0;
 
     auto printUsage = []() {
         std::cout << "\n set Environment variable ZET_ENABLE_METRICS=1"
@@ -509,50 +536,41 @@ void TestSettings::parseArguments(int argc, char *argv[]) {
         return;
     }
 
-    while ((opt = getopt_long(argc, argv, "ht:d:s:v:M:m:e:y", longOpts, nullptr)) != -1) {
-        switch (opt) {
-        case 't':
-            testName = optarg;
-            break;
+    if (isParamEnabled(argc, argv, "-h", "--help", &optind)) {
+        printUsage();
+        exit(0);
+    }
 
-        case 'd':
-            deviceId.set(std::atoi(optarg));
-            break;
+    if (isParamEnabled(argc, argv, "-t", "--test", &optind)) {
+        testName = copyArg(argc, argv, optind);
+    }
 
-        case 's':
-            subDeviceId.set(std::atoi(optarg));
-            break;
+    if (isParamEnabled(argc, argv, "-d", "--device", &optind)) {
+        deviceId.set(std::atoi(copyArg(argc, argv, optind).c_str()));
+    }
 
-        case 'v':
-            verboseLevel.set(std::atoi(optarg));
-            break;
+    if (isParamEnabled(argc, argv, "-s", "--subdevice", &optind)) {
+        subDeviceId.set(std::atoi(copyArg(argc, argv, optind).c_str()));
+    }
 
-        case 'M':
-            metricGroupName.set(optarg);
-            break;
+    if (isParamEnabled(argc, argv, "-v", "--verboseLevel", &optind)) {
+        verboseLevel.set(std::atoi(copyArg(argc, argv, optind).c_str()));
+    }
 
-        case 'm':
-            readMetricNames(optarg);
-            break;
+    if (isParamEnabled(argc, argv, "-M", "--metricGroupName", &optind)) {
+        metricGroupName.set(copyArg(argc, argv, optind));
+    }
 
-        case 'e':
-            eventNReportCount.set(std::atoi(optarg));
-            break;
+    if (isParamEnabled(argc, argv, "-m", "--metricName", &optind)) {
+        readMetricNames(&copyArg(argc, argv, optind)[0]);
+    }
 
-        case 'y':
-            showSystemInfo.set(true);
-            break;
+    if (isParamEnabled(argc, argv, "-e", "--eventNReports", &optind)) {
+        eventNReportCount.set(std::atoi(copyArg(argc, argv, optind).c_str()));
+    }
 
-        case 'h':
-            printUsage();
-            break;
-
-        default:
-            // Do not run tests in case of invalid option
-            testName.clear();
-            printUsage();
-            return;
-        }
+    if (isParamEnabled(argc, argv, "-y", "--showSystemInfo", &optind)) {
+        showSystemInfo.set(true);
     }
 }
 
