@@ -5,6 +5,7 @@
  *
  */
 
+#include "level_zero/include/level_zero/zes_intel_gpu_sysman.h"
 #include <level_zero/zes_api.h>
 
 #include <algorithm>
@@ -567,10 +568,61 @@ void testSysmanEcc(ze_device_handle_t &device) {
     }
 }
 
+void testSysmanSurvivability(ze_device_handle_t &device) {
+    zes_device_properties_t properties = {ZES_STRUCTURE_TYPE_DEVICE_PROPERTIES};
+    ze_result_t result = zesDeviceGetProperties(device, &properties);
+    if (result == ZE_RESULT_ERROR_SURVIVABILITY_MODE_DETECTED) {
+        std::cout << "Device is in survivability mode!!, Only firmware update supported" << std::endl;
+    }
+    if ((result == ZE_RESULT_SUCCESS) && verbose) {
+        std::cout << "Device is in Normal operations Mode. Device properties retrieved successfully. " << std::endl;
+        std::cout << "Device Name = " << properties.core.name << std::endl;
+        std::cout << "properties.vendorName = " << properties.vendorName << std::endl;
+        std::cout << "properties.core.vendorId = " << properties.core.vendorId << std::endl;
+        std::cout << "properties.core.deviceId = " << properties.core.deviceId << std::endl;
+        std::cout << "properties.core.uuid = " << std::endl;
+        for (uint32_t i = 0; i < ZE_MAX_UUID_SIZE; i++) {
+            std::cout << +properties.core.uuid.id[i] << " ";
+        }
+        std::cout << std::endl;
+        return;
+    }
+    uint32_t count = 0;
+    result = zesDeviceEnumFirmwares(device, &count, nullptr);
+    if (result != ZE_RESULT_SUCCESS) {
+        std::cout << "zesDeviceEnumFirmwares() Failed!!" << std::endl;
+        return;
+    }
+    if (count == 0) {
+        std::cout << "Could not retrieve Firmware domains" << std::endl;
+        return;
+    } else {
+        std::cout << "Found " << count << " firmware handles.." << std::endl;
+    }
+
+    std::vector<zes_firmware_handle_t> handles(count, nullptr);
+    VALIDATECALL(zesDeviceEnumFirmwares(device, &count, handles.data()));
+
+    for (auto handle : handles) {
+        zes_firmware_properties_t fwProperties = {};
+
+        VALIDATECALL(zesFirmwareGetProperties(handle, &fwProperties));
+        if (verbose) {
+            std::cout << "firmware name = " << fwProperties.name << std::endl;
+            std::cout << "On Subdevice = " << static_cast<uint32_t>(fwProperties.onSubdevice) << std::endl;
+            std::cout << "Subdevice Id = " << fwProperties.subdeviceId << std::endl;
+            std::cout << "firmware version = " << fwProperties.version << std::endl;
+        }
+    }
+}
+
 void testSysmanPci(ze_device_handle_t &device) {
     std::cout << std::endl
               << " ----  PCI tests ---- " << std::endl;
     zes_pci_properties_t properties = {};
+    zes_intel_pci_link_speed_downgrade_exp_properties_t extProps = {};
+    extProps.stype = ZES_INTEL_PCI_LINK_SPEED_DOWNGRADE_EXP_PROPERTIES;
+    properties.pNext = &extProps;
     VALIDATECALL(zesDevicePciGetProperties(device, &properties));
     if (verbose) {
         std::cout << "properties.address.domain = " << std::hex << properties.address.domain << std::endl;
@@ -583,6 +635,8 @@ void testSysmanPci(ze_device_handle_t &device) {
         std::cout << "properties.haveBandwidthCounters = " << static_cast<uint32_t>(properties.haveBandwidthCounters) << std::endl;
         std::cout << "properties.havePacketCounters = " << static_cast<uint32_t>(properties.havePacketCounters) << std::endl;
         std::cout << "properties.haveReplayCounters = " << static_cast<uint32_t>(properties.haveReplayCounters) << std::endl;
+        std::cout << "properties.pciLinkSpeedUpdateCapable = " << static_cast<bool>(extProps.pciLinkSpeedUpdateCapable) << std::endl;
+        std::cout << "properties.maxPciGenSupported = " << static_cast<int32_t>(extProps.maxPciGenSupported) << std::endl;
     }
 
     uint32_t count = 0;
@@ -630,6 +684,18 @@ void testSysmanPci(ze_device_handle_t &device) {
             std::cout << "pci_bar_properties_1_2_t.resizableBarEnabled = " << static_cast<uint32_t>(pciBarExtProps[i].resizableBarEnabled) << std::endl;
         }
     }
+
+    zes_pci_state_t pciState = {};
+    zes_intel_pci_link_speed_downgrade_exp_state_t extState = {};
+    extState.stype = ZES_INTEL_PCI_LINK_SPEED_DOWNGRADE_EXP_STATE;
+    pciState.pNext = &extState;
+    VALIDATECALL(zesDevicePciGetState(device, &pciState));
+    if (verbose) {
+        std::cout << "pciState.speed.gen = " << std::dec << pciState.speed.gen << std::endl;
+        std::cout << "pciState.speed.width = " << std::dec << pciState.speed.width << std::endl;
+        std::cout << "pciState.speed.maxBandWidth = " << std::dec << pciState.speed.maxBandwidth << std::endl;
+        std::cout << "pciState.pciLinkSpeedDowngradeStatus = " << static_cast<bool>(extState.pciLinkSpeedDowngradeStatus) << std::endl;
+    }
 }
 
 void testSysmanFrequency(ze_device_handle_t &device) {
@@ -1767,6 +1833,11 @@ int main(int argc, char *argv[]) {
             testSysmanPci(device);
         });
     }
+    if (isParamEnabled(argc, argv, "-z", "--survive", &optind)) {
+        std::for_each(devices.begin(), devices.end(), [&](auto device) {
+            testSysmanSurvivability(device);
+        });
+    }
     if (isParamEnabled(argc, argv, "-P", "--performance", &optind)) {
         deviceIndex = 0;
         optind = optind + 1;
