@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -14,13 +14,13 @@
 #include <level_zero/zet_api.h>
 
 namespace L0 {
-extern _ze_driver_handle_t *GlobalDriverHandle;
+extern std::vector<_ze_driver_handle_t *> *globalDriverHandles;
 
 namespace ult {
 
-void MetricIpSamplingFixture::SetUp() {
+void MetricIpSamplingMultiDevFixture::SetUp() {
 
-    DebugManager.flags.EnableImplicitScaling.set(1);
+    debugManager.flags.EnableImplicitScaling.set(1);
 
     MultiDeviceFixture::numRootDevices = 1;
     MultiDeviceFixture::numSubDevices = 2;
@@ -48,14 +48,15 @@ void MetricIpSamplingFixture::SetUp() {
         auto &metricOaSource = device->getMetricDeviceContext().getMetricSource<OaMetricSourceImp>();
         metricOaSource.setInitializationState(ZE_RESULT_ERROR_UNSUPPORTED_FEATURE);
     }
-    GlobalDriverHandle = static_cast<_ze_driver_handle_t *>(driverHandle.get());
+    globalDriverHandles->push_back(driverHandle.get());
 }
 
-void MetricIpSamplingFixture::TearDown() {
+void MetricIpSamplingMultiDevFixture::TearDown() {
     MultiDeviceFixture::tearDown();
+    globalDriverHandles->clear();
 }
 
-void MetricIpSamplingTimestampFixture::SetUp() {
+void MetricIpSamplingFixture::SetUp() {
     DeviceFixture::setUp();
     auto mockMetricIpSamplingOsInterface = new MockMetricIpSamplingOsInterface();
     osInterfaceVector.push_back(mockMetricIpSamplingOsInterface);
@@ -67,11 +68,12 @@ void MetricIpSamplingTimestampFixture::SetUp() {
     auto &metricOaSource = device->getMetricDeviceContext().getMetricSource<OaMetricSourceImp>();
     metricOaSource.setInitializationState(ZE_RESULT_ERROR_UNSUPPORTED_FEATURE);
 
-    GlobalDriverHandle = static_cast<_ze_driver_handle_t *>(driverHandle.get());
+    globalDriverHandles->push_back(driverHandle.get());
 }
 
-void MetricIpSamplingTimestampFixture::TearDown() {
+void MetricIpSamplingFixture::TearDown() {
     DeviceFixture::tearDown();
+    globalDriverHandles->clear();
 }
 
 } // namespace ult
