@@ -7,13 +7,11 @@
 
 #include "shared/source/os_interface/driver_info.h"
 
+#include "level_zero/tools/source/sysman/sysman_imp.h"
 #include "level_zero/tools/test/unit_tests/sources/sysman/ecc/windows/mock_ecc.h"
 
 extern bool sysmanUltsEnable;
 
-using ::testing::Matcher;
-using ::testing::NiceMock;
-
 namespace L0 {
 namespace ult {
 
@@ -32,7 +30,7 @@ class ZesEccFixture : public SysmanDeviceFixture {
         }
         SysmanDeviceFixture::SetUp();
         pFwUtilInterfaceOld = pWddmSysmanImp->pFwUtilInterface;
-        pMockFwInterface = std::make_unique<NiceMock<Mock<EccFwInterface>>>();
+        pMockFwInterface = std::make_unique<Mock<EccFwInterface>>();
         pWddmSysmanImp->pFwUtilInterface = pMockFwInterface.get();
 
         pEccImp = static_cast<L0::EccImp *>(pSysmanDeviceImp->pEcc);
