@@ -7,6 +7,7 @@
 
 #include "level_zero/tools/source/sysman/frequency/windows/os_frequency_imp.h"
 #include "level_zero/tools/source/sysman/sysman_const.h"
+#include "level_zero/tools/source/sysman/sysman_imp.h"
 #include "level_zero/tools/test/unit_tests/sources/sysman/frequency/windows/mock_frequency.h"
 #include "level_zero/tools/test/unit_tests/sources/sysman/windows/mock_sysman_fixture.h"
 
@@ -69,7 +70,7 @@ class SysmanDeviceFrequencyFixture : public SysmanDeviceFixture {
         return static_cast<double>(actualClock);
     }
 
-    std::vector<zes_freq_handle_t> get_frequency_handles(uint32_t count) {
+    std::vector<zes_freq_handle_t> getFrequencyHandles(uint32_t count) {
         std::vector<zes_freq_handle_t> handles(count, nullptr);
         EXPECT_EQ(zesDeviceEnumFrequencyDomains(device->toHandle(), &count, handles.data()), ZE_RESULT_SUCCESS);
         return handles;
@@ -104,7 +105,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenComponentCountZeroWhenEnumeratingFrequ
     pKmdSysManager->mockRequestSingleResult = ZE_RESULT_ERROR_UNKNOWN;
     uint32_t count = 0;
     EXPECT_EQ(zesDeviceEnumFrequencyDomains(device->toHandle(), &count, nullptr), ZE_RESULT_SUCCESS);
-    EXPECT_EQ(count, 0);
+    EXPECT_EQ(count, 0u);
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenComponentCountZeroWhenEnumeratingFrequencyDomainsThenValidPowerHandlesIsReturned) {
@@ -120,7 +121,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenComponentCountZeroWhenEnumeratingFrequ
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencyGetPropertiesThenSuccessIsReturned) {
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     uint32_t domainIndex = 0;
     for (auto handle : handles) {
         EXPECT_NE(handle, nullptr);
@@ -145,7 +146,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesAllowSetCallsToFalseFrequencyGetPropertiesThenSuccessIsReturned) {
     pKmdSysManager->allowSetCalls = false;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     uint32_t domainIndex = 0;
     for (auto handle : handles) {
         EXPECT_NE(handle, nullptr);
@@ -172,7 +173,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhileGettingFreque
     pKmdSysManager->mockRequestMultiple = true;
     pKmdSysManager->requestMultipleSizeDiff = false;
     pKmdSysManager->mockRequestMultipleResult = ZE_RESULT_ERROR_INVALID_SIZE;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         zes_freq_properties_t properties;
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyGetProperties(handle, &properties));
@@ -185,7 +186,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhileGettingFreque
     pKmdSysManager->mockRequestMultiple = true;
     pKmdSysManager->requestMultipleSizeDiff = true;
     pKmdSysManager->mockRequestMultipleResult = ZE_RESULT_SUCCESS;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         zes_freq_properties_t properties;
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyGetProperties(handle, &properties));
@@ -195,7 +196,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhileGettingFreque
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAndZeroCountWhenCallingzesFrequencyGetAvailableClocksThenCallSucceeds) {
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     uint32_t domainIndex = 0;
 
     for (auto handle : handles) {
@@ -206,7 +207,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAndZeroCountWhenCa
             EXPECT_EQ(numClocks, count);
         } else if (domainIndex == ZES_FREQ_DOMAIN_MEMORY) {
             EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyGetAvailableClocks(handle, &count, nullptr));
-            EXPECT_EQ(1, count);
+            EXPECT_EQ(1u, count);
         } else if (domainIndex == ZES_FREQ_DOMAIN_MEDIA) {
             EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyGetAvailableClocks(handle, &count, nullptr));
             EXPECT_EQ(numClocks, count);
@@ -217,7 +218,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAndZeroCountWhenCa
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAndCorrectCountWhenCallingzesFrequencyGetAvailableClocksThenCallSucceeds) {
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     uint32_t domainIndex = 0;
 
     for (auto handle : handles) {
@@ -240,7 +241,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAndCorrectCountWhe
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencyGetRangeThenVerifyzesFrequencyGetRangeTestCallSucceeds) {
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     uint32_t domainIndex = 0;
 
     for (auto handle : handles) {
@@ -262,7 +263,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingFrequencyGetRangeAndSetRangeThenUnsupportedErrorIsReturnedForMemoryDomain) {
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     uint32_t domainIndex = 0;
     for (auto handle : handles) {
         zes_freq_range_t limits;
@@ -277,7 +278,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingFrequen
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencySetRangeThenVerifyzesFrequencySetRangeTest1CallSucceeds) {
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     uint32_t domainIndex = 0;
 
     for (auto handle : handles) {
@@ -316,7 +317,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencySetRangeThenVerifyzesFrequencySetRangeTest2CallSucceeds) {
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     uint32_t domainIndex = 0;
 
     for (auto handle : handles) {
@@ -356,7 +357,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencyGetStateThenVerifyCallSucceeds) {
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     uint32_t domainIndex = 0;
 
     for (auto handle : handles) {
@@ -393,7 +394,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhileGettingFrequencyStateAndRequestMultipleFailsThenFailureIsReturned) {
     pKmdSysManager->mockRequestMultiple = true;
     pKmdSysManager->mockRequestMultipleResult = ZE_RESULT_ERROR_INVALID_SIZE;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         zes_freq_state_t state = {};
         EXPECT_EQ(ZE_RESULT_ERROR_INVALID_SIZE, zesFrequencyGetState(handle, &state));
@@ -404,7 +405,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhileGettingFreque
     pKmdSysManager->mockRequestMultiple = true;
     pKmdSysManager->requestMultipleSizeDiff = true;
     pKmdSysManager->mockRequestMultipleResult = ZE_RESULT_ERROR_INVALID_SIZE;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         zes_freq_state_t state = {};
         EXPECT_EQ(ZE_RESULT_ERROR_INVALID_SIZE, zesFrequencyGetState(handle, &state));
@@ -412,7 +413,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhileGettingFreque
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencyGetThrottleTimeThenVerifyCallFails) {
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         zes_freq_throttle_time_t throttletime = {};
         EXPECT_NE(ZE_RESULT_SUCCESS, zesFrequencyGetThrottleTime(handle, &throttletime));
@@ -422,7 +423,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencyOcGetCapabilitiesThenVerifyCallSucceeds) {
     pKmdSysManager->allowSetCalls = false;
     uint32_t domainIndex = 0;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         zes_oc_capabilities_t ocCaps = {};
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcGetCapabilities(handle, &ocCaps));
@@ -445,7 +446,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencyOcGetFrequencyTargetThenVerifyCallSucceeds) {
     uint32_t domainIndex = 0;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         double freqTarget = 0.0;
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcGetFrequencyTarget(handle, &freqTarget));
@@ -455,7 +456,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencyOcGetFrequencyTargetAndRequestSingleFailsThenFailureIsReturned) {
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         pKmdSysManager->mockRequestSingle = true;
         pKmdSysManager->mockRequestSingleResult = ZE_RESULT_ERROR_UNKNOWN;
@@ -466,7 +467,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencyOcGetVoltageTargetThenVerifyCallSucceeds) {
     uint32_t domainIndex = 0;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         double voltageTarget = 0.0, voltageOffset = 0.0;
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcGetVoltageTarget(handle, &voltageTarget, &voltageOffset));
@@ -480,7 +481,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
     pKmdSysManager->mockRequestMultiple = true;
     pKmdSysManager->requestMultipleSizeDiff = false;
     pKmdSysManager->mockRequestMultipleResult = ZE_RESULT_ERROR_INVALID_SIZE;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         double voltageTarget = 0.0, voltageOffset = 0.0;
         EXPECT_EQ(ZE_RESULT_ERROR_INVALID_SIZE, zesFrequencyOcGetVoltageTarget(handle, &voltageTarget, &voltageOffset));
@@ -489,67 +490,56 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFreq
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleWhenCallingzesFrequencyOcGetModeThenVerifyCallSucceeds) {
     pKmdSysManager->allowSetCalls = false;
-    uint32_t domainIndex = 0;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         zes_oc_mode_t mode = ZES_OC_MODE_OFF;
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcGetMode(handle, &mode));
         EXPECT_DOUBLE_EQ(ZES_OC_MODE_INTERPOLATIVE, mode);
-        domainIndex++;
     }
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToFalseWhenCallingzesFrequencyOcSetFrequencyTargetThenVerifyCallFails) {
     pKmdSysManager->allowSetCalls = false;
-    uint32_t domainIndex = 0;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         double freqTarget = 1400.0;
         EXPECT_NE(ZE_RESULT_SUCCESS, zesFrequencyOcSetFrequencyTarget(handle, freqTarget));
-        domainIndex++;
     }
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToFalseWhenCallingzesFrequencyOcSetVoltageTargetThenVerifyCallFails) {
     pKmdSysManager->allowSetCalls = false;
-    uint32_t domainIndex = 0;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         double voltageTarget = 1040.0, voltageOffset = 20.0;
         EXPECT_NE(ZE_RESULT_SUCCESS, zesFrequencyOcSetVoltageTarget(handle, voltageTarget, voltageOffset));
-        domainIndex++;
     }
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToFalseWhenCallingzesFrequencyOcSetModeThenVerifyCallFails) {
     pKmdSysManager->allowSetCalls = false;
-    uint32_t domainIndex = 0;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         zes_oc_mode_t mode = ZES_OC_MODE_OVERRIDE;
         EXPECT_NE(ZE_RESULT_SUCCESS, zesFrequencyOcSetMode(handle, mode));
-        domainIndex++;
     }
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToTrueWhenCallingzesFrequencyOcSetFrequencyTargetThenVerifyCallSucceed) {
     pKmdSysManager->allowSetCalls = true;
-    uint32_t domainIndex = 0;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         double freqTarget = 1400.0;
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcSetFrequencyTarget(handle, freqTarget));
         double newFreqTarget = 0.0;
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcGetFrequencyTarget(handle, &newFreqTarget));
         EXPECT_DOUBLE_EQ(newFreqTarget, freqTarget);
-        domainIndex++;
     }
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToTrueWhenCallingzesFrequencyOcSetVoltageTargetThenVerifyCallSucceed) {
     pKmdSysManager->allowSetCalls = true;
-    uint32_t domainIndex = 0;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         double voltageTarget = 1040.0, voltageOffset = 20.0;
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcSetVoltageTarget(handle, voltageTarget, voltageOffset));
@@ -557,13 +547,12 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToTru
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcGetVoltageTarget(handle, &newVoltageTarget, &newVoltageOffset));
         EXPECT_DOUBLE_EQ(voltageTarget, newVoltageTarget);
         EXPECT_DOUBLE_EQ(voltageOffset, newVoltageOffset);
-        domainIndex++;
     }
 }
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToTrueWhenCallingzesFrequencyOcSetIccMaxTargetThenVerifyCallSucceed) {
     pKmdSysManager->allowSetCalls = true;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         double setIccMax = 1050.0;
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcSetIccMax(handle, setIccMax));
@@ -575,7 +564,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToTru
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToTrueWhenCallingzesFrequencyOcSetTjMaxTargetThenVerifyCallSucceed) {
     pKmdSysManager->allowSetCalls = true;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
         double setTjMax = 1050.0;
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcSetTjMax(handle, setTjMax));
@@ -587,8 +576,7 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToTru
 
 TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToTrueWhenCallingzesFrequencyOcSetModeThenVerifyCallSucceed) {
     pKmdSysManager->allowSetCalls = true;
-    uint32_t domainIndex = 0;
-    auto handles = get_frequency_handles(frequencyHandleComponentCount);
+    auto handles = getFrequencyHandles(frequencyHandleComponentCount);
     for (auto handle : handles) {
 
         zes_oc_mode_t mode = ZES_OC_MODE_INTERPOLATIVE;
@@ -616,8 +604,6 @@ TEST_F(SysmanDeviceFrequencyFixture, GivenValidFrequencyHandleAllowSetCallsToTru
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcSetMode(handle, mode));
         EXPECT_EQ(ZE_RESULT_SUCCESS, zesFrequencyOcGetMode(handle, &newmode));
         EXPECT_EQ(newmode, ZES_OC_MODE_OVERRIDE);
-
-        domainIndex++;
     }
 }
 
