@@ -1,13 +1,11 @@
 /*
- * Copyright (C) 2018-2022 Intel Corporation
+ * Copyright (C) 2018-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
-
-#include "opencl/source/command_queue/command_queue.h"
 #include "opencl/source/kernel/kernel.h"
 
 #include "CL/cl.h"
@@ -20,7 +18,7 @@ struct GTPinKernelExec {
     cl_mem gtpinResource;
     CommandQueue *pCommandQueue;
     gtpin::command_buffer_handle_t commandBuffer;
-    uint32_t taskCount;
+    TaskCountType taskCount;
     bool isTaskCountValid;
     bool isResourceResident;
 
