@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021 Intel Corporation
+ * Copyright (C) 2021-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -11,11 +11,13 @@
 namespace NEO {
 class Kernel;
 class Device;
+class Context;
 struct MultiDispatchInfo;
 
 class ClPreemptionHelper {
   public:
     static PreemptionMode taskPreemptionMode(Device &device, const MultiDispatchInfo &multiDispatchInfo);
+    static void overrideMidThreadPreemptionSupport(Context &context, bool value);
 };
 
 } // namespace NEO
