@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,6 +7,8 @@
 
 #pragma once
 
+#include "shared/source/helpers/non_copyable_or_moveable.h"
+
 #include "opencl/source/sharings/gl/gl_sharing.h"
 
 #include "CL/cl_gl.h"
@@ -17,7 +19,7 @@ namespace NEO {
 class Buffer;
 class Context;
 
-class GlBuffer : public GlSharing {
+class GlBuffer : public GlSharing, NEO::NonCopyableAndNonMovableClass {
   public:
     static Buffer *createSharedGlBuffer(Context *context, cl_mem_flags flags, unsigned int bufferId, cl_int *errcodeRet);
     void synchronizeObject(UpdateData &updateData) override;
@@ -29,8 +31,6 @@ class GlBuffer : public GlSharing {
     ~GlBuffer() override {
         callReleaseResource(true);
     }
-    GlBuffer(const GlBuffer &other) = delete;
-    GlBuffer &operator=(const GlBuffer &other) = delete;
     void releaseResource(MemObj *memObject, uint32_t rootDeviceIndex) override;
     void callReleaseResource(bool createOrDestroy);
 
@@ -39,4 +39,7 @@ class GlBuffer : public GlSharing {
 
     static GraphicsAllocation *createGraphicsAllocation(Context *context, unsigned int bufferId, _tagCLGLBufferInfo &bufferInfo);
 };
+
+static_assert(NEO::NonCopyableAndNonMovable<GlBuffer>);
+
 } // namespace NEO
