@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2020 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -9,9 +9,13 @@
 
 #include "opencl/source/sharings/unified/unified_sharing.h"
 
+#include "CL/cl.h"
+
 namespace NEO {
 class Buffer;
 class Context;
+enum class UnifiedSharingHandleType;
+struct UnifiedSharingMemoryDescription;
 
 class UnifiedBuffer : public UnifiedSharing {
     using UnifiedSharing::UnifiedSharing;
