@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2022 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -30,7 +30,7 @@ bool VaSharingContextBuilder::processProperties(cl_context_properties &propertyT
 
     switch (propertyType) {
     case CL_CONTEXT_VA_API_DISPLAY_INTEL:
-        contextData->vaDisplay = (VADisplay)propertyValue;
+        contextData->vaDisplay = reinterpret_cast<VADisplay>(propertyValue);
         return true;
     }
     return false;
@@ -71,18 +71,18 @@ void VaSharingBuilderFactory::fillGlobalDispatchTable() {
     crtGlobalDispatchTable.clEnqueueAcquireVA_APIMediaSurfacesINTEL = clEnqueueAcquireVA_APIMediaSurfacesINTEL;
 }
 
-#define RETURN_FUNC_PTR_IF_EXIST(name) \
-    {                                  \
-        if (functionName == #name) {   \
-            return ((void *)(name));   \
-        }                              \
+#define RETURN_FUNC_PTR_IF_EXIST(name)             \
+    {                                              \
+        if (functionName == #name) {               \
+            return reinterpret_cast<void *>(name); \
+        }                                          \
     }
 void *VaSharingBuilderFactory::getExtensionFunctionAddress(const std::string &functionName) {
     RETURN_FUNC_PTR_IF_EXIST(clCreateFromVA_APIMediaSurfaceINTEL);
     RETURN_FUNC_PTR_IF_EXIST(clGetDeviceIDsFromVA_APIMediaAdapterINTEL);
     RETURN_FUNC_PTR_IF_EXIST(clEnqueueAcquireVA_APIMediaSurfacesINTEL);
     RETURN_FUNC_PTR_IF_EXIST(clEnqueueReleaseVA_APIMediaSurfacesINTEL);
-    if (DebugManager.flags.EnableFormatQuery.get()) {
+    if (debugManager.flags.EnableFormatQuery.get()) {
         RETURN_FUNC_PTR_IF_EXIST(clGetSupportedVA_APIMediaSurfaceFormatsINTEL);
     }
     auto extraFunction = getExtensionFunctionAddressExtra(functionName);
