@@ -1,12 +1,12 @@
 /*
- * Copyright (C) 2021 Intel Corporation
+ * Copyright (C) 2021-2022 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
-#include "shared/source/xe_hpg_core/hw_cmds_base.h"
-using Family = NEO::XE_HPG_COREFamily;
+#include "shared/source/xe_hpg_core/hw_cmds_xe_hpg_core_base.h"
+using Family = NEO::XeHpgCoreFamily;
 constexpr static auto gfxCore = IGFX_XE_HPG_CORE;
 
 #include "opencl/source/sampler/sampler.h"
