@@ -7,7 +7,6 @@
 
 #include "shared/source/memory_manager/graphics_allocation.h"
 #include "shared/source/memory_manager/unified_memory_manager.h"
-#include "shared/test/common/mocks/mock_device.h"
 
 #include "opencl/source/event/user_event.h"
 #include "opencl/test/unit_test/mocks/mock_cl_device.h"
@@ -15,8 +14,6 @@
 
 #include "cl_api_tests.h"
 
-#include <memory>
-
 using namespace NEO;
 
 using ClEnqueueSVMMigrateMemTests = ApiTests;
