@@ -5,10 +5,6 @@
  *
  */
 
-#include "shared/source/device/device.h"
-#include "shared/source/helpers/hw_info.h"
-#include "shared/source/helpers/product_config_helper.h"
-
 #include "opencl/test/unit_test/api/cl_api_tests.h"
 
 #include <cstring>
