@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -32,6 +32,12 @@ struct CompressionXeHPAndLater : public AUBFixture,
     void SetUp() override {
         REQUIRE_64BIT_OR_SKIP();
 
+        auto &ftrTable = defaultHwInfo->featureTable;
+        if ((!ftrTable.flags.ftrFlatPhysCCS) ||
+            (!ftrTable.flags.ftrLocalMemory && useLocalMemory)) {
+            GTEST_SKIP();
+        }
+
         debugRestorer = std::make_unique<DebugManagerStateRestore>();
         debugManager.flags.RenderCompressedBuffersEnabled.set(true);
         debugManager.flags.RenderCompressedImagesEnabled.set(true);
@@ -55,11 +61,6 @@ struct CompressionXeHPAndLater : public AUBFixture,
             GTEST_SKIP();
         }
 
-        auto &ftrTable = device->getHardwareInfo().featureTable;
-        if ((!ftrTable.flags.ftrFlatPhysCCS) ||
-            (!ftrTable.flags.ftrLocalMemory && useLocalMemory)) {
-            GTEST_SKIP();
-        }
         context->contextType = ContextType::CONTEXT_TYPE_SPECIALIZED;
     }
     void TearDown() override {
@@ -305,10 +306,10 @@ HWTEST2_P(CompressionLocalXeHPAndLater, givenCompressedImageWhenReadingThenResul
     givenCompressedImageWhenReadingThenResultsAreCorrect<FamilyType>();
 }
 
-INSTANTIATE_TEST_CASE_P(,
-                        CompressionLocalXeHPAndLater,
-                        ::testing::Values(aub_stream::ENGINE_RCS,
-                                          aub_stream::ENGINE_CCS));
+INSTANTIATE_TEST_SUITE_P(,
+                         CompressionLocalXeHPAndLater,
+                         ::testing::Values(aub_stream::ENGINE_RCS,
+                                           aub_stream::ENGINE_CCS));
 
 using CompressionSystemXeHPAndLater = CompressionXeHPAndLater<false>;
 HWTEST2_P(CompressionSystemXeHPAndLater, GENERATEONLY_givenCompressedBuffersWhenWritingAndCopyingThenResultsAreCorrect, CompressionSystemAubsSupportedMatcher) {
@@ -321,7 +322,7 @@ HWTEST2_P(CompressionSystemXeHPAndLater, givenCompressedImageWhenReadingThenResu
     givenCompressedImageWhenReadingThenResultsAreCorrect<FamilyType>();
 }
 
-INSTANTIATE_TEST_CASE_P(,
-                        CompressionSystemXeHPAndLater,
-                        ::testing::Values(aub_stream::ENGINE_RCS,
-                                          aub_stream::ENGINE_CCS));
+INSTANTIATE_TEST_SUITE_P(,
+                         CompressionSystemXeHPAndLater,
+                         ::testing::Values(aub_stream::ENGINE_RCS,
+                                           aub_stream::ENGINE_CCS));
