@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -219,7 +219,7 @@ HWTEST_P(AUBMapImage, WhenMappingAndUnmappingThenExpectationsAreMet) {
     delete[] expected;
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     AUBMapImage_simple, AUBMapImage,
     ::testing::Combine(::testing::Values( // formats
                            CL_UNORM_INT8, CL_SIGNED_INT16, CL_UNSIGNED_INT32,
