@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,12 +7,12 @@
 
 #pragma once
 #include "shared/source/aub_mem_dump/aub_mem_dump.h"
-#include "shared/source/command_stream/aub_command_stream_receiver.h"
 #include "shared/source/command_stream/aub_command_stream_receiver_hw.h"
 #include "shared/source/command_stream/command_stream_receiver_with_aub_dump.h"
 #include "shared/source/command_stream/tbx_command_stream_receiver_hw.h"
 #include "shared/source/helpers/api_specific_config.h"
 #include "shared/source/helpers/gfx_core_helper.h"
+#include "shared/test/common/helpers/ult_hw_config.h"
 #include "shared/test/common/mocks/mock_device.h"
 #include "shared/test/common/mocks/mock_memory_operations_handler.h"
 #include "shared/test/common/tests_configuration.h"
@@ -28,38 +28,17 @@ namespace NEO {
 
 class AUBFixture : public CommandQueueHwFixture {
   public:
-    static CommandStreamReceiver *prepareComputeEngine(MockDevice &device, const std::string &filename) {
-        CommandStreamReceiver *pCommandStreamReceiver = nullptr;
-        if (testMode == TestMode::AubTestsWithTbx) {
-            pCommandStreamReceiver = TbxCommandStreamReceiver::create(filename, true, *device.executionEnvironment, device.getRootDeviceIndex(), device.getDeviceBitfield());
-        } else {
-            pCommandStreamReceiver = AUBCommandStreamReceiver::create(filename, true, *device.executionEnvironment, device.getRootDeviceIndex(), device.getDeviceBitfield());
-        }
-        device.resetCommandStreamReceiver(pCommandStreamReceiver);
-        return pCommandStreamReceiver;
-    }
-    static void prepareCopyEngines(MockDevice &device, const std::string &filename) {
-        for (auto i = 0u; i < device.allEngines.size(); i++) {
-            if (EngineHelpers::isBcs(device.allEngines[i].getEngineType())) {
-                CommandStreamReceiver *pBcsCommandStreamReceiver = nullptr;
-                if (testMode == TestMode::AubTestsWithTbx) {
-                    pBcsCommandStreamReceiver = TbxCommandStreamReceiver::create(filename, true, *device.executionEnvironment, device.getRootDeviceIndex(), device.getDeviceBitfield());
-                } else {
-                    pBcsCommandStreamReceiver = AUBCommandStreamReceiver::create(filename, true, *device.executionEnvironment, device.getRootDeviceIndex(), device.getDeviceBitfield());
-                }
-                device.resetCommandStreamReceiver(pBcsCommandStreamReceiver, i);
-            }
-        }
-    }
-
     void setUp(const HardwareInfo *hardwareInfo) {
         const HardwareInfo &hwInfo = hardwareInfo ? *hardwareInfo : *defaultHwInfo;
 
+        backupUltConfig = std::make_unique<VariableBackup<UltHwConfig>>(&ultHwConfig);
+
         executionEnvironment = platform()->peekExecutionEnvironment();
         executionEnvironment->prepareRootDeviceEnvironments(1u);
         executionEnvironment->rootDeviceEnvironments[0]->setHwInfoAndInitHelpers(&hwInfo);
         executionEnvironment->rootDeviceEnvironments[0]->initGmm();
         executionEnvironment->rootDeviceEnvironments[0]->memoryOperationsInterface = std::make_unique<MockMemoryOperationsHandler>();
+        executionEnvironment->calculateMaxOsContextCount();
 
         auto &gfxCoreHelper = executionEnvironment->rootDeviceEnvironments[0]->getHelper<GfxCoreHelper>();
         auto engineType = getChosenEngineType(hwInfo);
@@ -69,12 +48,14 @@ class AUBFixture : public CommandQueueHwFixture {
         strfilename << ApiSpecificConfig::getAubPrefixForSpecificApi();
         strfilename << testInfo->test_case_name() << "_" << testInfo->name() << "_" << gfxCoreHelper.getCsTraits(engineType).name;
 
+        aubFileName = strfilename.str();
+        ultHwConfig.aubTestName = aubFileName.c_str();
+
         auto pDevice = MockDevice::create<MockDevice>(executionEnvironment, rootDeviceIndex);
         device = std::make_unique<MockClDevice>(pDevice);
+        pDevice->disableSecondaryEngines = true;
 
-        this->csr = prepareComputeEngine(*pDevice, strfilename.str());
-
-        prepareCopyEngines(*pDevice, strfilename.str());
+        this->csr = pDevice->getDefaultEngine().commandStreamReceiver;
 
         CommandQueueHwFixture::setUp(AUBFixture::device.get(), cl_command_queue_properties(0));
     }
@@ -83,6 +64,7 @@ class AUBFixture : public CommandQueueHwFixture {
     }
 
     GraphicsAllocation *createHostPtrAllocationFromSvmPtr(void *svmPtr, size_t size);
+    GraphicsAllocation *createResidentAllocationAndStoreItInCsr(const void *address, size_t size);
 
     template <typename FamilyType>
     CommandStreamReceiverSimulatedCommonHw<FamilyType> *getSimulatedCsr() const {
@@ -93,7 +75,7 @@ class AUBFixture : public CommandQueueHwFixture {
     void expectMemory(void *gfxAddress, const void *srcAddress, size_t length) {
         CommandStreamReceiverSimulatedCommonHw<FamilyType> *csrSimulated = getSimulatedCsr<FamilyType>();
 
-        if (testMode == TestMode::AubTestsWithTbx) {
+        if (testMode == TestMode::aubTestsWithTbx) {
             auto tbxCsr = csrSimulated;
             EXPECT_TRUE(tbxCsr->expectMemoryEqual(gfxAddress, srcAddress, length));
             csrSimulated = static_cast<CommandStreamReceiverSimulatedCommonHw<FamilyType> *>(
@@ -116,7 +98,7 @@ class AUBFixture : public CommandQueueHwFixture {
     template <typename FamilyType>
     void expectMMIO(uint32_t mmioRegister, uint32_t expectedValue) {
         CommandStreamReceiver *csrtemp = csr;
-        if (testMode == TestMode::AubTestsWithTbx) {
+        if (testMode == TestMode::aubTestsWithTbx) {
             csrtemp = static_cast<CommandStreamReceiverWithAUBDump<TbxCommandStreamReceiverHw<FamilyType>> *>(csr)->aubCSR.get();
         }
 
@@ -131,7 +113,7 @@ class AUBFixture : public CommandQueueHwFixture {
     void expectNotEqualMemory(void *gfxAddress, const void *srcAddress, size_t length) {
         CommandStreamReceiverSimulatedCommonHw<FamilyType> *csrSimulated = getSimulatedCsr<FamilyType>();
 
-        if (testMode == TestMode::AubTestsWithTbx) {
+        if (testMode == TestMode::aubTestsWithTbx) {
             auto tbxCsr = csrSimulated;
             EXPECT_TRUE(tbxCsr->expectMemoryNotEqual(gfxAddress, srcAddress, length));
             csrSimulated = static_cast<CommandStreamReceiverSimulatedCommonHw<FamilyType> *>(
@@ -147,7 +129,7 @@ class AUBFixture : public CommandQueueHwFixture {
     void expectCompressedMemory(void *gfxAddress, const void *srcAddress, size_t length) {
         CommandStreamReceiverSimulatedCommonHw<FamilyType> *csrSimulated = getSimulatedCsr<FamilyType>();
 
-        if (testMode == TestMode::AubTestsWithTbx) {
+        if (testMode == TestMode::aubTestsWithTbx) {
             auto tbxCsr = csrSimulated;
             EXPECT_TRUE(tbxCsr->expectMemoryCompressed(gfxAddress, srcAddress, length));
             csrSimulated = static_cast<CommandStreamReceiverSimulatedCommonHw<FamilyType> *>(
@@ -159,6 +141,11 @@ class AUBFixture : public CommandQueueHwFixture {
         }
     }
 
+    template <typename FamilyType>
+    void pollForCompletion() {
+        getSimulatedCsr<FamilyType>()->pollForCompletion();
+    }
+
     static void *getGpuPointer(GraphicsAllocation *allocation) {
         return reinterpret_cast<void *>(allocation->getGpuAddress());
     }
@@ -176,6 +163,9 @@ class AUBFixture : public CommandQueueHwFixture {
 
   private:
     using CommandQueueHwFixture::setUp;
+    std::string aubFileName;
+    std::unique_ptr<VariableBackup<UltHwConfig>> backupUltConfig;
+
 }; // namespace NEO
 
 template <typename KernelFixture>
