@@ -67,7 +67,7 @@ HWTEST_F(CommandQueueHwTest, whenCallingIsCompletedThenTestTaskCountValue) {
     cmdQ.bcsEngines[0] = &control;
     cmdQ.bcsStates[0] = state;
 
-    Range<CopyEngineState> states{&state};
+    std::span<CopyEngineState> states{&state, 1};
 
     EXPECT_EQ(0u, ultCsr.downloadAllocationsCalledCount);
     EXPECT_EQ(0u, bcsCsr->downloadAllocationsCalledCount);
@@ -96,7 +96,7 @@ HWTEST_F(CommandQueueHwTest, givenEnableTimestampWaitForQueuesWhenGpuHangDetecte
     cmdQ.timestampPacketContainer = std::make_unique<TimestampPacketContainer>();
     cmdQ.timestampPacketContainer->add(mockTagAllocator->getTag());
 
-    status = cmdQ.waitForAllEngines(false, nullptr, false);
+    status = cmdQ.waitForAllEngines(false, nullptr, false, false);
 
     EXPECT_EQ(WaitStatus::gpuHang, status);
 }
