@@ -1,12 +1,11 @@
 /*
- * Copyright (C) 2018-2021 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
-#include "shared/test/common/test_macros/test.h"
 #include "shared/test/common/test_macros/test_checks_shared.h"
 
 #include "opencl/test/unit_test/command_queue/command_enqueue_fixture.h"
@@ -16,20 +15,20 @@
 namespace NEO {
 
 struct EnqueueFillImageTestFixture : public CommandEnqueueFixture {
-    void SetUp(void) override {
+    void setUp() {
         REQUIRE_IMAGES_OR_SKIP(defaultHwInfo);
-        CommandEnqueueFixture::SetUp();
+        CommandEnqueueFixture::setUp();
         context = new MockContext(pClDevice);
-        image = Image2dHelper<>::create(context);
+        image = Image2dHelperUlt<>::create(context);
     }
 
-    void TearDown(void) override {
+    void tearDown() {
         if (testing::Test::IsSkipped()) {
             return;
         }
         delete image;
         delete context;
-        CommandEnqueueFixture::TearDown();
+        CommandEnqueueFixture::tearDown();
     }
 
   protected:
