@@ -1,16 +1,13 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
-#include "shared/source/memory_manager/memory_manager.h"
-#include "shared/test/common/test_macros/test.h"
 #include "shared/test/common/test_macros/test_checks_shared.h"
 
 #include "opencl/source/command_queue/command_queue_hw.h"
-#include "opencl/source/event/event.h"
 #include "opencl/test/unit_test/command_queue/command_queue_fixture.h"
 #include "opencl/test/unit_test/command_queue/enqueue_fixture.h"
 #include "opencl/test/unit_test/fixtures/cl_device_fixture.h"
@@ -43,8 +40,8 @@ struct OOMCommandQueueImageTest : public ClDeviceFixture,
         context = new MockContext(pClDevice);
         CommandQueueFixture::setUp(context, pClDevice, 0);
 
-        srcImage = Image2dHelper<>::create(context);
-        dstImage = Image2dHelper<>::create(context);
+        srcImage = Image2dHelperUlt<>::create(context);
+        dstImage = Image2dHelperUlt<>::create(context);
 
         const auto &oomSetting = GetParam();
         auto oomSize = 10u;
@@ -178,7 +175,7 @@ HWTEST_P(OOMCommandQueueImageTest, WhenWritingImageThenMaxAvailableSpaceIsNotExc
     EXPECT_EQ(CL_SUCCESS, retVal2);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     OOM,
     OOMCommandQueueImageTest,
     testing::ValuesIn(oomSettings));
