@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -10,7 +10,6 @@
 #include "shared/source/memory_manager/memory_manager.h"
 #include "shared/source/os_interface/os_context.h"
 #include "shared/test/common/helpers/debug_manager_state_restore.h"
-#include "shared/test/common/libult/ult_command_stream_receiver.h"
 #include "shared/test/common/mocks/mock_allocation_properties.h"
 #include "shared/test/common/test_macros/test_checks_shared.h"
 
@@ -133,7 +132,7 @@ TEST(UserEvent, GivenInitialUserEventStateWhenCheckingReadyForSubmissionThenFals
 TEST(UserEvent, GivenUserEventWhenGettingTaskLevelThenZeroIsReturned) {
     MyUserEvent uEvent;
     EXPECT_EQ(0U, uEvent.getTaskLevel());
-    EXPECT_EQ(WaitStatus::NotReady, uEvent.wait(false, false));
+    EXPECT_EQ(WaitStatus::notReady, uEvent.wait(false, false));
 }
 
 TEST(UserEvent, WhenSettingStatusThenReadyForSubmissionisTrue) {
@@ -543,12 +542,12 @@ TEST_F(MockEventTests, GivenAbortedUserEventWhenEnqueingNdrThenDoNotFlushToCsr)
 
 TEST_F(MockEventTests, givenDebugVariableWhenStatusIsQueriedThenNoFlushHappens) {
     DebugManagerStateRestore restorer;
-    DebugManager.flags.SkipFlushingEventsOnGetStatusCalls.set(1);
-    DebugManager.flags.PerformImplicitFlushForNewResource.set(0);
-    DebugManager.flags.PerformImplicitFlushForIdleGpu.set(0);
+    debugManager.flags.SkipFlushingEventsOnGetStatusCalls.set(1);
+    debugManager.flags.PerformImplicitFlushForNewResource.set(0);
+    debugManager.flags.PerformImplicitFlushForIdleGpu.set(0);
 
     auto &csr = pCmdQ->getGpgpuCommandStreamReceiver();
-    csr.overrideDispatchPolicy(DispatchMode::BatchedDispatch);
+    csr.overrideDispatchPolicy(DispatchMode::batchedDispatch);
     csr.postInitFlagsSetup();
 
     cl_event retEvent = nullptr;
@@ -791,7 +790,7 @@ TEST_F(MockEventTests, givenBlockedQueueThenCommandStreamDoesNotChangeWhileEnque
 
 TEST_F(EventTests, givenUserEventThatHasCallbackAndBlockQueueWhenQueueIsQueriedForBlockedThenCallBackIsCalled) {
     DebugManagerStateRestore dbgRestore;
-    DebugManager.flags.EnableAsyncEventsHandler.set(false);
+    debugManager.flags.EnableAsyncEventsHandler.set(false);
     struct EV : UserEvent {
         EV(Context *ctx) : UserEvent(ctx) {
         }
@@ -839,7 +838,7 @@ TEST_F(EventTests, givenUserEventThatHasCallbackAndBlockQueueWhenQueueIsQueriedF
 
 TEST_F(EventTests, GivenEventCallbackWithWaitWhenWaitingForEventsThenSuccessIsReturned) {
     DebugManagerStateRestore dbgRestore;
-    DebugManager.flags.EnableAsyncEventsHandler.set(false);
+    debugManager.flags.EnableAsyncEventsHandler.set(false);
     UserEvent event1;
     struct E2Clb {
         static void CL_CALLBACK signalEv2(cl_event e, cl_int status, void *data)
@@ -870,7 +869,7 @@ TEST_F(EventTests, GivenEventCallbackWithWaitWhenWaitingForEventsThenSuccessIsRe
 
 TEST_F(EventTests, GivenEventCallbackWithoutWaitWhenWaitingForEventsThenSuccessIsReturned) {
     DebugManagerStateRestore dbgRestore;
-    DebugManager.flags.EnableAsyncEventsHandler.set(false);
+    debugManager.flags.EnableAsyncEventsHandler.set(false);
     UserEvent event1(context);
     struct E2Clb {
         static void CL_CALLBACK signalEv2(cl_event e, cl_int status, void *data)
@@ -902,7 +901,7 @@ TEST_F(MockEventTests, GivenEnqueueReadImageWhenWaitingforEventThenSuccessIsRetu
     uEvent = makeReleaseable<UserEvent>(context);
     cl_event eventWaitList[] = {uEvent.get()};
 
-    auto image = clUniquePtr(Image2dHelper<>::create(this->context));
+    auto image = clUniquePtr(Image2dHelperUlt<>::create(this->context));
     ASSERT_NE(nullptr, image);
 
     auto retVal = EnqueueReadImageHelper<>::enqueueReadImage(pCmdQ,
@@ -954,7 +953,7 @@ TEST_F(EventTests, WhenWaitingForEventsThenTemporaryAllocationsAreDestroyed) {
 TEST_F(EventTest, WhenUserEventIsCreatedThenWaitIsNonBlocking) {
     UserEvent event;
     auto result = event.wait(false, false);
-    EXPECT_EQ(WaitStatus::NotReady, result);
+    EXPECT_EQ(WaitStatus::notReady, result);
 }
 
 TEST_F(EventTest, GivenSingleUserEventWhenWaitingForEventsThenSuccessIsReturned) {
@@ -968,7 +967,7 @@ TEST_F(EventTest, GivenSingleUserEventWhenWaitingForEventsThenSuccessIsReturned)
 
 TEST_F(EventTest, GivenMultipleOutOfOrderCallbacksWhenWaitingForEventsThenSuccessIsReturned) {
     DebugManagerStateRestore dbgRestore;
-    DebugManager.flags.EnableAsyncEventsHandler.set(false);
+    debugManager.flags.EnableAsyncEventsHandler.set(false);
     UserEvent event1;
     struct E2Clb {
         static void CL_CALLBACK signalEv2(cl_event e, cl_int status, void *data)
@@ -989,7 +988,7 @@ TEST_F(EventTest, GivenMultipleOutOfOrderCallbacksWhenWaitingForEventsThenSucces
 
 TEST_F(EventTests, WhenCalbackWasRegisteredOnCallbackThenExecutionPassesCorrectExecutionStatus) {
     DebugManagerStateRestore dbgRestore;
-    DebugManager.flags.EnableAsyncEventsHandler.set(false);
+    debugManager.flags.EnableAsyncEventsHandler.set(false);
     struct HelperClb {
         static void CL_CALLBACK setClbStatus(cl_event e, cl_int status, void *data)
 
