@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -143,7 +143,7 @@ TEST_F(GmmTests, WhenConvertingPlanesThenCorrectPlaneIsReturned) {
 class GmmImgTest : public GmmTests,
                    public ::testing::WithParamInterface<uint32_t /*cl_mem_object_type*/> {};
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     GmmImgTests,
     GmmImgTest,
     testing::ValuesIn(GmmTestConst::imgTypes));
@@ -336,12 +336,33 @@ TEST_F(GmmCompressionTests, givenNV12FormatWhenQueryingThenDisallow) {
     EXPECT_FALSE(queryGmm->isCompressionEnabled());
 }
 
+TEST_F(GmmCompressionTests, givenInvalidCompressionFormatAndXe2CompressionFtrSetWhenQueryingThenDisallowOnGmmXe2CompFormat) {
+    auto mockGmmClient = static_cast<MockGmmClientContext *>(getGmmClientContext());
+    imgInfo.surfaceFormat = &SurfaceFormats::readOnlyDepth()[2].surfaceFormat;
+
+    localPlatformDevice->featureTable.flags.ftrXe2Compression = true;
+    uint8_t validFormat = static_cast<uint8_t>(GMM_XE2_UNIFIED_COMP_FORMAT::GMM_XE2_UNIFIED_COMP_FORMAT_R32);
+    uint8_t invalidFormat = static_cast<uint8_t>(GMM_XE2_UNIFIED_COMP_FORMAT::GMM_XE2_UNIFIED_COMP_FORMAT_INVALID);
+
+    mockGmmClient->compressionFormatToReturn = invalidFormat;
+    auto queryGmm = MockGmm::queryImgParams(getGmmHelper(), imgInfo, true);
+    auto resourceFormat = queryGmm->gmmResourceInfo->getResourceFormat();
+    auto compressionFormat = getGmmClientContext()->getSurfaceStateCompressionFormat(resourceFormat);
+    EXPECT_EQ(compressionFormat, invalidFormat);
+    EXPECT_FALSE(queryGmm->isCompressionEnabled());
+
+    mockGmmClient->compressionFormatToReturn = validFormat;
+    queryGmm = MockGmm::queryImgParams(getGmmHelper(), imgInfo, true);
+    EXPECT_TRUE(queryGmm->isCompressionEnabled());
+}
+
 TEST_F(GmmCompressionTests, givenInvalidCompressionFormatAndFlatCcsFtrSetWhenQueryingThenDisallowOnGmmFlatCcsFormat) {
     auto mockGmmClient = static_cast<MockGmmClientContext *>(getGmmClientContext());
     imgInfo.surfaceFormat = &SurfaceFormats::readOnlyDepth()[2].surfaceFormat;
 
+    localPlatformDevice->featureTable.flags.ftrXe2Compression = false;
     localPlatformDevice->featureTable.flags.ftrFlatPhysCCS = true;
-    uint8_t validFormat = static_cast<uint8_t>(GMM_E2ECOMP_FORMAT::GMM_E2ECOMP_FORMAT_INVALID);
+    uint8_t validFormat = static_cast<uint8_t>(GMM_FLATCCS_FORMAT::GMM_FLATCCS_FORMAT_R32U);
     uint8_t invalidFormat = static_cast<uint8_t>(GMM_FLATCCS_FORMAT::GMM_FLATCCS_FORMAT_INVALID);
 
     mockGmmClient->compressionFormatToReturn = invalidFormat;
@@ -360,9 +381,10 @@ TEST_F(GmmCompressionTests, givenInvalidCompressionFormatAndFlatCcsFtrNotSetWhen
     auto mockGmmClient = static_cast<MockGmmClientContext *>(getGmmClientContext());
     imgInfo.surfaceFormat = &SurfaceFormats::readOnlyDepth()[2].surfaceFormat;
 
+    localPlatformDevice->featureTable.flags.ftrXe2Compression = false;
     localPlatformDevice->featureTable.flags.ftrFlatPhysCCS = false;
+    uint8_t validFormat = static_cast<uint8_t>(GMM_E2ECOMP_FORMAT::GMM_E2ECOMP_FORMAT_RGB32);
     uint8_t invalidFormat = static_cast<uint8_t>(GMM_E2ECOMP_FORMAT::GMM_E2ECOMP_FORMAT_INVALID);
-    uint8_t validFormat = static_cast<uint8_t>(GMM_FLATCCS_FORMAT::GMM_FLATCCS_FORMAT_INVALID);
     mockGmmClient->compressionFormatToReturn = invalidFormat;
 
     auto queryGmm = MockGmm::queryImgParams(getGmmHelper(), imgInfo, true);
@@ -451,6 +473,7 @@ TEST_F(GmmLocalMemoryTests, givenUseCompressionAndLocalMemoryInImageInfoTrueWhen
     StorageInfo storageInfo = {};
     storageInfo.memoryBanks.set(1);
     storageInfo.systemMemoryPlacement = false;
+    storageInfo.localOnlyRequired = true;
 
     auto gmm = std::make_unique<Gmm>(getGmmHelper(), imgInfo, storageInfo, true);
     EXPECT_TRUE(gmm->isCompressionEnabled());
