@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2021 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -15,18 +15,21 @@
 #include "shared/source/helpers/ptr_math.h"
 #include "shared/source/sku_info/sku_info_base.h"
 #include "shared/test/common/cmd_parse/gen_cmd_parse.h"
-#include "shared/test/common/test_macros/test.h"
+#include "shared/test/common/test_macros/hw_test.h"
 
 #include "hw_cmds.h"
 #include "third_party/opencl_headers/CL/cl.h"
 
 #include <algorithm>
+#include <chrono>
 #include <fstream>
 #include <iostream>
 #include <list>
 #include <map>
 #include <memory>
+#include <ranges>
 #include <set>
+#include <sstream>
 #include <stdio.h>
 #include <string>
 #include <vector>
