@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2021 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,15 +7,14 @@
 
 #pragma once
 
-#include "shared/source/indirect_heap/indirect_heap.h"
-
 namespace NEO {
 
 class CommandQueue;
+class IndirectHeap;
 
 struct IndirectHeapFixture {
-    virtual void SetUp(CommandQueue *pCmdQ);
-    virtual void TearDown() {
+    void setUp(CommandQueue *pCmdQ);
+    void tearDown() {
     }
 
     IndirectHeap *pDSH = nullptr;
