@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -111,7 +111,7 @@ TEST_P(PackedYuvImageTest, GivenInvalidWidthWhenValidatingImageFormatThenInvalid
     EXPECT_EQ(CL_INVALID_IMAGE_DESCRIPTOR, retVal);
 }
 
-INSTANTIATE_TEST_CASE_P(
+INSTANTIATE_TEST_SUITE_P(
     PackedYuvImageTests,
     PackedYuvImageTest,
     testing::ValuesIn(packedYuvChannels));
