@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2021 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -11,10 +11,12 @@
 
 #include <atomic>
 #include <iterator>
-#include <memory>
-#include <mutex>
 #include <vector>
 
+namespace NEO {
+class Event;
+} // namespace NEO
+
 using namespace NEO;
 namespace MockAsyncEventHandlerGlobals {
 extern bool destructorCalled;
