@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -14,7 +14,10 @@
 
 namespace NEO {
 class MockDevice;
-}
+class Context;
+class GmmHelper;
+class GraphicsAllocation;
+} // namespace NEO
 
 using namespace NEO;
 
@@ -72,7 +75,7 @@ class MockBuffer : public MockBufferStorage, public Buffer {
         return Buffer::allowCpuAccess();
     }
 
-    void setArgStateful(void *memory, bool forceNonAuxMode, bool disableL3, bool alignSizeForAuxTranslation, bool isReadOnly, const Device &device, bool useGlobalAtomics, bool areMultipleSubDevicesInContext) override;
+    void setArgStateful(void *memory, bool forceNonAuxMode, bool disableL3, bool alignSizeForAuxTranslation, bool isReadOnly, const Device &device, bool areMultipleSubDevicesInContext) override;
 
     void transferDataToHostPtr(MemObjSizeArray &copySize, MemObjOffsetArray &copyOffset) override {
         ++transferDataToHostPtrCalledCount;
@@ -118,7 +121,7 @@ class AlignedBuffer : public MockBufferStorage, public Buffer {
         }
     }
 
-    void setArgStateful(void *memory, bool forceNonAuxMode, bool disableL3, bool alignSizeForAuxTranslation, bool isReadOnly, const Device &device, bool useGlobalAtomics, bool areMultipleSubDevicesInContext) override;
+    void setArgStateful(void *memory, bool forceNonAuxMode, bool disableL3, bool alignSizeForAuxTranslation, bool isReadOnly, const Device &device, bool areMultipleSubDevicesInContext) override;
 
     GraphicsAllocation *externalAlloc = nullptr;
 };
@@ -140,7 +143,7 @@ class UnalignedBuffer : public MockBufferStorage, public Buffer {
         }
     }
 
-    void setArgStateful(void *memory, bool forceNonAuxMode, bool disableL3, bool alignSizeForAuxTranslation, bool isReadOnly, const Device &device, bool useGlobalAtomics, bool areMultipleSubDevicesInContext) override;
+    void setArgStateful(void *memory, bool forceNonAuxMode, bool disableL3, bool alignSizeForAuxTranslation, bool isReadOnly, const Device &device, bool areMultipleSubDevicesInContext) override;
 
     GraphicsAllocation *externalAlloc = nullptr;
 };
