@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,6 +7,7 @@
 
 #include "opencl/test/unit_test/mocks/mock_cl_device.h"
 
+#include "shared/source/command_stream/command_stream_receiver.h"
 #include "shared/source/helpers/hw_info.h"
 #include "shared/test/common/mocks/mock_device.h"
 
@@ -26,7 +27,7 @@ MockClDevice::MockClDevice(MockDevice *pMockDevice)
 
 ExecutionEnvironment *MockClDevice::prepareExecutionEnvironment(const HardwareInfo *pHwInfo, uint32_t rootDeviceIndex) {
     auto executionEnvironment = new MockClExecutionEnvironment();
-    auto numRootDevices = DebugManager.flags.CreateMultipleRootDevices.get() ? DebugManager.flags.CreateMultipleRootDevices.get() : rootDeviceIndex + 1;
+    auto numRootDevices = debugManager.flags.CreateMultipleRootDevices.get() ? debugManager.flags.CreateMultipleRootDevices.get() : rootDeviceIndex + 1;
     executionEnvironment->prepareRootDeviceEnvironments(numRootDevices);
     pHwInfo = pHwInfo ? pHwInfo : defaultHwInfo.get();
     for (auto i = 0u; i < executionEnvironment->rootDeviceEnvironments.size(); i++) {
@@ -37,6 +38,10 @@ ExecutionEnvironment *MockClDevice::prepareExecutionEnvironment(const HardwareIn
     return executionEnvironment;
 }
 
+std::unique_ptr<CommandStreamReceiver> MockClDevice::createCommandStreamReceiver() const {
+    return device.createCommandStreamReceiver();
+}
+
 bool MockClDevice::areOcl21FeaturesSupported() const {
     return device.getHardwareInfo().capabilityTable.supportsOcl21Features;
 }
