@@ -7,14 +7,10 @@
 
 #pragma once
 
-#include "shared/source/command_stream/wait_status.h"
-#include "shared/source/memory_manager/graphics_allocation.h"
 #include "shared/test/common/libult/ult_command_stream_receiver.h"
 
 #include "opencl/source/command_queue/command_queue_hw.h"
 
-#include <optional>
-
 ////////////////////////////////////////////////////////////////////////////////
 // MockCommandQueue - Core implementation
 ////////////////////////////////////////////////////////////////////////////////
@@ -59,19 +55,9 @@ class MockCommandQueue : public CommandQueue {
         bcsQueueEngineType = std::nullopt;
     }
 
-    void insertBcsEngine(aub_stream::EngineType bcsEngineType) {
-        const auto index = NEO::EngineHelpers::getBcsIndex(bcsEngineType);
-        const auto engine = &getDevice().getEngine(bcsEngineType, EngineUsage::regular);
-        bcsEngines[index] = engine;
-        bcsQueueEngineType = bcsEngineType;
-        bcsInitialized = true;
-    }
+    void insertBcsEngine(aub_stream::EngineType bcsEngineType);
 
-    size_t countBcsEngines() const {
-        return std::count_if(bcsEngines.begin(), bcsEngines.end(), [](const EngineControl *engine) {
-            return engine != nullptr && engine->getEngineUsage() == EngineUsage::regular;
-        });
-    }
+    size_t countBcsEngines() const;
 
     void setProfilingEnabled() {
         commandQueueProperties |= CL_QUEUE_PROFILING_ENABLE;
@@ -79,18 +65,16 @@ class MockCommandQueue : public CommandQueue {
     void setOoqEnabled() {
         commandQueueProperties |= CL_QUEUE_OUT_OF_ORDER_EXEC_MODE_ENABLE;
     }
-    MockCommandQueue() : CommandQueue(nullptr, nullptr, 0, false) {}
-    MockCommandQueue(Context &context) : MockCommandQueue(&context, context.getDevice(0), nullptr, false) {}
-    MockCommandQueue(Context *context, ClDevice *device, const cl_queue_properties *props, bool internalUsage)
-        : CommandQueue(context, device, props, internalUsage) {
-    }
+    MockCommandQueue();
+    MockCommandQueue(Context &context);
+    MockCommandQueue(Context *context, ClDevice *device, const cl_queue_properties *props, bool internalUsage);
 
     LinearStream &getCS(size_t minRequiredSize) override {
         requestedCmdStreamSize = minRequiredSize;
         return CommandQueue::getCS(minRequiredSize);
     }
 
-    void releaseIndirectHeap(IndirectHeap::Type heap) override {
+    void releaseIndirectHeap(IndirectHeapType heap) override {
         releaseIndirectHeapCalled = true;
         CommandQueue::releaseIndirectHeap(heap);
     }
@@ -113,7 +97,7 @@ class MockCommandQueue : public CommandQueue {
         return CL_SUCCESS;
     }
 
-    WaitStatus waitUntilComplete(TaskCountType gpgpuTaskCountToWait, Range<CopyEngineState> copyEnginesToWait, FlushStamp flushStampToWait, bool useQuickKmdSleep, bool cleanTemporaryAllocationList, bool skipWait) override {
+    WaitStatus waitUntilComplete(TaskCountType gpgpuTaskCountToWait, std::span<CopyEngineState> copyEnginesToWait, FlushStamp flushStampToWait, bool useQuickKmdSleep, bool cleanTemporaryAllocationList, bool skipWait) override {
         latestTaskCountWaited = gpgpuTaskCountToWait;
 
         waitUntilCompleteCalledCount++;
@@ -124,7 +108,7 @@ class MockCommandQueue : public CommandQueue {
         return CommandQueue::waitUntilComplete(gpgpuTaskCountToWait, copyEnginesToWait, flushStampToWait, useQuickKmdSleep, cleanTemporaryAllocationList, skipWait);
     }
 
-    WaitStatus waitUntilComplete(TaskCountType gpgpuTaskCountToWait, Range<CopyEngineState> copyEnginesToWait, FlushStamp flushStampToWait, bool useQuickKmdSleep) override {
+    WaitStatus waitUntilComplete(TaskCountType gpgpuTaskCountToWait, std::span<CopyEngineState> copyEnginesToWait, FlushStamp flushStampToWait, bool useQuickKmdSleep) override {
         latestTaskCountWaited = gpgpuTaskCountToWait;
         return CommandQueue::waitUntilComplete(gpgpuTaskCountToWait, copyEnginesToWait, flushStampToWait, useQuickKmdSleep);
     }
@@ -171,10 +155,7 @@ class MockCommandQueue : public CommandQueue {
     cl_int enqueueSVMMemFill(void *svmPtr, const void *pattern, size_t patternSize, size_t size, cl_uint numEventsInWaitList,
                              const cl_event *eventWaitList, cl_event *event) override { return CL_SUCCESS; }
 
-    cl_int enqueueMarkerWithWaitList(cl_uint numEventsInWaitList, const cl_event *eventWaitList, cl_event *event) override {
-        enqueueMarkerWithWaitListCalled = true;
-        return CL_SUCCESS;
-    }
+    cl_int enqueueMarkerWithWaitList(cl_uint numEventsInWaitList, const cl_event *eventWaitList, cl_event *event) override;
 
     cl_int enqueueMigrateMemObjects(cl_uint numMemObjects, const cl_mem *memObjects, cl_mem_migration_flags flags,
                                     cl_uint numEventsInWaitList, const cl_event *eventWaitList, cl_event *event) override { return CL_SUCCESS; }
@@ -252,20 +233,12 @@ class MockCommandQueue : public CommandQueue {
 
     cl_int flush() override { return CL_SUCCESS; }
 
-    bool waitForTimestamps(Range<CopyEngineState> copyEnginesToWait, WaitStatus &status, TimestampPacketContainer *mainContainer, TimestampPacketContainer *deferredContainer) override {
+    bool waitForTimestamps(std::span<CopyEngineState> copyEnginesToWait, WaitStatus &status, TimestampPacketContainer *mainContainer, TimestampPacketContainer *deferredContainer) override {
         waitForTimestampsCalled = true;
         return false;
     };
 
-    bool isCompleted(TaskCountType gpgpuTaskCount, const Range<CopyEngineState> &bcsStates) override {
-        isCompletedCalled++;
-
-        if (!device || !getGpgpuCommandStreamReceiver().getTagAddress()) {
-            return true;
-        }
-
-        return CommandQueue::isCompleted(gpgpuTaskCount, bcsStates);
-    }
+    bool isCompleted(TaskCountType gpgpuTaskCount, const std::span<CopyEngineState> &bcsStates) override;
 
     bool enqueueMarkerWithWaitListCalled = false;
     bool releaseIndirectHeapCalled = false;
@@ -479,7 +452,8 @@ class MockCommandQueueHw : public CommandQueueHw<GfxFamily> {
         useBcsCsrOnNotifyEnabled = notifyBcsCsr;
     }
 
-    WaitStatus waitUntilComplete(TaskCountType gpgpuTaskCountToWait, Range<CopyEngineState> copyEnginesToWait, FlushStamp flushStampToWait, bool useQuickKmdSleep, bool cleanTemporaryAllocationList, bool skipWait) override {
+    WaitStatus waitUntilComplete(TaskCountType gpgpuTaskCountToWait, std::span<CopyEngineState> copyEnginesToWait, FlushStamp flushStampToWait, bool useQuickKmdSleep, bool cleanTemporaryAllocationList, bool skipWait) override {
+        this->recordedSkipWait = skipWait;
         latestTaskCountWaited = gpgpuTaskCountToWait;
         if (waitUntilCompleteReturnValue.has_value()) {
             return *waitUntilCompleteReturnValue;
@@ -488,14 +462,14 @@ class MockCommandQueueHw : public CommandQueueHw<GfxFamily> {
         return BaseClass::waitUntilComplete(gpgpuTaskCountToWait, copyEnginesToWait, flushStampToWait, useQuickKmdSleep, cleanTemporaryAllocationList, skipWait);
     }
 
-    WaitStatus waitForAllEngines(bool blockedQueue, PrintfHandler *printfHandler, bool cleanTemporaryAllocationsList) override {
+    WaitStatus waitForAllEngines(bool blockedQueue, PrintfHandler *printfHandler, bool cleanTemporaryAllocationsList, bool waitForTaskCountRequired) override {
         waitForAllEnginesCalledCount++;
 
         if (waitForAllEnginesReturnValue.has_value()) {
             return *waitForAllEnginesReturnValue;
         }
 
-        return BaseClass::waitForAllEngines(blockedQueue, printfHandler, cleanTemporaryAllocationsList);
+        return BaseClass::waitForAllEngines(blockedQueue, printfHandler, cleanTemporaryAllocationsList, waitForTaskCountRequired);
     }
 
     bool isCacheFlushForBcsRequired() const override {
@@ -522,7 +496,7 @@ class MockCommandQueueHw : public CommandQueueHw<GfxFamily> {
         return BaseClass::isGpgpuSubmissionForBcsRequired(queueBlocked, timestampPacketDependencies, containsCrossEngineDependency, textureCacheFlushRequired);
     }
 
-    bool waitForTimestamps(Range<CopyEngineState> copyEnginesToWait, WaitStatus &status, TimestampPacketContainer *mainContainer, TimestampPacketContainer *deferredContainer) override {
+    bool waitForTimestamps(std::span<CopyEngineState> copyEnginesToWait, WaitStatus &status, TimestampPacketContainer *mainContainer, TimestampPacketContainer *deferredContainer) override {
         waitForTimestampsCalled = true;
 
         latestWaitForTimestampsStatus = BaseClass::waitForTimestamps(copyEnginesToWait, status, mainContainer, deferredContainer);
@@ -530,7 +504,7 @@ class MockCommandQueueHw : public CommandQueueHw<GfxFamily> {
         return latestWaitForTimestampsStatus;
     }
 
-    bool isCompleted(TaskCountType gpgpuTaskCount, const Range<CopyEngineState> &bcsStates) override {
+    bool isCompleted(TaskCountType gpgpuTaskCount, const std::span<CopyEngineState> &bcsStates) override {
         isCompletedCalled++;
 
         return CommandQueue::isCompleted(gpgpuTaskCount, bcsStates);
@@ -574,6 +548,7 @@ class MockCommandQueueHw : public CommandQueueHw<GfxFamily> {
     bool useBcsCsrOnNotifyEnabled = false;
     bool waitForTimestampsCalled = false;
     bool latestWaitForTimestampsStatus = false;
+    bool recordedSkipWait = false;
     int setQueueBlocked = -1;
     int forceGpgpuSubmissionForBcsRequired = -1;
     mutable bool isBlitEnqueueImageAllowed = false;
