@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020 Intel Corporation
+ * Copyright (C) 2020-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -12,6 +12,7 @@
 
 namespace NEO {
 class ExecutionEnvironment;
+class ClExecutionEnvironment;
 class ClDevice;
 class MemoryManager;
 class MockMemoryManager;
@@ -20,6 +21,7 @@ struct UltDeviceFactory;
 
 struct UltClDeviceFactory {
     UltClDeviceFactory(uint32_t rootDevicesCount, uint32_t subDevicesCount);
+    UltClDeviceFactory(uint32_t rootDevicesCount, uint32_t subDevicesCount, ClExecutionEnvironment *clExecutionEnvironment);
     ~UltClDeviceFactory();
 
     std::unique_ptr<UltDeviceFactory> pUltDeviceFactory;
