@@ -27,7 +27,7 @@ struct IOQTaskTestsMt : public HelloWorldTest<HelloWorldFixtureFactory> {
         CommandStreamFixture::setUp(pCmdQ);
         ASSERT_NE(nullptr, pCS);
         IndirectHeapFixture::setUp(pCmdQ);
-        KernelFixture::setUp(pClDevice, kernelName);
+        KernelFixture::setUp(pClDevice);
         ASSERT_NE(nullptr, pKernel);
 
         auto retVal = CL_INVALID_VALUE;
