@@ -11,6 +11,8 @@
 #include <map>
 #include <string>
 
+extern PRODUCT_FAMILY productFamily;
+
 struct MockIgaWrapper : public IgaWrapper {
     bool tryDisassembleGenISA(const void *kernelPtr, uint32_t kernelSize, std::string &out) override {
         out = asmToReturn;
@@ -31,17 +33,19 @@ struct MockIgaWrapper : public IgaWrapper {
     }
 
     void setProductFamily(PRODUCT_FAMILY product) override {
+        IgaWrapper::setProductFamily(product);
         setProductFamilyWasCalled = true;
     }
 
-    bool isKnownPlatform() const override {
-        return isKnownPlatformReturnValue;
-    }
-
     bool tryLoadIga() override {
         return true;
     }
 
+    bool isValidPlatform() {
+        setProductFamily(productFamily);
+        return isKnownPlatform();
+    }
+
     std::string asmToReturn;
     std::string binaryToReturn;
     std::string receivedAsm;
@@ -49,7 +53,6 @@ struct MockIgaWrapper : public IgaWrapper {
 
     bool disasmWasCalled = false;
     bool asmWasCalled = false;
-    bool isKnownPlatformReturnValue = false;
     bool setProductFamilyWasCalled = false;
     bool setGfxCoreWasCalled = false;
 };
