@@ -10,24 +10,21 @@
 #include "shared/offline_compiler/source/ocloc_api.h"
 #include "shared/offline_compiler/source/ocloc_arg_helper.h"
 #include "shared/source/compiler_interface/compiler_options.h"
-#include "shared/source/device_binary_format/ar/ar.h"
 #include "shared/source/device_binary_format/ar/ar_decoder.h"
 #include "shared/source/device_binary_format/ar/ar_encoder.h"
 #include "shared/source/device_binary_format/elf/elf_decoder.h"
 #include "shared/source/device_binary_format/elf/ocl_elf.h"
 #include "shared/source/helpers/compiler_product_helper.h"
-#include "shared/source/helpers/gfx_core_helper.h"
 #include "shared/source/helpers/product_config_helper.h"
 #include "shared/source/release_helper/release_helper.h"
 #include "shared/test/common/helpers/gtest_helpers.h"
-#include "shared/test/common/helpers/stdout_capture.h"
+#include "shared/test/common/helpers/stream_capture.h"
 #include "shared/test/common/helpers/variable_backup.h"
-#include "shared/test/common/mocks/mock_io_functions.h"
 
 #include "environment.h"
 #include "mock/mock_argument_helper.h"
 #include "mock/mock_offline_compiler.h"
-#include "platforms.h"
+#include "neo_aot_platforms.h"
 
 #include <algorithm>
 #include <filesystem>
@@ -195,10 +192,10 @@ TEST(OclocFatBinaryRequestedFatBinary, givenReleaseOrFamilyAcronymWhenGetAcronym
 
         if (!acronym.empty()) {
             getProductsAcronymsForTarget<AOT::RELEASE>(outRelease, device.release, argHelper.get());
-            EXPECT_TRUE(std::find(outRelease.begin(), outRelease.end(), acronym) != outRelease.end());
+            EXPECT_TRUE(std::find(outRelease.begin(), outRelease.end(), acronym) != outRelease.end()) << acronym.str();
 
             getProductsAcronymsForTarget<AOT::FAMILY>(outFamily, device.family, argHelper.get());
-            EXPECT_TRUE(std::find(outFamily.begin(), outFamily.end(), acronym) != outFamily.end());
+            EXPECT_TRUE(std::find(outFamily.begin(), outFamily.end(), acronym) != outFamily.end()) << acronym.str();
 
             device.deviceAcronyms.clear();
             device.rtlIdAcronyms.clear();
@@ -206,10 +203,10 @@ TEST(OclocFatBinaryRequestedFatBinary, givenReleaseOrFamilyAcronymWhenGetAcronym
             outFamily.clear();
 
             getProductsAcronymsForTarget<AOT::RELEASE>(outRelease, device.release, argHelper.get());
-            EXPECT_FALSE(std::find(outRelease.begin(), outRelease.end(), acronym) != outRelease.end());
+            EXPECT_FALSE(std::find(outRelease.begin(), outRelease.end(), acronym) != outRelease.end()) << acronym.str();
 
             getProductsAcronymsForTarget<AOT::FAMILY>(outFamily, device.family, argHelper.get());
-            EXPECT_FALSE(std::find(outFamily.begin(), outFamily.end(), acronym) != outFamily.end());
+            EXPECT_FALSE(std::find(outFamily.begin(), outFamily.end(), acronym) != outFamily.end()) << acronym.str();
         }
     }
 }
@@ -337,7 +334,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenClosedRangeTooExtensiveWhenProdu
             "-device",
             target};
 
-        StdoutCapture capture;
+        StreamCapture capture;
         capture.captureStdout();
         int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
         auto output = capture.getCapturedStdout();
@@ -398,7 +395,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenTwoTargetsOfProductsWhenFatBinar
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -437,7 +434,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenTwoVersionsOfProductConfigsWhenF
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -471,7 +468,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenProductsAcronymsWithoutDashesWhe
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -510,7 +507,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenBinaryOutputNameOptionWhenBuildi
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -550,7 +547,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenBinaryOutputDirOptionWhenBuildin
             "-device",
             acronymsTarget};
 
-        StdoutCapture capture;
+        StreamCapture capture;
         capture.captureStdout();
         int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
         auto output = capture.getCapturedStdout();
@@ -580,7 +577,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenBinaryOutputDirOptionWhenBuildin
             "-device",
             acronymsTarget};
 
-        StdoutCapture capture;
+        StreamCapture capture;
         capture.captureStdout();
         int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
         auto output = capture.getCapturedStdout();
@@ -691,7 +688,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenTwoTargetsOfReleasesWhenFatBinar
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -733,7 +730,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenTwoTargetsOfFamiliesWhenFatBinar
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -776,7 +773,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenProductsClosedRangeWhenFatBinary
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -815,7 +812,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenProductsClosedRangeWithoutDashes
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -905,7 +902,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenClosedRangeWithOneFamilyBeingGen
             "-device",
             acronymsTarget};
 
-        StdoutCapture capture;
+        StreamCapture capture;
         capture.captureStdout();
         int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
         auto output = capture.getCapturedStdout();
@@ -952,7 +949,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenFamiliesClosedRangeWhenFatBinary
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -986,7 +983,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenOpenRangeFromProductWhenFatBinar
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -996,7 +993,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenOpenRangeFromProductWhenFatBinar
         resString << "Build succeeded for : " << product.str() + ".\n";
     }
 
-    EXPECT_STREQ(output.c_str(), resString.str().c_str());
+    EXPECT_STREQ(output.c_str(), resString.str().c_str()) << ConstStringRef(" ").join(argv);
 }
 
 TEST_F(OclocFatBinaryProductAcronymsTests, givenOpenRangeFromProductWithoutDashesWhenFatBinaryBuildIsInvokedThenSuccessIsReturned) {
@@ -1024,7 +1021,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenOpenRangeFromProductWithoutDashe
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -1059,7 +1056,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenOpenRangeToProductWhenFatBinaryB
         "-device",
         acronymsTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -1127,7 +1124,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenFullRangeWhenGetProductsForRange
         GTEST_SKIP();
     }
     auto product = aotInfos[0].aotConfig.value;
-    uint32_t productTo = AOT::CONFIG_MAX_PLATFORM;
+    uint32_t productTo = AOT::getConfixMaxPlatform();
     --productTo;
     auto got = NEO::getProductsForRange(product, static_cast<AOT::PRODUCT_CONFIG>(productTo), oclocArgHelperWithoutInput.get());
 
@@ -1165,7 +1162,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenOnlyRtlIdAcronymsForConfigWhenGe
     std::string tmpStr("tmp");
     aotInfo.rtlIdAcronyms.push_back(ConstStringRef(tmpStr));
 
-    uint32_t productTo = AOT::CONFIG_MAX_PLATFORM;
+    uint32_t productTo = AOT::getConfixMaxPlatform();
     --productTo;
     auto acronyms = NEO::getProductsForRange(product, static_cast<AOT::PRODUCT_CONFIG>(productTo), oclocArgHelperWithoutInput.get());
 
@@ -1202,7 +1199,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenOpenRangeFromReleaseWhenFatBinar
         "-device",
         releasesTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -1235,7 +1232,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenDeviceOptionsForNotCompiledDevic
         enabledProductsAcronyms[2].str(),
         "deviceOptions"};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     [[maybe_unused]] int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -1280,7 +1277,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenDeviceOptionsForCompiledDeviceAn
         enabledProductsAcronyms[0].str(),
         "deviceOptions"};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     [[maybe_unused]] int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -1333,7 +1330,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenDeviceOptionsForMultipleDevicesS
         productsForDeviceOptions.str().c_str(),
         "deviceOptions"};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     [[maybe_unused]] int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -1374,7 +1371,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenOpenRangeToReleaseWhenFatBinaryB
         "-device",
         releasesTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -1560,7 +1557,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenOpenRangeFromFamilyWhenFatBinary
         "-device",
         familiesTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -1602,7 +1599,7 @@ TEST_F(OclocFatBinaryProductAcronymsTests, givenOpenRangeToFamilyWhenFatBinaryBu
         "-device",
         familiesTarget};
 
-    StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     int retVal = buildFatBinary(argv, oclocArgHelperWithoutInput.get());
     auto output = capture.getCapturedStdout();
@@ -1750,7 +1747,7 @@ TEST_F(OclocFatBinaryTest, givenDeviceFlagWithoutConsecutiveArgumentWhenBuilding
         "ocloc",
         "-device"};
 
-    ::StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     const auto result = buildFatBinary(args, &mockArgHelper);
     const auto output{capture.getCapturedStdout()};
@@ -1775,7 +1772,7 @@ TEST_F(OclocFatBinaryTest, givenFlagsWhichRequireMoreArgsWithoutThemWhenBuilding
             devices,
             flag};
 
-        ::StdoutCapture capture;
+        StreamCapture capture;
         capture.captureStdout();
         const auto result = buildFatBinary(args, &mockArgHelper);
         const auto output{capture.getCapturedStdout()};
@@ -1945,7 +1942,7 @@ TEST_F(OclocFatBinaryTest, givenEmptyFileWhenAppendingGenericIrThenInvalidFileIs
     mockArgHelperFilesMap[emptyFile] = "";
     mockArgHelper.shouldLoadDataFromFileReturnZeroSize = true;
 
-    ::StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     const auto errorCode{appendGenericIr(ar, emptyFile, &mockArgHelper, dummyOptions)};
     const auto output{capture.getCapturedStdout()};
@@ -1960,7 +1957,7 @@ TEST_F(OclocFatBinaryTest, givenInvalidIrFileWhenAppendingGenericIrThenInvalidFi
     std::string dummyOptions{"-cl-opt-disable "};
     mockArgHelperFilesMap[dummyFile] = "This is not IR!";
 
-    ::StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     const auto errorCode{appendGenericIr(ar, dummyFile, &mockArgHelper, dummyOptions)};
     const auto output{capture.getCapturedStdout()};
@@ -2019,7 +2016,7 @@ TEST_F(OclocTest, givenPreviousCompilationSuccessAndFailingBuildWhenBuildingFatb
     const auto mockArgHelper = mockOfflineCompiler.uniqueHelper.get();
     const auto deviceConfig = getDeviceConfig(mockOfflineCompiler, mockArgHelper);
 
-    ::StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     const int previousReturnValue{OCLOC_SUCCESS};
     const auto buildResult = buildFatBinaryForTarget(previousReturnValue, argv, pointerSize, ar, &mockOfflineCompiler, mockArgHelper, deviceConfig);
@@ -2066,7 +2063,7 @@ TEST_F(OclocTest, givenNonEmptyBuildLogWhenBuildingFatbinaryForTargetThenBuildLo
     const auto mockArgHelper = mockOfflineCompiler.uniqueHelper.get();
     const auto deviceConfig = getDeviceConfig(mockOfflineCompiler, mockArgHelper);
 
-    ::StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     const int previousReturnValue{OCLOC_SUCCESS};
     const auto buildResult = buildFatBinaryForTarget(previousReturnValue, argv, pointerSize, ar, &mockOfflineCompiler, mockArgHelper, deviceConfig);
@@ -2080,7 +2077,7 @@ TEST_F(OclocTest, givenNonEmptyBuildLogWhenBuildingFatbinaryForTargetThenBuildLo
 }
 
 TEST_F(OclocTest, givenNonEmptyBuildLogWhenBuildingFatbinaryForTargetThenBuildLogIsNotPrinted) {
-    ::StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
 
     const std::vector<std::string> argv = {
@@ -2120,7 +2117,7 @@ TEST_F(OclocTest, givenListOfDeprecatedAcronymsThenUseThemAsIs) {
         return;
     }
 
-    ::StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
 
     std::vector<std::string> argv = {
@@ -2180,7 +2177,7 @@ TEST_F(OclocTest, givenListOfGenericAcronymsThenUseThemAsIs) {
         GTEST_SKIP();
     }
 
-    ::StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
 
     std::vector<std::string> argv = {
@@ -2252,7 +2249,7 @@ TEST_F(OclocTest, givenQuietModeWhenBuildingFatbinaryForTargetThenNothingIsPrint
     const auto mockArgHelper = mockOfflineCompiler.uniqueHelper.get();
     const auto deviceConfig = getDeviceConfig(mockOfflineCompiler, mockArgHelper);
 
-    ::StdoutCapture capture;
+    StreamCapture capture;
     capture.captureStdout();
     const int previousReturnValue{OCLOC_SUCCESS};
     const auto buildResult = buildFatBinaryForTarget(previousReturnValue, argv, pointerSize, ar, &mockOfflineCompiler, mockArgHelper, deviceConfig);
