@@ -1,11 +1,12 @@
 /*
- * Copyright (C) 2018-2022 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #include "shared/test/common/helpers/gtest_helpers.h"
+#include "shared/test/common/helpers/stream_capture.h"
 #include "shared/test/common/libult/signal_utils.h"
 
 #include "gtest/gtest.h"
@@ -13,6 +14,7 @@
 
 #include <string>
 
+StreamCapture capture;
 extern int generateSegfaultWithSafetyGuard(SegfaultHelper *segfaultHelper);
 
 int main(int argc, char **argv) {
@@ -31,25 +33,28 @@ int main(int argc, char **argv) {
         return sigOut;
 
     retVal = RUN_ALL_TESTS();
+    cleanupSignals();
 
     return retVal;
 }
 
 void captureAndCheckStdOut() {
-    std::string callstack = ::testing::internal::GetCapturedStdout();
+    std::string callstack = capture.getCapturedStdout();
 
     EXPECT_TRUE(hasSubstr(callstack, std::string("Callstack")));
     EXPECT_TRUE(hasSubstr(callstack, std::string("cloc_segfault_test")));
-    EXPECT_TRUE(hasSubstr(callstack, std::string("generateSegfaultWithSafetyGuard")));
+    EXPECT_TRUE(hasSubstr(callstack, std::string("generateSegfaultWithSafetyGuard"))) << callstack;
 }
 
 TEST(SegFault, givenCallWithSafetyGuardWhenSegfaultHappensThenCallstackIsPrintedToStdOut) {
 #if !defined(SKIP_SEGFAULT_TEST)
-    ::testing::internal::CaptureStdout();
+    capture.captureStdout();
     SegfaultHelper segfault;
     segfault.segfaultHandlerCallback = captureAndCheckStdOut;
 
     auto retVal = generateSegfaultWithSafetyGuard(&segfault);
     EXPECT_EQ(-60, retVal);
+#else
+    GTEST_SKIP();
 #endif
 }
