@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2022 Intel Corporation
+ * Copyright (C) 2018-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -17,7 +17,7 @@
 class SegfaultHelper {
   public:
     int NO_SANITIZE generateSegfault() {
-        int *pointer = reinterpret_cast<int *>(0);
+        volatile int *pointer = reinterpret_cast<int *>(0);
         *pointer = 0; // NOLINT(clang-analyzer-core.NullDereference)
         return 0;
     }
