@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2021 Intel Corporation
+ * Copyright (C) 2018-2022 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -14,6 +14,6 @@ namespace NEO {
 
 class MockPerformanceCountersWin : public PerformanceCountersWin {
   public:
-    MockPerformanceCountersWin(Device *device);
+    MockPerformanceCountersWin();
 };
 } // namespace NEO
