@@ -1,17 +1,24 @@
 /*
- * Copyright (C) 2022 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
-#include "opencl/test/unit_test/mocks/mock_program.h"
+
 #include "opencl/test/unit_test/program/program_tests.h"
 
+namespace NEO {
+struct KernelInfo;
+class MockGraphicsAllocation;
+class MockProgram;
+} // namespace NEO
+
 using namespace NEO;
 
 class MockBuffer;
+
 class ProgramWithZebinFixture : public ProgramTests {
   public:
     std::unique_ptr<MockProgram> program;
@@ -24,5 +31,6 @@ class ProgramWithZebinFixture : public ProgramTests {
     void TearDown() override;
     void addEmptyZebin(MockProgram *program);
     void populateProgramWithSegments(MockProgram *program);
-    ~ProgramWithZebinFixture() override = default;
+    ~ProgramWithZebinFixture() override;
+    ProgramWithZebinFixture();
 };
