@@ -1,18 +1,20 @@
 /*
- * Copyright (C) 2022 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
+#include "shared/source/device_binary_format/zebin/debug_zebin.h"
 #include "shared/test/common/mocks/mock_modules_zebin.h"
-#include "shared/test/common/mocks/mock_source_level_debugger.h"
 #include "shared/test/common/test_macros/test.h"
 
-#include "opencl/test/unit_test/mocks/mock_buffer.h"
+#include "opencl/test/unit_test/mocks/mock_cl_device.h"
+#include "opencl/test/unit_test/mocks/mock_program.h"
 #include "opencl/test/unit_test/program/program_with_zebin.h"
 
 #include <memory>
+
 using namespace NEO;
 
 TEST_F(ProgramWithZebinFixture, givenNoZebinThenSegmentsAreEmpty) {
@@ -34,7 +36,7 @@ TEST_F(ProgramWithZebinFixture, givenZebinSegmentsThenSegmentsArePopulated) {
     populateProgramWithSegments(program.get());
     auto segments = program->getZebinSegments(rootDeviceIndex);
 
-    auto checkGPUSeg = [](NEO::GraphicsAllocation *alloc, NEO::Debug::Segments::Segment segment) {
+    auto checkGPUSeg = [](NEO::GraphicsAllocation *alloc, NEO::Zebin::Debug::Segments::Segment segment) {
         EXPECT_EQ(static_cast<uintptr_t>(alloc->getGpuAddress()), segment.address);
         EXPECT_EQ(static_cast<size_t>(alloc->getUnderlyingBufferSize()), segment.size);
     };
@@ -116,7 +118,7 @@ TEST_F(ProgramWithZebinFixture, givenEmptyDebugDataAndZebinBinaryFormatThenCreat
     EXPECT_EQ(numDevices * sizeof(debugData), retData);
 }
 
-TEST_F(ProgramWithZebinFixture, givenZebinFormatAndDebuggerNotAvailableWhenNotifyingDebuggerThenCreateDebugZebinIsCalled) {
+TEST_F(ProgramWithZebinFixture, givenZebinFormatAndDebuggerNotAvailableWhenCreatingDebugDataThenCreateDebugZebinIsCalled) {
     pClDevice->getExecutionEnvironment()->rootDeviceEnvironments[pDevice->getRootDeviceIndex()]->debugger.reset(nullptr);
 
     addEmptyZebin(program.get());
@@ -125,31 +127,10 @@ TEST_F(ProgramWithZebinFixture, givenZebinFormatAndDebuggerNotAvailableWhenNotif
     buildInfo.debugDataSize = 0u;
     buildInfo.debugData.reset(nullptr);
     for (auto &device : program->getDevices()) {
-        program->notifyDebuggerWithDebugData(device);
+        program->createDebugData(device);
     }
     EXPECT_TRUE(program->wasCreateDebugZebinCalled);
     EXPECT_FALSE(program->wasProcessDebugDataCalled);
     EXPECT_NE(nullptr, program->buildInfos[rootDeviceIndex].debugData);
     EXPECT_GT(program->buildInfos[rootDeviceIndex].debugDataSize, 0u);
-}
-
-TEST_F(ProgramWithZebinFixture, givenZebinFormatAndDebuggerAvailableWhenNotifyingDebuggerThenCreateDebugZebinIsCalledAndDebuggerNotified) {
-    MockSourceLevelDebugger *sourceLevelDebugger = new MockSourceLevelDebugger;
-    sourceLevelDebugger->setActive(true);
-    pClDevice->getExecutionEnvironment()->rootDeviceEnvironments[pDevice->getRootDeviceIndex()]->debugger.reset(sourceLevelDebugger);
-
-    addEmptyZebin(program.get());
-    populateProgramWithSegments(program.get());
-    auto &buildInfo = program->buildInfos[rootDeviceIndex];
-    buildInfo.debugDataSize = 0u;
-    buildInfo.debugData.reset(nullptr);
-    for (auto &device : program->getDevices()) {
-        program->notifyDebuggerWithDebugData(device);
-    }
-    EXPECT_TRUE(program->wasCreateDebugZebinCalled);
-    EXPECT_FALSE(program->wasProcessDebugDataCalled);
-    EXPECT_NE(nullptr, program->buildInfos[rootDeviceIndex].debugData);
-    EXPECT_GT(program->buildInfos[rootDeviceIndex].debugDataSize, 0u);
-
-    EXPECT_EQ(1u, sourceLevelDebugger->notifyKernelDebugDataCalled);
 }
\ No newline at end of file
