@@ -1,15 +1,12 @@
 /*
- * Copyright (C) 2018-2022 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
-#include "shared/source/command_stream/command_stream_receiver.h"
 #include "shared/source/compiler_interface/oclc_extensions.h"
-#include "shared/source/device/device.h"
 #include "shared/source/helpers/string.h"
-#include "shared/test/common/fixtures/memory_management_fixture.h"
 #include "shared/test/common/helpers/debug_manager_state_restore.h"
 #include "shared/test/common/helpers/gtest_helpers.h"
 #include "shared/test/common/mocks/mock_device.h"
@@ -21,7 +18,6 @@
 #include "opencl/test/unit_test/mocks/mock_cl_device.h"
 #include "opencl/test/unit_test/mocks/mock_context.h"
 #include "opencl/test/unit_test/mocks/mock_platform.h"
-#include "opencl/test/unit_test/mocks/mock_sharing_factory.h"
 
 #include "gtest/gtest.h"
 
@@ -246,7 +242,7 @@ TEST(Context, givenMockSharingBuilderWhenContextWithInvalidPropertiesThenContext
 
 TEST(SharingFactoryTests, givenDisabledFormatQueryAndFactoryWithSharingWhenAskedForExtensionThenFormatQueryExtensionIsNotReturned) {
     DebugManagerStateRestore restorer;
-    DebugManager.flags.EnableFormatQuery.set(false);
+    debugManager.flags.EnableFormatQuery.set(false);
 
     SharingFactoryStateRestore stateRestore;
     stateRestore.clearCurrentState();
@@ -258,7 +254,7 @@ TEST(SharingFactoryTests, givenDisabledFormatQueryAndFactoryWithSharingWhenAsked
 
 TEST(SharingFactoryTests, givenEnabledFormatQueryAndFactoryWithSharingWhenAskedForExtensionThenFormatQueryExtensionIsReturned) {
     DebugManagerStateRestore restorer;
-    DebugManager.flags.EnableFormatQuery.set(true);
+    debugManager.flags.EnableFormatQuery.set(true);
 
     SharingFactoryStateRestore stateRestore;
     stateRestore.clearCurrentState();
@@ -270,7 +266,7 @@ TEST(SharingFactoryTests, givenEnabledFormatQueryAndFactoryWithSharingWhenAskedF
 
 TEST(SharingFactoryTests, givenEnabledFormatQueryAndFactoryWithNoSharingsWhenAskedForExtensionThenNoExtensionIsReturned) {
     DebugManagerStateRestore restorer;
-    DebugManager.flags.EnableFormatQuery.set(true);
+    debugManager.flags.EnableFormatQuery.set(true);
 
     SharingFactoryStateRestore sharingFactory;
 
