@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -32,6 +32,10 @@
 
 #include <va/va_backend.h>
 
+namespace NEO {
+class Context;
+} // namespace NEO
+
 using namespace NEO;
 
 class VaSharingTests : public ::testing::Test, public PlatformFixture {
@@ -281,7 +285,7 @@ TEST_F(VaSharingTests, givenSupportedFourccFormatWhenIsSupportedPlanarFormatThen
     EXPECT_TRUE(VASurface::isSupportedPlanarFormat(VA_FOURCC_P016));
     EXPECT_TRUE(VASurface::isSupportedPlanarFormat(VA_FOURCC_NV12));
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
     EXPECT_TRUE(VASurface::isSupportedPlanarFormat(VA_FOURCC_RGBP));
 }
 
@@ -303,7 +307,7 @@ TEST_F(VaSharingTests, givenSupportedPlanarFormatWhenIsSupportedPackedFormatThen
 
 TEST_F(VaSharingTests, givenValidYUY2SurfaceWhenGetSurfaceDescriptionThenCLSuccessIsReturnedAndDataAreSet) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
     vaSharing->sharingFunctions.haveExportSurfaceHandle = true;
 
     vaSharing->sharingFunctions.mockVaSurfaceDesc.fourcc = VA_FOURCC_YUY2;
@@ -326,7 +330,7 @@ TEST_F(VaSharingTests, givenValidYUY2SurfaceWhenGetSurfaceDescriptionThenCLSucce
 
 TEST_F(VaSharingTests, givenValidY210SurfaceWhenGetSurfaceDescriptionThenCLSuccessIsReturnedAndDataAreSet) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
     vaSharing->sharingFunctions.haveExportSurfaceHandle = true;
 
     vaSharing->sharingFunctions.mockVaSurfaceDesc.fourcc = VA_FOURCC_Y210;
@@ -349,7 +353,7 @@ TEST_F(VaSharingTests, givenValidY210SurfaceWhenGetSurfaceDescriptionThenCLSucce
 
 TEST_F(VaSharingTests, givenValidYUY2SurfaceWithInvalidPlaneNumberWhenGetSurfaceDescriptionThenFailIsReturned) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
     vaSharing->sharingFunctions.haveExportSurfaceHandle = true;
 
     vaSharing->sharingFunctions.mockVaSurfaceDesc.fourcc = VA_FOURCC_YUY2;
@@ -368,7 +372,7 @@ TEST_F(VaSharingTests, givenValidYUY2SurfaceWithInvalidPlaneNumberWhenGetSurface
 
 TEST_F(VaSharingTests, givenValidY210SurfaceWithInvalidPlaneNumberWhenGetSurfaceDescriptionThenFailIsReturned) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
     vaSharing->sharingFunctions.haveExportSurfaceHandle = true;
 
     vaSharing->sharingFunctions.mockVaSurfaceDesc.fourcc = VA_FOURCC_Y210;
@@ -387,7 +391,7 @@ TEST_F(VaSharingTests, givenValidY210SurfaceWithInvalidPlaneNumberWhenGetSurface
 
 TEST_F(VaSharingTests, givenValidPlanarSurfaceWithPlaneSetWhenGetSurfaceDescriptionThenCLSuccessIsReturnedAndDataAreSet) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
     vaSharing->sharingFunctions.haveExportSurfaceHandle = true;
 
     vaSharing->sharingFunctions.mockVaSurfaceDesc.fourcc = VA_FOURCC_NV12;
@@ -533,7 +537,7 @@ TEST_F(VaSharingTests, givenValidPlanarSurfaceWithPlaneSetWhenApplyPlanarOptions
     // RGBP part
 
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
 
     surfaceInfo.imageFourcc = VA_FOURCC_RGBP;
 
@@ -596,7 +600,7 @@ TEST_F(VaSharingTests, givenValidSurfaceWithPlaneSetWhenApplyPlaneSettingsThenPr
     EXPECT_EQ(surfaceInfo.imgInfo.yOffsetForUVPlane, static_cast<uint32_t>(surfaceInfo.imageOffset / surfaceInfo.imagePitch));
 
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
 
     surfaceInfo.imageFourcc = VA_FOURCC_RGBP;
 
@@ -648,7 +652,7 @@ TEST_F(VaSharingTests, givenInvalidPlaneInputWhenVaSurfaceIsCreatedThenInvalidVa
 
 TEST_F(VaSharingTests, givenValidPlaneInputWhenVaSurfaceIsCreatedAndDebugFlagEnabledThenCLSuccessIsReturned) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
 
     vaSharing->sharingFunctions.mockVaSurfaceDesc.fourcc = VA_FOURCC_RGBP;
     vaSharing->sharingFunctions.mockVaSurfaceDesc.objects[1] = {8, 98304, I915_FORMAT_MOD_Y_TILED};
@@ -1052,7 +1056,7 @@ TEST_F(VaSharingTests, givenNotSupportedFormatWhenCreatingSharedVaSurfaceThenErr
 
 TEST_F(VaSharingTests, givenEnabledExtendedVaFormatsAndRGBPFormatWhenCreatingSharedVaSurfaceForPlane0ThenCorrectFormatIsUsedByImageAndGMM) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
 
     vaSharing->sharingFunctions.mockVaSurfaceDesc.fourcc = VA_FOURCC_RGBP;
     vaSharing->sharingFunctions.mockVaSurfaceDesc.objects[1] = {8, 98304, I915_FORMAT_MOD_Y_TILED};
@@ -1076,7 +1080,7 @@ TEST_F(VaSharingTests, givenEnabledExtendedVaFormatsAndRGBPFormatWhenCreatingSha
 
 TEST_F(VaSharingTests, givenEnabledExtendedVaFormatsAndRGBPFormatWhenCreatingSharedVaSurfaceForPlane1ThenCorrectFormatIsUsedByImageAndGMM) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
 
     vaSharing->sharingFunctions.mockVaSurfaceDesc.fourcc = VA_FOURCC_RGBP;
     vaSharing->sharingFunctions.mockVaSurfaceDesc.objects[1] = {8, 98304, I915_FORMAT_MOD_Y_TILED};
@@ -1100,7 +1104,7 @@ TEST_F(VaSharingTests, givenEnabledExtendedVaFormatsAndRGBPFormatWhenCreatingSha
 
 TEST_F(VaSharingTests, givenEnabledExtendedVaFormatsAndRGBPFormatWhenCreatingSharedVaSurfaceForPlane2ThenCorrectFormatIsUsedByImageAndGMM) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
 
     vaSharing->sharingFunctions.mockVaSurfaceDesc.fourcc = VA_FOURCC_RGBP;
     vaSharing->sharingFunctions.mockVaSurfaceDesc.objects[1] = {8, 98304, I915_FORMAT_MOD_Y_TILED};
@@ -1124,7 +1128,7 @@ TEST_F(VaSharingTests, givenEnabledExtendedVaFormatsAndRGBPFormatWhenCreatingSha
 
 TEST_F(VaSharingTests, givenMockVaWithExportSurfaceHandlerAndRGBPWhenVaSurfaceIsCreatedThenCallHandlerWithDrmPrime2ToGetSurfaceFormatsInDescriptor) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
     vaSharing->sharingFunctions.haveExportSurfaceHandle = true;
 
     vaSharing->sharingFunctions.mockVaSurfaceDesc.fourcc = VA_FOURCC_RGBP;
@@ -1177,7 +1181,7 @@ TEST_F(VaSharingTests, givenMockVaWithExportSurfaceHandlerAndRGBPWhenVaSurfaceIs
 
 TEST_F(VaSharingTests, givenEnabledExtendedVaFormatsAndNV12FormatWhenCreatingSharedVaSurfaceForPlane0ThenCorrectFormatIsUsedByImageAndGMM) {
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
 
     vaSharing->sharingFunctions.derivedImageFormatBpp = 12;
     vaSharing->sharingFunctions.derivedImageFormatFourCC = VA_FOURCC_NV12;
@@ -1345,7 +1349,7 @@ TEST(VaSurface, givenInvalidPlaneOrFlagsWhenValidatingInputsThenTrueIsReturned)
 TEST(VaSurface, givenNotSupportedVaFormatsWhenCheckingIfSupportedThenFalseIsReturned) {
     EXPECT_FALSE(VASurface::isSupportedFourCCTwoPlaneFormat(VA_FOURCC_NV11));
     DebugManagerStateRestore restore;
-    DebugManager.flags.EnableExtendedVaFormats.set(true);
+    debugManager.flags.EnableExtendedVaFormats.set(true);
     EXPECT_FALSE(VASurface::isSupportedFourCCThreePlaneFormat(VA_FOURCC_NV11));
     EXPECT_EQ(nullptr, VASurface::getExtendedSurfaceFormatInfo(VA_FOURCC_NV11));
 }
