@@ -5,14 +5,13 @@
  *
  */
 
+#include "shared/source/xe_hpc_core/hw_cmds_xe_hpc_core_base.h"
 #include "shared/test/common/test_macros/header/per_product_test_definitions.h"
 #include "shared/test/common/test_macros/test.h"
 
 #include "opencl/source/platform/platform_info.h"
 #include "opencl/test/unit_test/fixtures/platform_fixture.h"
 
-#include "hw_cmds_xe_hpc_core_base.h"
-
 using namespace NEO;
 
 struct XeHpcCorePlatformCaps : public PlatformFixture, public ::testing::Test {
