@@ -1,10 +1,11 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
+#include <cstdint>
 #include <fstream>
 #include <iomanip>
 #include <iostream>
@@ -75,7 +76,7 @@ std::string parseToCharArray(std::unique_ptr<uint8_t[]> &binary, size_t size, st
     out << std::endl;
     out << "    \"";
     deviceIp != "" ? out << deviceIp << "_" << builtinName : out << builtinName;
-    isSpirV ? out << ".builtin_kernel.bc\"," : out << ".builtin_kernel.bin\",";
+    isSpirV ? out << ".builtin_kernel.spv\"," : out << ".builtin_kernel.bin\",";
     out << std::endl;
     out << "    (const char *)" << builtinName;
     if (deviceIpPresent) {
