@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -45,7 +45,7 @@ int BinaryDecoder::decode() {
     return processBinary(ptr, size, ptmFile);
 }
 
-void BinaryDecoder::dumpField(const void *&binaryPtr, const PTField &field, std::ostream &ptmFile) {
+void BinaryDecoder::dumpField(const void *&binaryPtr, const PTField &field, std::stringstream &ptmFile) {
     ptmFile << '\t' << static_cast<int>(field.size) << ' ';
     switch (field.size) {
     case 1: {
@@ -282,7 +282,7 @@ void BinaryDecoder::parseTokens() {
 }
 
 void BinaryDecoder::printHelp() {
-    argHelper->printf(R"===(Disassembles Intel Compute GPU device binary files.
+    argHelper->printf(R"OCLOC_HELP(Disassembles Intel Compute GPU device binary files.
 Output of such operation is a set of files that can be later used to
 reassemble back a valid Intel Compute GPU device binary (using ocloc 'asm'
 command). This set of files contains:
@@ -325,16 +325,18 @@ Usage: ocloc disasm -file <file> [-patch <patchtokens_dir>] [-dump <dump_dir>] [
   -ignore_isa_padding       Ignores Kernel Heap padding - Kernel Heap binary
                             will be saved without padding.
 
+  -v                        Verbose mode.
+
   --help                    Print this usage message.
 
 Examples:
   Disassemble Intel Compute GPU device binary
     ocloc disasm -file source_file_Gen9core.bin
-)===",
+)OCLOC_HELP",
                       argHelper->createStringForArgs(argHelper->productConfigHelper->getDeviceAcronyms()).c_str());
 }
 
-int BinaryDecoder::processBinary(const void *&ptr, size_t sectionSize, std::ostream &ptmFile) {
+int BinaryDecoder::processBinary(const void *&ptr, size_t sectionSize, std::stringstream &ptmFile) {
     ptmFile << "ProgramBinaryHeader:\n";
     uint32_t numberOfKernels = 0, patchListSize = 0, device = 0;
     for (const auto &v : programHeader.fields) {
@@ -360,7 +362,9 @@ int BinaryDecoder::processBinary(const void *&ptr, size_t sectionSize, std::ostr
         processKernel(ptr, sectionSize, ptmFile);
     }
 
-    argHelper->saveOutput(pathToDump + "PTM.txt", ptmFile);
+    auto ptmFileString = ptmFile.str();
+
+    argHelper->saveOutput(pathToDump + "PTM.txt", ptmFileString.c_str(), ptmFileString.length() + 1);
     return 0;
 }
 
@@ -371,7 +375,7 @@ void BinaryDecoder::validateLoadedKernelData(KernelSizeData kernelLoadedData, si
     }
 }
 
-void BinaryDecoder::processKernel(const void *&ptr, size_t sectionSize, std::ostream &ptmFile) {
+void BinaryDecoder::processKernel(const void *&ptr, size_t sectionSize, std::stringstream &ptmFile) {
     KernelSizeData kernelPatchListSize{"PatchListSize", 0u},
         kernelNameSize{"KernelNameSize", 0u},
         kernelHeapSize{"KernelHeapSize", 0u},
@@ -453,7 +457,7 @@ void BinaryDecoder::processKernel(const void *&ptr, size_t sectionSize, std::ost
     readPatchTokens(ptr, kernelPatchListSize.size, ptmFile);
 }
 
-void BinaryDecoder::readPatchTokens(const void *&patchListPtr, uint32_t patchListSize, std::ostream &ptmFile) {
+void BinaryDecoder::readPatchTokens(const void *&patchListPtr, uint32_t patchListSize, std::stringstream &ptmFile) {
     auto endPatchListPtr = ptrOffset(patchListPtr, patchListSize);
     while (patchListPtr != endPatchListPtr) {
         auto patchTokenPtr = patchListPtr;
@@ -551,6 +555,8 @@ int BinaryDecoder::validateInput(const std::vector<std::string> &args) {
         } else if ("-q" == currArg) {
             argHelper->getPrinterRef().setSuppressMessages(true);
             iga->setMessagePrinter(argHelper->getPrinterRef());
+        } else if ("-v" == currArg) {
+            argHelper->setVerbose(true);
         } else {
             argHelper->printf("Unknown argument %s\n", currArg.c_str());
             return -1;
