@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,7 +8,9 @@
 #pragma once
 
 #include "shared/offline_compiler/source/ocloc_api.h"
+#include "shared/source/compiler_interface/compiler_options.h"
 #include "shared/source/helpers/hw_info.h"
+#include "shared/source/helpers/non_copyable_or_moveable.h"
 #include "shared/source/utilities/arrayref.h"
 #include "shared/source/utilities/const_stringref.h"
 
@@ -29,7 +31,7 @@ namespace NEO {
 
 class CompilerCache;
 class CompilerProductHelper;
-class OclocFclFacade;
+class OclocFclFacadeBase;
 class OclocIgcFacade;
 
 std::string convertToPascalCase(const std::string &inString);
@@ -44,7 +46,24 @@ static_assert(sizeof(NameVersionPair) == sizeof(ocloc_name_version));
 
 const HardwareInfo *getHwInfoForDeprecatedAcronym(const std::string &deviceName);
 
-class OfflineCompiler {
+constexpr bool isIntermediateRepresentation(IGC::CodeType::CodeType_t codeType) {
+    return false == ((IGC::CodeType::oclC == codeType) || (IGC::CodeType::oclCpp == codeType) || (IGC::CodeType::oclGenBin == codeType));
+}
+
+constexpr const char *getFileExtension(IGC::CodeType::CodeType_t codeType) {
+    switch (codeType) {
+    default:
+        return ".bin";
+    case IGC::CodeType::llvmBc:
+        return ".bc";
+    case IGC::CodeType::llvmLl:
+        return ".ll";
+    case IGC::CodeType::spirV:
+        return ".spv";
+    }
+}
+
+class OfflineCompiler : NEO::NonCopyableAndNonMovableClass {
   public:
     static std::vector<NameVersionPair> getExtensions(ConstStringRef product, bool needVersions, OclocArgHelper *helper);
     static std::vector<NameVersionPair> getOpenCLCVersions(ConstStringRef product, OclocArgHelper *helper);
@@ -110,8 +129,6 @@ that correspond to the given name.
 All supported acronyms: %s.
 )OCLOC_HELP";
 
-    OfflineCompiler &operator=(const OfflineCompiler &) = delete;
-    OfflineCompiler(const OfflineCompiler &) = delete;
     MOCKABLE_VIRTUAL ~OfflineCompiler();
 
     bool isQuiet() const {
@@ -158,18 +175,19 @@ All supported acronyms: %s.
     std::string getStringWithinDelimiters(const std::string &src);
     int initialize(size_t numArgs, const std::vector<std::string> &allArgs, bool dumpFiles);
     int parseCommandLine(size_t numArgs, const std::vector<std::string> &allArgs);
+    int parseCommandLineExt(size_t numArgs, const std::vector<std::string> &allArgs, uint32_t &argIndex);
     void setStatelessToStatefulBufferOffsetFlag();
     void appendExtraInternalOptions(std::string &internalOptions);
     void parseDebugSettings();
     void storeBinary(char *&pDst, size_t &dstSize, const void *pSrc, const size_t srcSize);
     MOCKABLE_VIRTUAL int buildSourceCode();
     MOCKABLE_VIRTUAL std::string validateInputType(const std::string &input, bool isLlvm, bool isSpirv);
-    MOCKABLE_VIRTUAL int buildIrBinary();
+    MOCKABLE_VIRTUAL int buildToIrBinary();
     void updateBuildLog(const char *pErrorString, const size_t errorStringSize);
     MOCKABLE_VIRTUAL bool generateElfBinary();
     std::string generateFilePathForIr(const std::string &fileNameBase) {
-        const char *ext = (isSpirV) ? ".spv" : ".bc";
-        return generateFilePath(outputDirectory, fileNameBase, useLlvmText ? ".ll" : ext);
+        const char *ext = getFileExtension(intermediateRepresentation);
+        return generateFilePath(outputDirectory, fileNameBase, ext);
     }
 
     std::string generateOptsSuffix() {
@@ -179,7 +197,8 @@ All supported acronyms: %s.
     }
 
     MOCKABLE_VIRTUAL void writeOutAllFiles();
-    MOCKABLE_VIRTUAL void createDir(const std::string &path);
+    MOCKABLE_VIRTUAL int createDir(const std::string &path);
+    bool useIgcAsFcl();
     void unifyExcludeIrFlags();
     void enforceFormat(std::string &format);
     HardwareInfo hwInfo{};
@@ -200,23 +219,31 @@ All supported acronyms: %s.
     std::string internalOptionsReadFromFile = "";
     std::string formatToEnforce = "";
     std::string addressingMode = "default";
+    CompilerOptions::HeaplessMode heaplessMode = CompilerOptions::HeaplessMode::defaultMode;
     std::string irHash, genHash, dbgHash, elfHash;
     std::string cacheDir;
 
     bool allowCaching = false;
     bool dumpFiles = true;
-    bool useLlvmText = false;
-    bool useLlvmBc = false;
     bool useCppFile = false;
     bool useGenFile = false;
     bool useOptionsSuffix = false;
     bool quiet = false;
     bool onlySpirV = false;
-    bool inputFileLlvm = false;
-    bool inputFileSpirV = false;
+    bool useLlvmTxt = false;
+
+    IGC::CodeType::CodeType_t inputCodeType = IGC::CodeType::oclC;
+
+    bool inputFileLlvm() const {
+        return (IGC::CodeType::llvmBc == inputCodeType) || (IGC::CodeType::llvmLl == inputCodeType);
+    }
+
+    bool inputFileSpirV() const {
+        return IGC::CodeType::spirV == inputCodeType;
+    }
+
     bool outputNoSuffix = false;
     bool forceStatelessToStatefulOptimization = false;
-    bool isSpirV = true;
     bool showHelp = false;
     bool excludeIr = false;
 
@@ -234,13 +261,16 @@ All supported acronyms: %s.
     uint64_t hwInfoConfig = 0u;
 
     std::unique_ptr<OclocIgcFacade> igcFacade;
-    std::unique_ptr<OclocFclFacade> fclFacade;
+    std::unique_ptr<OclocFclFacadeBase> fclFacade;
     std::unique_ptr<CompilerCache> cache;
     std::unique_ptr<CompilerProductHelper> compilerProductHelper;
     std::unique_ptr<ReleaseHelper> releaseHelper;
     IGC::CodeType::CodeType_t preferredIntermediateRepresentation;
+    IGC::CodeType::CodeType_t intermediateRepresentation = IGC::CodeType::undefined;
 
     OclocArgHelper *argHelper = nullptr;
 };
 
+static_assert(NEO::NonCopyableAndNonMovable<OfflineCompiler>);
+
 } // namespace NEO
