@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2023 Intel Corporation
+ * Copyright (C) 2021-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,7 +21,8 @@ enum class QueryType {
     oclDeviceExtensionsWithVersion,
     oclDeviceProfile,
     oclDeviceOpenCLCAllVersions,
-    oclDeviceOpenCLCFeatures
+    oclDeviceOpenCLCFeatures,
+    supportedDevices
 };
 
 inline constexpr ConstStringRef queryNeoRevision = "NEO_REVISION";
@@ -32,5 +33,6 @@ inline constexpr ConstStringRef queryOCLDeviceExtensionsWithVersion = "CL_DEVICE
 inline constexpr ConstStringRef queryOCLDeviceProfile = "CL_DEVICE_PROFILE";
 inline constexpr ConstStringRef queryOCLDeviceOpenCLCAllVersions = "CL_DEVICE_OPENCL_C_ALL_VERSIONS";
 inline constexpr ConstStringRef queryOCLDeviceOpenCLCFeatures = "CL_DEVICE_OPENCL_C_FEATURES";
+inline constexpr ConstStringRef querySupportedDevices = "SUPPORTED_DEVICES";
 }; // namespace Queries
 } // namespace NEO
