@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,6 +8,7 @@
 #pragma once
 
 #include "shared/source/built_ins/sip_kernel_type.h"
+#include "shared/source/helpers/non_copyable_or_moveable.h"
 
 #include <string>
 #include <vector>
@@ -22,14 +23,10 @@ class OsContext;
 
 struct RootDeviceEnvironment;
 
-class SipKernel {
+class SipKernel : NEO::NonCopyableAndNonMovableClass {
   public:
     SipKernel(SipKernelType type, GraphicsAllocation *sipAlloc, std::vector<char> ssah, std::vector<char> binary);
     SipKernel(SipKernelType type, GraphicsAllocation *sipAlloc, std::vector<char> ssah);
-    SipKernel(const SipKernel &) = delete;
-    SipKernel &operator=(const SipKernel &) = delete;
-    SipKernel(SipKernel &&) = delete;
-    SipKernel &operator=(SipKernel &&) = delete;
     virtual ~SipKernel();
 
     SipKernelType getType() const {
@@ -78,6 +75,7 @@ class SipKernel {
     static std::string createHeaderFilename(const std::string &filename);
 
     static bool initHexadecimalArraySipKernel(SipKernelType type, Device &device);
+    static bool initSipKernelFromExternalLib(SipKernelType type, Device &device);
     static void selectSipClassType(std::string &fileName, Device &device);
 
     const std::vector<char> stateSaveAreaHeader;
@@ -87,4 +85,6 @@ class SipKernel {
     SipKernelType type = SipKernelType::count;
 };
 
+static_assert(NEO::NonCopyableAndNonMovable<SipKernel>);
+
 } // namespace NEO
