@@ -112,7 +112,7 @@ CommandContainer::ErrorCode CommandContainer::initialize(Device *device, Allocat
             return ErrorCode::outOfDeviceMemory;
         }
         secondaryCommandStreamForImmediateCmdList = std::make_unique<LinearStream>(cmdBufferAllocationHost->getUnderlyingBuffer(),
-                                                                                   usableSize, this, this->selectedBbCmdSize);
+                                                                                   usableSize, cmdcontainer, this->selectedBbCmdSize);
         secondaryCommandStreamForImmediateCmdList->replaceGraphicsAllocation(cmdBufferAllocationHost);
         cmdBufferAllocations.push_back(cmdBufferAllocationHost);
         addToResidencyContainer(cmdBufferAllocationHost);
@@ -570,9 +570,6 @@ void CommandContainer::storeAllocationAndFlushTagUpdate(GraphicsAllocation *allo
     } else {
         getHeapHelper()->storeHeapAllocation(allocation);
     }
-    if (device->getProductHelper().isDcFlushMitigated()) {
-        this->immediateCmdListCsr->registerDcFlushForDcMitigation();
-    }
     this->immediateCmdListCsr->flushTagUpdate();
 }
 
