@@ -500,6 +500,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     }
 
     bool isTbxMode() const;
+    bool isAubMode() const;
     bool ensureTagAllocationForRootDeviceIndex(uint32_t rootDeviceIndex);
 
     L1CachePolicy *getStoredL1CachePolicy() {
@@ -673,13 +674,12 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     const uint32_t rootDeviceIndex;
     const DeviceBitfield deviceBitfield;
 
-    int8_t lastMediaSamplerConfig = -1;
-
     bool isPreambleSent = false;
     bool isStateSipSent = false;
     bool isEnginePrologueSent = false;
     bool areExceptionsSent = false;
     bool isPerDssBackedBufferSent = false;
+    bool isWalkerWithProfilingEnqueued = false;
     bool gsbaFor32BitProgrammed = false;
     bool gsbaStateDirty = true;
     bool bindingTableBaseAddressRequired = false;
