@@ -43,13 +43,10 @@ class CommandStreamReceiverSimulatedCommonHw : public CommandStreamReceiverHw<Gf
     uint64_t getGTTBits() const {
         return 0u;
     }
-    void initGlobalMMIO();
     uint64_t getPPGTTAdditionalBits(GraphicsAllocation *gfxAllocation);
     void getGTTData(void *memory, AubGTTData &data);
     uint32_t getMemoryBankForGtt() const;
     static const AubMemDump::LrcaHelper &getCsTraits(aub_stream::EngineType engineType);
-    void initEngineMMIO();
-    void submitLRCA(const MiContextDescriptorReg &contextDescriptor);
     void setupContext(OsContext &osContext) override;
     virtual bool expectMemoryEqual(void *gfxAddress, const void *srcAddress, size_t length);
     virtual bool expectMemoryNotEqual(void *gfxAddress, const void *srcAddress, size_t length);
@@ -87,7 +84,5 @@ class CommandStreamReceiverSimulatedCommonHw : public CommandStreamReceiverHw<Gf
         size_t sizeRingBuffer;
         uint32_t tailRingBuffer;
     } engineInfo = {};
-
-    AubMemDump::AubStream *stream;
 };
 } // namespace NEO
