@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,6 +21,7 @@
 #include "shared/source/memory_manager/internal_allocation_storage.h"
 #include "shared/source/memory_manager/memory_manager.h"
 #include "shared/source/os_interface/os_context.h"
+#include "shared/source/os_interface/product_helper.h"
 
 namespace NEO {
 ScratchSpaceControllerXeHPAndLater::ScratchSpaceControllerXeHPAndLater(uint32_t rootDeviceIndex,
@@ -56,13 +57,12 @@ void ScratchSpaceControllerXeHPAndLater::setRequiredScratchSpace(void *sshBaseAd
                                                                  uint32_t offset,
                                                                  uint32_t requiredPerThreadScratchSizeSlot0,
                                                                  uint32_t requiredPerThreadScratchSizeSlot1,
-                                                                 TaskCountType currentTaskCount,
                                                                  OsContext &osContext,
                                                                  bool &stateBaseAddressDirty,
                                                                  bool &vfeStateDirty) {
     setNewSshPtr(sshBaseAddress, vfeStateDirty, offset == 0 ? true : false);
     bool scratchSurfaceDirty = false;
-    prepareScratchAllocation(requiredPerThreadScratchSizeSlot0, requiredPerThreadScratchSizeSlot1, currentTaskCount, osContext, stateBaseAddressDirty, scratchSurfaceDirty, vfeStateDirty);
+    prepareScratchAllocation(requiredPerThreadScratchSizeSlot0, requiredPerThreadScratchSizeSlot1, osContext, stateBaseAddressDirty, scratchSurfaceDirty, vfeStateDirty);
     if (scratchSurfaceDirty) {
         vfeStateDirty = true;
         updateSlots = true;
@@ -89,7 +89,7 @@ void ScratchSpaceControllerXeHPAndLater::programSurfaceStateAtPtr(void *surfaceS
     }
     gfxCoreHelper.setRenderSurfaceStateForScratchResource(*executionEnvironment.rootDeviceEnvironments[rootDeviceIndex],
                                                           surfaceStateForScratchAllocation, computeUnitsUsedForScratch, scratchAllocationAddress, 0,
-                                                          perThreadScratchSize, nullptr, false, scratchType, false, true);
+                                                          perThreadScratchSpaceSlot0Size, nullptr, false, scratchType, false, true);
 
     if (twoSlotScratchSpaceSupported) {
         void *surfaceStateForSlot1Allocation = ptrOffset(surfaceStateForScratchAllocation, singleSurfaceStateSize);
@@ -133,13 +133,12 @@ void ScratchSpaceControllerXeHPAndLater::reserveHeap(IndirectHeap::Type heapType
 void ScratchSpaceControllerXeHPAndLater::programBindlessSurfaceStateForScratch(BindlessHeapsHelper *heapsHelper,
                                                                                uint32_t requiredPerThreadScratchSizeSlot0,
                                                                                uint32_t requiredPerThreadScratchSizeSlot1,
-                                                                               TaskCountType currentTaskCount,
                                                                                OsContext &osContext,
                                                                                bool &stateBaseAddressDirty,
                                                                                bool &vfeStateDirty,
                                                                                NEO::CommandStreamReceiver *csr) {
     bool scratchSurfaceDirty = false;
-    prepareScratchAllocation(requiredPerThreadScratchSizeSlot0, requiredPerThreadScratchSizeSlot1, currentTaskCount, osContext, stateBaseAddressDirty, scratchSurfaceDirty, vfeStateDirty);
+    prepareScratchAllocation(requiredPerThreadScratchSizeSlot0, requiredPerThreadScratchSizeSlot1, osContext, stateBaseAddressDirty, scratchSurfaceDirty, vfeStateDirty);
     if (scratchSurfaceDirty) {
         bindlessSS = heapsHelper->allocateSSInHeap(singleSurfaceStateSize * (twoSlotScratchSpaceSupported ? 2 : 1), scratchSlot0Allocation, BindlessHeapsHelper::specialSsh);
         programSurfaceStateAtPtr(bindlessSS.ssPtr);
@@ -152,7 +151,6 @@ void ScratchSpaceControllerXeHPAndLater::programBindlessSurfaceStateForScratch(B
 
 void ScratchSpaceControllerXeHPAndLater::prepareScratchAllocation(uint32_t requiredPerThreadScratchSizeSlot0,
                                                                   uint32_t requiredPerThreadScratchSizeSlot1,
-                                                                  TaskCountType currentTaskCount,
                                                                   OsContext &osContext,
                                                                   bool &stateBaseAddressDirty,
                                                                   bool &scratchSurfaceDirty,
@@ -161,17 +159,18 @@ void ScratchSpaceControllerXeHPAndLater::prepareScratchAllocation(uint32_t requi
     if (!Math::isPow2(requiredPerThreadScratchSizeSlot0AlignedUp)) {
         requiredPerThreadScratchSizeSlot0AlignedUp = Math::nextPowerOfTwo(requiredPerThreadScratchSizeSlot0);
     }
+    auto &productHelper = executionEnvironment.rootDeviceEnvironments[rootDeviceIndex]->getHelper<ProductHelper>();
     size_t requiredScratchSizeInBytes = static_cast<size_t>(requiredPerThreadScratchSizeSlot0AlignedUp) * computeUnitsUsedForScratch;
+    productHelper.adjustScratchSize(requiredScratchSizeInBytes);
     scratchSurfaceDirty = false;
     auto multiTileCapable = osContext.getNumSupportedDevices() > 1;
     if (scratchSlot0SizeInBytes < requiredScratchSizeInBytes) {
         if (scratchSlot0Allocation) {
-            scratchSlot0Allocation->updateTaskCount(currentTaskCount, osContext.getContextId());
             csrAllocationStorage.storeAllocation(std::unique_ptr<GraphicsAllocation>(scratchSlot0Allocation), TEMPORARY_ALLOCATION);
         }
         scratchSurfaceDirty = true;
         scratchSlot0SizeInBytes = requiredScratchSizeInBytes;
-        perThreadScratchSize = requiredPerThreadScratchSizeSlot0AlignedUp;
+        perThreadScratchSpaceSlot0Size = requiredPerThreadScratchSizeSlot0AlignedUp;
         AllocationProperties properties{this->rootDeviceIndex, true, scratchSlot0SizeInBytes, AllocationType::scratchSurface, multiTileCapable, false, osContext.getDeviceBitfield()};
         scratchSlot0Allocation = getMemoryManager()->allocateGraphicsMemoryWithProperties(properties);
     }
@@ -181,9 +180,9 @@ void ScratchSpaceControllerXeHPAndLater::prepareScratchAllocation(uint32_t requi
             requiredPerThreadScratchSizeSlot1AlignedUp = Math::nextPowerOfTwo(requiredPerThreadScratchSizeSlot1);
         }
         size_t requiredScratchSlot1SizeInBytes = static_cast<size_t>(requiredPerThreadScratchSizeSlot1AlignedUp) * computeUnitsUsedForScratch;
+        productHelper.adjustScratchSize(requiredScratchSlot1SizeInBytes);
         if (scratchSlot1SizeInBytes < requiredScratchSlot1SizeInBytes) {
             if (scratchSlot1Allocation) {
-                scratchSlot1Allocation->updateTaskCount(currentTaskCount, osContext.getContextId());
                 csrAllocationStorage.storeAllocation(std::unique_ptr<GraphicsAllocation>(scratchSlot1Allocation), TEMPORARY_ALLOCATION);
             }
             scratchSlot1SizeInBytes = requiredScratchSlot1SizeInBytes;
@@ -199,13 +198,12 @@ void ScratchSpaceControllerXeHPAndLater::programHeaps(HeapContainer &heapContain
                                                       uint32_t scratchSlot,
                                                       uint32_t requiredPerThreadScratchSizeSlot0,
                                                       uint32_t requiredPerThreadScratchSizeSlot1,
-                                                      TaskCountType currentTaskCount,
                                                       OsContext &osContext,
                                                       bool &stateBaseAddressDirty,
                                                       bool &vfeStateDirty) {
     sshOffset = scratchSlot;
     updateSlots = false;
-    setRequiredScratchSpace(heapContainer[0]->getUnderlyingBuffer(), sshOffset, requiredPerThreadScratchSizeSlot0, requiredPerThreadScratchSizeSlot1, currentTaskCount, osContext, stateBaseAddressDirty, vfeStateDirty);
+    setRequiredScratchSpace(heapContainer[0]->getUnderlyingBuffer(), sshOffset, requiredPerThreadScratchSizeSlot0, requiredPerThreadScratchSizeSlot1, osContext, stateBaseAddressDirty, vfeStateDirty);
 
     for (uint32_t i = 1; i < heapContainer.size(); ++i) {
         surfaceStateHeap = static_cast<char *>(heapContainer[i]->getUnderlyingBuffer());
