@@ -9,6 +9,7 @@
 #include "shared/source/helpers/non_copyable_or_moveable.h"
 #include "shared/source/helpers/options.h"
 #include "shared/source/helpers/string.h"
+#include "shared/source/helpers/timestamp.h"
 #include "shared/source/utilities/io_functions.h"
 
 #include <cstdint>
@@ -16,6 +17,13 @@
 #include <string>
 #include <type_traits>
 
+#if defined(_WIN32)
+#include <process.h>
+#pragma warning(disable : 4996)
+#else
+#include <unistd.h>
+#endif
+
 enum class DebugFunctionalityLevel {
     none,   // Debug functionality disabled
     full,   // Debug functionality fully enabled
@@ -30,9 +38,11 @@ constexpr DebugFunctionalityLevel globalDebugFunctionalityLevel = DebugFunctiona
 constexpr DebugFunctionalityLevel globalDebugFunctionalityLevel = DebugFunctionalityLevel::none;
 #endif
 
-#define PRINT_DEBUG_STRING(flag, ...) \
-    if (flag)                         \
-        NEO::printDebugString(flag, __VA_ARGS__);
+#define PRINT_DEBUG_STRING(flag, stream, ...) \
+    if (flag)                                 \
+        NEO::printDebugString(flag, stream, __VA_ARGS__);
+
+#define EMIT_WARNING(flag, stream, ...) PRINT_DEBUG_STRING(flag, stream, __VA_ARGS__)
 
 namespace NEO {
 template <DebugFunctionalityLevel debugLevel>
@@ -44,14 +54,6 @@ void flushDebugStream(StreamT stream, Args &&...args) {
     IoFunctions::fflushPtr(stream);
 }
 
-template <typename... Args>
-void printDebugString(bool showDebugLogs, Args... args) {
-    if (showDebugLogs) {
-        IoFunctions::fprintf(args...);
-        flushDebugStream(args...);
-    }
-}
-
 void logDebugString(std::string_view debugString);
 
 #if defined(__clang__)
@@ -196,7 +198,10 @@ class DebugSettingsManager : NEO::NonCopyableAndNonMovableClass {
         auto setCsr = flags.SetCommandStreamReceiver.get();
         auto isTbxMode = (setCsr == static_cast<int32_t>(CommandStreamReceiverType::tbx)) ||
                          (setCsr == static_cast<int32_t>(CommandStreamReceiverType::tbxWithAub));
-        auto isFaultManagerEnabledInEnvVars = flags.EnableTbxPageFaultManager.get();
+        auto isFaultManagerEnabledInEnvVars = true;
+        if (flags.EnableTbxPageFaultManager.get() == 0) {
+            isFaultManagerEnabledInEnvVars = false;
+        }
         return isFaultManagerEnabledInEnvVars && isTbxMode;
     }
 
@@ -220,6 +225,25 @@ static_assert(NEO::NonCopyableAndNonMovable<DebugSettingsManager<DebugFunctional
 
 extern DebugSettingsManager<globalDebugFunctionalityLevel> debugManager;
 
+struct DebugMessagesBitmask {
+    constexpr static int32_t withPid = 1 << 0;
+    constexpr static int32_t withTimestamp = 1 << 1;
+};
+
+template <typename... Args>
+void printDebugString(bool showDebugLogs, FILE *stream, Args... args) {
+    if (showDebugLogs) {
+        if (NEO::debugManager.flags.DebugMessagesBitmask.get() & DebugMessagesBitmask::withPid) {
+            IoFunctions::fprintf(stream, "[PID: %d] ", getpid());
+        }
+        if (NEO::debugManager.flags.DebugMessagesBitmask.get() & DebugMessagesBitmask::withTimestamp) {
+            IoFunctions::fprintf(stream, "%s", TimestampHelper::getTimestamp().c_str());
+        }
+        IoFunctions::fprintf(stream, args...);
+        flushDebugStream(stream, args...);
+    }
+}
+
 class DurationLog {
     DurationLog() = delete;
 
