@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2024 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -56,7 +56,7 @@ inline void assignToken(const T *&dst, const SPatchItemHeader *src) {
     dst = reinterpret_cast<const T *>(src);
 }
 
-inline KernelArgFromPatchtokens &getKernelArg(KernelFromPatchtokens &kernel, size_t argNum, ArgObjectType type = ArgObjectType::none, ArgObjectTypeSpecialized typeSpecialized = ArgObjectTypeSpecialized::none) {
+inline KernelArgFromPatchtokens &getKernelArg(KernelFromPatchtokens &kernel, size_t argNum, ArgObjectType type) {
     if (kernel.tokens.kernelArgs.size() < argNum + 1) {
         kernel.tokens.kernelArgs.resize(argNum + 1);
     }
@@ -69,12 +69,6 @@ inline KernelArgFromPatchtokens &getKernelArg(KernelFromPatchtokens &kernel, siz
         DEBUG_BREAK_IF(true);
     }
 
-    if (arg.objectTypeSpecialized == ArgObjectTypeSpecialized::none) {
-        arg.objectTypeSpecialized = typeSpecialized;
-    } else if (typeSpecialized != ArgObjectTypeSpecialized::none) {
-        UNRECOVERABLE_IF(arg.objectTypeSpecialized != typeSpecialized);
-    }
-
     return arg;
 }
 
@@ -110,9 +104,6 @@ inline void assignArg(KernelFromPatchtokens &kernel, const SPatchItemHeader *src
     case PATCH_TOKEN_STATELESS_CONSTANT_MEMORY_OBJECT_KERNEL_ARGUMENT:
         argNum = getArgNum<SPatchStatelessConstantMemoryObjectKernelArgument>(src);
         break;
-    case PATCH_TOKEN_STATELESS_DEVICE_QUEUE_KERNEL_ARGUMENT:
-        argNum = getArgNum<SPatchStatelessDeviceQueueKernelArgument>(src);
-        break;
     }
 
     getKernelArg(kernel, argNum, type).objectArg = src;
@@ -264,19 +255,6 @@ inline void decodeKernelDataParameterToken(const SPatchDataParameterBuffer *toke
         getKernelArg(out, argNum, ArgObjectType::sampler).metadata.sampler.normalizedCoords = token;
         break;
 
-    case DATA_PARAMETER_VME_MB_BLOCK_TYPE:
-        getKernelArg(out, argNum, ArgObjectType::none, ArgObjectTypeSpecialized::vme).metadataSpecialized.vme.mbBlockType = token;
-        break;
-    case DATA_PARAMETER_VME_SUBPIXEL_MODE:
-        getKernelArg(out, argNum, ArgObjectType::none, ArgObjectTypeSpecialized::vme).metadataSpecialized.vme.subpixelMode = token;
-        break;
-    case DATA_PARAMETER_VME_SAD_ADJUST_MODE:
-        getKernelArg(out, argNum, ArgObjectType::none, ArgObjectTypeSpecialized::vme).metadataSpecialized.vme.sadAdjustMode = token;
-        break;
-    case DATA_PARAMETER_VME_SEARCH_PATH_TYPE:
-        getKernelArg(out, argNum, ArgObjectType::none, ArgObjectTypeSpecialized::vme).metadataSpecialized.vme.searchPathType = token;
-        break;
-
     case DATA_PARAMETER_PARENT_EVENT:
         crossthread.parentEvent = token;
         break;
@@ -356,9 +334,6 @@ inline bool decodeToken(const SPatchItemHeader *token, KernelFromPatchtokens &ou
         break;
     case PATCH_TOKEN_ALLOCATE_STATELESS_EVENT_POOL_SURFACE:
         break;
-    case PATCH_TOKEN_ALLOCATE_STATELESS_DEFAULT_DEVICE_QUEUE_SURFACE:
-        assignToken(out.tokens.allocateStatelessDefaultDeviceQueueSurface, token);
-        break;
     case PATCH_TOKEN_STRING:
         assignToken(out.tokens.strings, token);
         break;
@@ -395,7 +370,6 @@ inline bool decodeToken(const SPatchItemHeader *token, KernelFromPatchtokens &ou
     case PATCH_TOKEN_GLOBAL_MEMORY_OBJECT_KERNEL_ARGUMENT:
     case PATCH_TOKEN_STATELESS_GLOBAL_MEMORY_OBJECT_KERNEL_ARGUMENT:
     case PATCH_TOKEN_STATELESS_CONSTANT_MEMORY_OBJECT_KERNEL_ARGUMENT:
-    case PATCH_TOKEN_STATELESS_DEVICE_QUEUE_KERNEL_ARGUMENT:
         assignArg(out, token);
         break;
 
