@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -19,7 +19,12 @@ std::unique_ptr<NEO::Debugger> DebuggerL0::create(NEO::Device *device) {
         return nullptr;
     }
     auto osInterface = device->getRootDeviceEnvironment().osInterface.get();
-    if (!osInterface || !osInterface->isDebugAttachAvailable()) {
+    if (!osInterface) {
+        return nullptr;
+    }
+    if (!osInterface->isDebugAttachAvailable()) {
+        auto cardName = osInterface->getDriverModel()->as<Drm>()->getSysFsPciPathBaseName();
+        IoFunctions::fprintf(stderr, "Kernel debug mode is not enabled for %s. Device is not available for use\n", cardName.c_str());
         return nullptr;
     }
 
