@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -12,4 +12,10 @@ namespace NEO {
 void ExecutionEnvironment::adjustRootDeviceEnvironments() {
 }
 
+void ExecutionEnvironment::configureCcsMode() {
+}
+
+void ExecutionEnvironment::restoreCcsMode() {
+}
+
 } // namespace NEO
