@@ -22,11 +22,6 @@ constexpr uint32_t AUBCommandStreamReceiverHw<Family>::getMaskAndValueForPollFor
     return 0x00008000;
 }
 
-template <>
-void AUBCommandStreamReceiverHw<Family>::addContextToken(uint32_t dumpHandle) {
-    AUB::createContext(*stream, dumpHandle);
-}
-
 template <>
 void populateFactoryTable<AUBCommandStreamReceiverHw<Family>>() {
     extern AubCommandStreamReceiverCreateFunc aubCommandStreamReceiverFactory[IGFX_MAX_CORE];
