@@ -1,14 +1,15 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
-#include "shared/source/direct_submission/direct_submission_bdw_and_later.inl"
 #include "shared/source/direct_submission/direct_submission_hw.inl"
 #include "shared/source/direct_submission/direct_submission_prefetch_mitigation_base.inl"
 #include "shared/source/direct_submission/direct_submission_prefetcher_base.inl"
+#include "shared/source/direct_submission/direct_submission_relaxed_ordering.inl"
+#include "shared/source/direct_submission/direct_submission_tgllp_and_later.inl"
 #include "shared/source/direct_submission/dispatchers/blitter_dispatcher.inl"
 #include "shared/source/direct_submission/dispatchers/dispatcher.inl"
 #include "shared/source/direct_submission/dispatchers/render_dispatcher.inl"
