@@ -8,11 +8,7 @@
 #include "shared/source/gen12lp/hw_cmds_adlp.h"
 #include "shared/source/gen12lp/hw_info_adlp.h"
 #include "shared/source/helpers/hw_info.h"
-#include "shared/source/helpers/pipeline_select_args.h"
-#include "shared/source/helpers/pipeline_select_helper.h"
-#include "shared/source/os_interface/product_helper.h"
-#include "shared/source/os_interface/product_helper.inl"
-#include "shared/source/os_interface/product_helper_tgllp_and_later.inl"
+#include "shared/source/os_interface/product_helper_hw.h"
 
 constexpr static auto gfxProduct = IGFX_ALDERLAKE_P;
 
