@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -9,15 +9,16 @@
 
 #include "shared/source/debug_settings/debug_settings_manager.h"
 #include "shared/source/execution_environment/root_device_environment.h"
+#include "shared/source/helpers/cache_policy.h"
 #include "shared/source/helpers/gfx_core_helper.h"
 #include "shared/source/helpers/hw_info.h"
 #include "shared/source/memory_manager/allocation_type.h"
+#include "shared/source/memory_manager/graphics_allocation.h"
 #include "shared/source/os_interface/product_helper.h"
 #include "shared/source/release_helper/release_helper.h"
-
 namespace NEO {
 
-GMM_RESOURCE_USAGE_TYPE_ENUM CacheSettingsHelper::getGmmUsageType(AllocationType allocationType, bool forceUncached, const ProductHelper &productHelper) {
+GMM_RESOURCE_USAGE_TYPE_ENUM CacheSettingsHelper::getGmmUsageType(AllocationType allocationType, bool forceUncached, const ProductHelper &productHelper, const HardwareInfo *hwInfo) {
     if (debugManager.flags.ForceUncachedGmmUsageType.get()) {
         UNRECOVERABLE_IF(allocationType == AllocationType::unknown);
         if ((1llu << (static_cast<int64_t>(allocationType) - 1)) & debugManager.flags.ForceUncachedGmmUsageType.get()) {
@@ -28,7 +29,7 @@ GMM_RESOURCE_USAGE_TYPE_ENUM CacheSettingsHelper::getGmmUsageType(AllocationType
     if (forceUncached || debugManager.flags.ForceAllResourcesUncached.get()) {
         return getDefaultUsageTypeWithCachingDisabled(allocationType, productHelper);
     } else {
-        return getDefaultUsageTypeWithCachingEnabled(allocationType, productHelper);
+        return getDefaultUsageTypeWithCachingEnabled(allocationType, productHelper, hwInfo);
     }
 }
 
@@ -46,11 +47,7 @@ bool CacheSettingsHelper::preferNoCpuAccess(GMM_RESOURCE_USAGE_TYPE_ENUM gmmReso
     return (gmmResourceUsageType != GMM_RESOURCE_USAGE_OCL_SYSTEM_MEMORY_BUFFER);
 }
 
-GMM_RESOURCE_USAGE_TYPE_ENUM CacheSettingsHelper::getDefaultUsageTypeWithCachingEnabled(AllocationType allocationType, const ProductHelper &productHelper) {
-    if (productHelper.overrideUsageForDcFlushMitigation(allocationType)) {
-        return getDefaultUsageTypeWithCachingDisabled(allocationType, productHelper);
-    }
-
+GMM_RESOURCE_USAGE_TYPE_ENUM CacheSettingsHelper::getDefaultUsageTypeWithCachingEnabled(AllocationType allocationType, const ProductHelper &productHelper, const HardwareInfo *hwInfo) {
     if (debugManager.flags.ForceGmmSystemMemoryBufferForAllocations.get()) {
         UNRECOVERABLE_IF(allocationType == AllocationType::unknown);
         if ((1llu << (static_cast<int64_t>(allocationType))) & debugManager.flags.ForceGmmSystemMemoryBufferForAllocations.get()) {
@@ -58,6 +55,16 @@ GMM_RESOURCE_USAGE_TYPE_ENUM CacheSettingsHelper::getDefaultUsageTypeWithCaching
         }
     }
 
+    if (hwInfo->capabilityTable.isIntegratedDevice) {
+        if (productHelper.isResourceUncachedForCS(allocationType)) {
+            return GMM_RESOURCE_USAGE_OCL_BUFFER_CSR_UC;
+        } else if (AllocationType::semaphoreBuffer == allocationType) {
+            return GMM_RESOURCE_USAGE_OCL_SYSTEM_MEMORY_BUFFER;
+        } else if (AllocationType::tagBuffer == allocationType) {
+            return GMM_RESOURCE_USAGE_OCL_BUFFER;
+        }
+    }
+
     switch (allocationType) {
     case AllocationType::image:
         return GMM_RESOURCE_USAGE_OCL_IMAGE;
@@ -80,11 +87,11 @@ GMM_RESOURCE_USAGE_TYPE_ENUM CacheSettingsHelper::getDefaultUsageTypeWithCaching
             return getDefaultUsageTypeWithCachingDisabled(allocationType, productHelper);
         }
         return GMM_RESOURCE_USAGE_OCL_BUFFER;
-    case AllocationType::externalHostPtr:
     case AllocationType::bufferHostMemory:
+    case AllocationType::externalHostPtr:
+    case AllocationType::fillPattern:
     case AllocationType::internalHostMemory:
     case AllocationType::mapAllocation:
-    case AllocationType::fillPattern:
     case AllocationType::svmCpu:
     case AllocationType::svmZeroCopy:
     case AllocationType::tagBuffer:
@@ -94,13 +101,10 @@ GMM_RESOURCE_USAGE_TYPE_ENUM CacheSettingsHelper::getDefaultUsageTypeWithCaching
         return GMM_RESOURCE_USAGE_OCL_SYSTEM_MEMORY_BUFFER;
     case AllocationType::gpuTimestampDeviceBuffer:
     case AllocationType::timestampPacketTagBuffer:
-        if (debugManager.flags.ForceNonCoherentModeForTimestamps.get()) {
+        if (productHelper.isNonCoherentTimestampsModeEnabled()) {
             return GMM_RESOURCE_USAGE_OCL_BUFFER;
         }
-        if (productHelper.isDcFlushAllowed()) {
-            return getDefaultUsageTypeWithCachingDisabled(allocationType, productHelper);
-        }
-        return GMM_RESOURCE_USAGE_OCL_BUFFER;
+        return getDefaultUsageTypeWithCachingDisabled(allocationType, productHelper);
     default:
         return GMM_RESOURCE_USAGE_OCL_BUFFER;
     }
@@ -113,15 +117,18 @@ GMM_RESOURCE_USAGE_TYPE_ENUM CacheSettingsHelper::getDefaultUsageTypeWithCaching
     case AllocationType::internalHeap:
     case AllocationType::linearStream:
         return GMM_RESOURCE_USAGE_OCL_SYSTEM_MEMORY_BUFFER_CACHELINE_MISALIGNED;
-    case AllocationType::timestampPacketTagBuffer:
-    case AllocationType::gpuTimestampDeviceBuffer:
-        if (debugManager.flags.ForceNonCoherentModeForTimestamps.get()) {
-            return GMM_RESOURCE_USAGE_OCL_BUFFER;
-        }
-        [[fallthrough]];
     default:
         return productHelper.isNewCoherencyModelSupported() ? GMM_RESOURCE_USAGE_OCL_BUFFER_CSR_UC : GMM_RESOURCE_USAGE_OCL_BUFFER_CACHELINE_MISALIGNED;
     }
 }
 
+// Set 2-way coherency for allocations which are not aligned to cacheline
+GMM_RESOURCE_USAGE_TYPE_ENUM CacheSettingsHelper::getGmmUsageTypeForUserPtr(bool isCacheFlushRequired, const void *userPtr, size_t size, const ProductHelper &productHelper) {
+    if (isCacheFlushRequired && !isL3Capable(userPtr, size) && productHelper.isMisalignedUserPtr2WayCoherent()) {
+        return GMM_RESOURCE_USAGE_HW_CONTEXT;
+    } else {
+        return GMM_RESOURCE_USAGE_OCL_SYSTEM_MEMORY_BUFFER;
+    }
+}
+
 } // namespace NEO
