@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2022 Intel Corporation
+ * Copyright (C) 2021-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,7 +7,7 @@
 
 #pragma once
 
-#include "shared/source/helpers/common_types.h"
+#include "shared/source/helpers/device_bitfield.h"
 
 #include <bitset>
 #include <limits>
@@ -35,10 +35,6 @@ class AffinityMaskHelper {
         enableGenericSubDevice(subDeviceIndex, std::numeric_limits<uint32_t>::max());
     }
 
-    void enableEngineInstancedSubDevice(uint32_t subDeviceIndex, uint32_t engineIndex) {
-        enableGenericSubDevice(subDeviceIndex, (1u << engineIndex));
-    }
-
     void enableAllGenericSubDevices(uint32_t subDeviceCount) {
         for (uint32_t i = 0; i < subDeviceCount; i++) {
             enableGenericSubDevice(i);
