@@ -20,6 +20,7 @@ BlitProperties BlitProperties::constructPropertiesForMemoryFill(GraphicsAllocati
         .blitDirection = BlitterConstants::BlitDirection::fill,
         .dstAllocation = dstAllocation,
         .fillPattern = pattern,
+        .dstGpuAddress = dstAllocation->getGpuAddress(),
         .copySize = {size, 1, 1},
         .dstOffset = {offset, 0, 0},
         .srcOffset = {0, 0, 0},
@@ -27,6 +28,19 @@ BlitProperties BlitProperties::constructPropertiesForMemoryFill(GraphicsAllocati
         .isSystemMemoryPoolUsed = MemoryPoolHelper::isSystemMemoryPool(dstAllocation->getMemoryPool())};
 }
 
+BlitProperties BlitProperties::constructPropertiesForSystemMemoryFill(uint64_t dstPtr, size_t size, uint32_t *pattern, size_t patternSize, size_t offset) {
+    return {
+        .blitDirection = BlitterConstants::BlitDirection::fill,
+        .dstAllocation = nullptr,
+        .fillPattern = pattern,
+        .dstGpuAddress = dstPtr,
+        .copySize = {size, 1, 1},
+        .dstOffset = {offset, 0, 0},
+        .srcOffset = {0, 0, 0},
+        .fillPatternSize = patternSize,
+        .isSystemMemoryPoolUsed = true};
+}
+
 BlitProperties BlitProperties::constructPropertiesForReadWrite(BlitterConstants::BlitDirection blitDirection,
                                                                CommandStreamReceiver &commandStreamReceiver,
                                                                GraphicsAllocation *memObjAllocation,
@@ -129,6 +143,54 @@ BlitProperties BlitProperties::constructPropertiesForCopy(GraphicsAllocation *ds
         .isSystemMemoryPoolUsed = MemoryPoolHelper::isSystemMemoryPool(dstAllocation->getMemoryPool(), srcAllocation->getMemoryPool())};
 }
 
+BlitProperties BlitProperties::constructPropertiesForSystemCopy(GraphicsAllocation *dstAllocation, GraphicsAllocation *srcAllocation, uint64_t dstPtr, uint64_t srcPtr,
+                                                                const Vec3<size_t> &dstOffset, const Vec3<size_t> &srcOffset, Vec3<size_t> copySize,
+                                                                size_t srcRowPitch, size_t srcSlicePitch,
+                                                                size_t dstRowPitch, size_t dstSlicePitch, GraphicsAllocation *clearColorAllocation) {
+    copySize.y = copySize.y ? copySize.y : 1;
+    copySize.z = copySize.z ? copySize.z : 1;
+    uint64_t dst;
+    uint64_t src;
+    if (dstAllocation) {
+        dst = dstAllocation->getGpuAddress();
+    } else {
+        dst = dstPtr;
+    }
+
+    if (srcAllocation) {
+        src = srcAllocation->getGpuAddress();
+    } else {
+        src = srcPtr;
+    }
+
+    bool sysMem;
+    if ((srcAllocation) && (dstAllocation)) {
+        sysMem = MemoryPoolHelper::isSystemMemoryPool(dstAllocation->getMemoryPool(), srcAllocation->getMemoryPool());
+    } else {
+        sysMem = true;
+    }
+
+    return {
+        .blitSyncProperties = {},
+        .csrDependencies = {},
+        .multiRootDeviceEventSync = nullptr,
+        .blitDirection = BlitterConstants::BlitDirection::bufferToBuffer,
+        .auxTranslationDirection = AuxTranslationDirection::none,
+        .dstAllocation = dstAllocation,
+        .srcAllocation = srcAllocation,
+        .clearColorAllocation = clearColorAllocation,
+        .dstGpuAddress = dst,
+        .srcGpuAddress = src,
+        .copySize = copySize,
+        .dstOffset = dstOffset,
+        .srcOffset = srcOffset,
+        .dstRowPitch = dstRowPitch,
+        .dstSlicePitch = dstSlicePitch,
+        .srcRowPitch = srcRowPitch,
+        .srcSlicePitch = srcSlicePitch,
+        .isSystemMemoryPoolUsed = sysMem};
+}
+
 BlitProperties BlitProperties::constructPropertiesForAuxTranslation(AuxTranslationDirection auxTranslationDirection,
                                                                     GraphicsAllocation *allocation, GraphicsAllocation *clearColorAllocation) {
 
