@@ -70,9 +70,10 @@ enum class BlitDirection : uint32_t {
     bufferToHostPtr,
     hostPtrToBuffer,
     bufferToBuffer,
+    fill,
     hostPtrToImage,
     imageToHostPtr,
-    imageToImage
+    imageToImage,
 };
 
 enum PostBlitMode : int32_t {
@@ -95,4 +96,6 @@ inline constexpr uint32_t maxWorkgroupSize = 1024u;
 inline constexpr uint32_t minimalSyncBufferSize = 12;
 inline constexpr uint32_t gpuHangCheckTimeInUS = 500'000;
 inline constexpr double defaultProfilingTimerResolution = 83.333;
+inline constexpr uint64_t nsecPerSec = 1000000000ull;
+inline constexpr uint32_t maxAllowedEnvVariableSize = 4096u;
 } // namespace CommonConstants
