@@ -21,6 +21,8 @@ std::string engineUsageToString(EngineUsage usage) {
         return "Regular";
     case EngineUsage::lowPriority:
         return "LowPriority";
+    case EngineUsage::highPriority:
+        return "HighPriority";
     case EngineUsage::internal:
         return "Internal";
     case EngineUsage::cooperative:
@@ -170,6 +172,9 @@ uint32_t getBcsIndex(aub_stream::EngineType engineType) {
 }
 
 aub_stream::EngineType getBcsEngineAtIdx(uint32_t idx) {
+    if (idx == 0) {
+        return aub_stream::ENGINE_BCS;
+    }
     return static_cast<aub_stream::EngineType>((idx - 1) + aub_stream::ENGINE_BCS1);
 }
 
