@@ -1,13 +1,12 @@
 /*
- * Copyright (C) 2018-2021 Intel Corporation
+ * Copyright (C) 2018-2022 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
-#include "shared/source/helpers/aligned_memory.h"
-
+#include <cstddef>
 #include <cstdint>
 
 namespace NEO {
