@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -11,6 +11,7 @@ namespace NEO {
 
 struct PipeControlArgs {
     PipeControlArgs() = default;
+    void *postSyncCmd = nullptr;
 
     bool blockSettingPostSyncProperties = false;
     bool csStallOnly = false;
@@ -33,6 +34,7 @@ struct PipeControlArgs {
     bool depthCacheFlushEnable = false;
     bool depthStallEnable = false;
     bool protectedMemoryDisable = false;
+    bool isWalkerWithProfilingEnqueued = false;
 };
 
 } // namespace NEO
