@@ -26,19 +26,16 @@ class RayTracingHelper : public NonCopyableAndNonMovableClass {
     static constexpr uint32_t bvhStackSize = 96;
     static constexpr uint32_t memoryBackedFifoSizePerDss = 8 * MemoryConstants::kiloByte;
     static constexpr uint32_t maxBvhLevels = 8;
-    static constexpr uint32_t maxNumDSSRTStacks = 2048;
+
+    static constexpr uint32_t maxSizeOfRtStacksPerDss = 4096;
+    static constexpr uint32_t fixedSizeOfRtStacksPerDss = 2048;
 
     static size_t getDispatchGlobalSize() {
         return static_cast<size_t>(alignUp(sizeof(RTDispatchGlobals), MemoryConstants::cacheLineSize));
     }
 
     static size_t getRTStackSizePerTile(const Device &device, uint32_t tiles, uint32_t maxBvhLevel, uint32_t extraBytesLocal, uint32_t extraBytesGlobal) {
-        auto &productHelper = device.getProductHelper();
-        auto numRTStacksPerDss = productHelper.getNumRtStacksPerDSSForAllocation(device.getHardwareInfo());
-        auto stackSizePerRay = getStackSizePerRay(maxBvhLevel, extraBytesLocal);
-        auto numRtStacks = getNumRtStacks(device, numRTStacksPerDss);
-
-        return static_cast<size_t>(alignUp(stackSizePerRay * numRtStacks + extraBytesGlobal, MemoryConstants::cacheLineSize));
+        return static_cast<size_t>(alignUp(getStackSizePerRay(maxBvhLevel, extraBytesLocal) * (getNumRtStacks(device)) + extraBytesGlobal, MemoryConstants::cacheLineSize));
     }
 
     static size_t getTotalMemoryBackedFifoSize(const Device &device) {
@@ -49,16 +46,29 @@ class RayTracingHelper : public NonCopyableAndNonMovableClass {
         return static_cast<size_t>(Math::log2(memoryBackedFifoSizePerDss / MemoryConstants::kiloByte) - 1);
     }
 
-    static uint32_t getNumRtStacks(const Device &device, uint32_t nRtStacksPerDss) {
-        return NEO::GfxCoreHelper::getHighestEnabledDualSubSlice(device.getHardwareInfo()) * nRtStacksPerDss;
+    static uint32_t getNumRtStacks(const Device &device) {
+        return NEO::GfxCoreHelper::getHighestEnabledDualSubSlice(device.getHardwareInfo()) * getNumRtStacksPerDss(device);
+    }
+
+    static uint32_t getNumRtStacksPerDss(const Device &device) {
+        auto releaseHelper = device.getReleaseHelper();
+
+        if (releaseHelper == nullptr || releaseHelper->isNumRtStacksPerDssFixedValue()) {
+            return fixedSizeOfRtStacksPerDss;
+        }
+
+        const auto &hwInfo = device.getHardwareInfo();
+        UNRECOVERABLE_IF(hwInfo.gtSystemInfo.EUCount == 0)
+
+        uint32_t maxNumEUsPerDSS = hwInfo.gtSystemInfo.MaxEuPerSubSlice;
+        uint32_t maxNumThreadsPerEU = hwInfo.gtSystemInfo.ThreadCount / hwInfo.gtSystemInfo.EUCount;
+        uint32_t maxSIMTThreadsPerThread = CommonConstants::maximalSimdSize;
+
+        return std::min(maxSizeOfRtStacksPerDss, maxNumEUsPerDSS * maxNumThreadsPerEU * maxSIMTThreadsPerThread);
     }
 
     static uint32_t getStackSizePerRay(uint32_t maxBvhLevel, uint32_t extraBytesLocal) {
         return hitInfoSize + bvhStackSize * maxBvhLevel + extraBytesLocal;
     }
-
-    static uint32_t getAsyncNumRTStacksPerDss() {
-        return maxNumDSSRTStacks;
-    }
 };
 } // namespace NEO
