@@ -146,13 +146,10 @@ struct ArgDescriptor final {
         }
         union {
             struct {
-                bool isAccelerator : 1;
-                bool isDeviceQueue : 1;
                 bool isMediaImage : 1;
                 bool isMediaBlockImage : 1;
                 bool isTransformable : 1;
                 bool needsPatch : 1;
-                bool hasVmeExtendedDescriptor : 1;
             };
             uint32_t packed;
         };
@@ -373,8 +370,4 @@ inline ArgDescriptor::ArgDescriptor(ArgType type) : type(type) {
     }
 }
 
-struct ArgDescriptorExtended {
-    virtual ~ArgDescriptorExtended() = default;
-};
-
 } // namespace NEO
