@@ -1,11 +1,12 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
+#include "shared/source/helpers/non_copyable_or_moveable.h"
 #include "shared/source/utilities/idlist.h"
 
 #include <atomic>
@@ -15,14 +16,11 @@
 namespace NEO {
 class DeferrableDeletion;
 class Thread;
-class DeferredDeleter {
+class DeferredDeleter : NEO::NonCopyableAndNonMovableClass {
   public:
     DeferredDeleter();
     virtual ~DeferredDeleter();
 
-    DeferredDeleter(const DeferredDeleter &) = delete;
-    DeferredDeleter &operator=(const DeferredDeleter &) = delete;
-
     MOCKABLE_VIRTUAL void deferDeletion(DeferrableDeletion *deletion);
 
     MOCKABLE_VIRTUAL void addClient();
@@ -31,16 +29,18 @@ class DeferredDeleter {
 
     MOCKABLE_VIRTUAL void drain(bool blocking, bool hostptrsOnly);
 
+    MOCKABLE_VIRTUAL bool areElementsReleased(bool hostptrsOnly);
+
   protected:
     void stop();
     void safeStop();
     void ensureThread();
     MOCKABLE_VIRTUAL void clearQueue(bool hostptrsOnly);
-    MOCKABLE_VIRTUAL bool areElementsReleased(bool hostptrsOnly);
     MOCKABLE_VIRTUAL bool shouldStop();
 
     static void *run(void *);
 
+    std::atomic<bool> exitedMainLoop = false;
     std::atomic<bool> doWorkInBackground = false;
     std::atomic<int> elementsToRelease = 0;
     std::atomic<int> hostptrsToRelease = 0;
@@ -51,4 +51,7 @@ class DeferredDeleter {
     std::mutex threadMutex;
     std::condition_variable condition;
 };
+
+static_assert(NEO::NonCopyableAndNonMovable<DeferredDeleter>);
+
 } // namespace NEO
