@@ -16,7 +16,7 @@ namespace NEO {
 std::unique_ptr<OSTime> OSTime::create(OSInterface *osInterface) {
     if (nullptr == osInterface) {
         return std::make_unique<OSTime>(std::make_unique<DeviceTime>());
-    } else if (osInterface->getDriverModel()->getDriverModelType() == DriverModelType::DRM) {
+    } else if (osInterface->getDriverModel()->getDriverModelType() == DriverModelType::drm) {
         return OSTimeLinux::create(*osInterface, std::make_unique<DeviceTimeDrm>(*osInterface));
     } else {
         auto wddm = osInterface->getDriverModel()->as<Wddm>();
