@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2023 Intel Corporation
+ * Copyright (C) 2021-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,9 +7,7 @@
 
 #include "shared/source/os_interface/linux/clos_cache.h"
 
-#include "shared/source/debug_settings/debug_settings_manager.h"
 #include "shared/source/helpers/common_types.h"
-#include "shared/source/os_interface/linux/drm_neo.h"
 #include "shared/source/os_interface/linux/ioctl_helper.h"
 
 #include <cerrno>
@@ -18,7 +16,7 @@
 namespace NEO {
 
 CacheRegion ClosCacheReservation::reserveCache(CacheLevel cacheLevel, uint16_t numWays) {
-    auto closIndex = allocEntry();
+    auto closIndex = allocEntry(cacheLevel);
     if (closIndex == CacheRegion::none) {
         return CacheRegion::none;
     }
@@ -38,16 +36,16 @@ CacheRegion ClosCacheReservation::freeCache(CacheLevel cacheLevel, CacheRegion c
     return freeEntry(closIndex);
 }
 
-CacheRegion ClosCacheReservation::allocEntry() {
-    return drm.getIoctlHelper()->closAlloc();
+CacheRegion ClosCacheReservation::allocEntry(CacheLevel cacheLevel) {
+    return ioctlHelper.closAlloc(cacheLevel);
 }
 
 CacheRegion ClosCacheReservation::freeEntry(CacheRegion closIndex) {
-    return drm.getIoctlHelper()->closFree(closIndex);
+    return ioctlHelper.closFree(closIndex);
 }
 
 uint16_t ClosCacheReservation::allocCacheWay(CacheRegion closIndex, CacheLevel cacheLevel, uint16_t numWays) {
-    return drm.getIoctlHelper()->closAllocWays(closIndex, static_cast<uint16_t>(cacheLevel), numWays);
+    return ioctlHelper.closAllocWays(closIndex, static_cast<uint16_t>(cacheLevel), numWays);
 }
 
 } // namespace NEO
