@@ -7,6 +7,7 @@
 
 #include "shared/source/os_interface/linux/device_time_drm.h"
 
+#include "shared/source/debug_settings/debug_settings_manager.h"
 #include "shared/source/helpers/register_offsets.h"
 #include "shared/source/os_interface/linux/drm_neo.h"
 #include "shared/source/os_interface/linux/drm_wrappers.h"
@@ -21,11 +22,20 @@ DeviceTimeDrm::DeviceTimeDrm(OSInterface &osInterface) {
     pDrm = osInterface.getDriverModel()->as<Drm>();
 }
 
-bool DeviceTimeDrm::getGpuCpuTimeImpl(TimeStampData *pGpuCpuTime, OSTime *osTime) {
-    return pDrm->getIoctlHelper()->setGpuCpuTimes(pGpuCpuTime, osTime);
+TimeQueryStatus DeviceTimeDrm::getGpuCpuTimeImpl(TimeStampData *pGpuCpuTime, OSTime *osTime) {
+
+    if (!pDrm->getIoctlHelper()->setGpuCpuTimes(pGpuCpuTime, osTime)) {
+        if (pDrm->getErrno() == EOPNOTSUPP) {
+            return TimeQueryStatus::unsupportedFeature;
+        } else {
+            return TimeQueryStatus::deviceLost;
+        }
+    }
+
+    return TimeQueryStatus::success;
 }
 
-double DeviceTimeDrm::getDynamicDeviceTimerResolution(HardwareInfo const &hwInfo) const {
+double DeviceTimeDrm::getDynamicDeviceTimerResolution() const {
     if (pDrm) {
         int frequency = 0;
 
@@ -34,10 +44,10 @@ double DeviceTimeDrm::getDynamicDeviceTimerResolution(HardwareInfo const &hwInfo
             return nanosecondsPerSecond / frequency;
         }
     }
-    return OSTime::getDeviceTimerResolution(hwInfo);
+    return OSTime::getDeviceTimerResolution();
 }
 
-uint64_t DeviceTimeDrm::getDynamicDeviceTimerClock(HardwareInfo const &hwInfo) const {
+uint64_t DeviceTimeDrm::getDynamicDeviceTimerClock() const {
 
     if (pDrm) {
         int frequency = 0;
@@ -47,7 +57,15 @@ uint64_t DeviceTimeDrm::getDynamicDeviceTimerClock(HardwareInfo const &hwInfo) c
             return static_cast<uint64_t>(frequency);
         }
     }
-    return static_cast<uint64_t>(nanosecondsPerSecond / OSTime::getDeviceTimerResolution(hwInfo));
+    return static_cast<uint64_t>(nanosecondsPerSecond / OSTime::getDeviceTimerResolution());
 }
 
-} // namespace NEO
\ No newline at end of file
+bool DeviceTimeDrm::isTimestampsRefreshEnabled() const {
+    bool timestampsRefreshEnabled = pDrm->getIoctlHelper()->isTimestampsRefreshEnabled();
+    if (debugManager.flags.EnableReusingGpuTimestamps.get() != -1) {
+        timestampsRefreshEnabled = debugManager.flags.EnableReusingGpuTimestamps.get();
+    }
+    return timestampsRefreshEnabled;
+}
+
+} // namespace NEO
