@@ -14,9 +14,10 @@ class Drm;
 class DeviceTimeDrm : public DeviceTime {
   public:
     DeviceTimeDrm(OSInterface &osInterface);
-    bool getGpuCpuTimeImpl(TimeStampData *pGpuCpuTime, OSTime *osTime) override;
-    double getDynamicDeviceTimerResolution(HardwareInfo const &hwInfo) const override;
-    uint64_t getDynamicDeviceTimerClock(HardwareInfo const &hwInfo) const override;
+    TimeQueryStatus getGpuCpuTimeImpl(TimeStampData *pGpuCpuTime, OSTime *osTime) override;
+    double getDynamicDeviceTimerResolution() const override;
+    uint64_t getDynamicDeviceTimerClock() const override;
+    bool isTimestampsRefreshEnabled() const override;
 
   protected:
     Drm *pDrm = nullptr;
