@@ -58,6 +58,7 @@ std::string DrmAllocation::getPatIndexInfoString(const ProductHelper &productHel
         ss << " Gmm resource usage: "
            << "[ " << gmm->getUsageTypeString() << " ],";
         ss << " Cacheable: " << gmm->resourceParams.Flags.Info.Cacheable;
+        ss << " NotLockable: " << gmm->resourceParams.Flags.Info.NotLockable;
     }
     return ss.str();
 }
@@ -161,12 +162,15 @@ bool DrmAllocation::setCacheRegion(Drm *drm, CacheRegion regionIndex) {
         return true;
     }
 
-    auto cacheInfo = drm->getL3CacheInfo();
+    auto cacheInfo = drm->getCacheInfo();
     if (cacheInfo == nullptr) {
         return false;
     }
 
-    auto regionSize = (cacheInfo->getMaxReservationNumCacheRegions() > 0) ? cacheInfo->getMaxReservationCacheSize() / cacheInfo->getMaxReservationNumCacheRegions() : 0;
+    const auto cacheLevel{cacheInfo->getLevelForRegion(regionIndex)};
+    const auto maxCacheRegions{cacheInfo->getMaxReservationNumCacheRegions(cacheLevel)};
+    const auto maxReservationCacheSize{cacheInfo->getMaxReservationCacheSize(cacheLevel)};
+    const auto regionSize{(maxCacheRegions > 0) ? maxReservationCacheSize / maxCacheRegions : 0};
     if (regionSize == 0) {
         return false;
     }
@@ -175,7 +179,7 @@ bool DrmAllocation::setCacheRegion(Drm *drm, CacheRegion regionIndex) {
 }
 
 bool DrmAllocation::setCacheAdvice(Drm *drm, size_t regionSize, CacheRegion regionIndex, bool isSystemMemoryPool) {
-    if (!drm->getL3CacheInfo()->getCacheRegion(regionSize, regionIndex)) {
+    if (!drm->getCacheInfo()->getCacheRegion(regionSize, regionIndex)) {
         return false;
     }
 
