@@ -199,17 +199,11 @@ bool IoctlHelperUpstream::isEuStallSupported() {
     return false;
 }
 
-bool IoctlHelperUpstream::getEuStallProperties(std::array<uint64_t, 12u> &properties, uint64_t dssBufferSize,
-                                               uint64_t samplingRate, uint64_t pollPeriod, uint64_t engineInstance,
-                                               uint64_t notifyNReports) {
-    return false;
-}
-
 uint32_t IoctlHelperUpstream::getEuStallFdParameter() {
     return 0u;
 }
 
-bool IoctlHelperUpstream::perfOpenEuStallStream(uint32_t euStallFdParameter, std::array<uint64_t, 12u> &properties, int32_t *stream) {
+bool IoctlHelperUpstream::perfOpenEuStallStream(uint32_t euStallFdParameter, uint32_t &samplingPeriodNs, uint64_t engineInstance, uint64_t notifyNReports, uint64_t gpuTimeStampfrequency, int32_t *stream) {
     return false;
 }
 
