@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021 Intel Corporation
+ * Copyright (C) 2021-2022 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -13,5 +13,7 @@
 namespace NEO {
 
 std::optional<std::string> getPciPath(int deviceFd);
+std::optional<std::string> getPciLinkPath(int deviceFd);
+std::optional<std::string> getPciRootPath(int deviceFd);
 
-}
\ No newline at end of file
+} // namespace NEO
\ No newline at end of file
