@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020 Intel Corporation
+ * Copyright (C) 2020-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -12,8 +12,4 @@ namespace NEO {
 SettingsReader *SettingsReader::createOsReader(bool userScope, const std::string &regKey) {
     return new EnvironmentVariableReader;
 }
-
-char *SettingsReader::getenv(const char *settingName) {
-    return ::getenv(settingName);
-}
 } // namespace NEO
