@@ -141,6 +141,8 @@ class IoctlHelperXe : public IoctlHelper {
     uint32_t getGtIdFromTileId(uint32_t tileId, uint16_t engineClass) const override;
     bool makeResidentBeforeLockNeeded() const override;
     bool isSmallBarConfigAllowed() const override { return false; }
+    void *pciBarrierMmap() override;
+    bool retrieveMmapOffsetForBufferObject(BufferObject &bo, uint64_t flags, uint64_t &offset) override;
 
   protected:
     static constexpr uint32_t maxContextSetProperties = 4;
@@ -164,7 +166,6 @@ class IoctlHelperXe : public IoctlHelper {
     uint64_t getEudebugExtPropertyValue();
     virtual bool isMediaEngine(uint16_t engineClass) const { return false; }
     virtual std::optional<uint32_t> getCxlType() { return {}; }
-    virtual uint32_t getNumEngines(uint64_t *enginesData) const;
     virtual bool isMediaGt(uint16_t gtType) const;
 
     struct UserFenceExtension {
