@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020 Intel Corporation
+ * Copyright (C) 2020-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -19,7 +19,7 @@ namespace GmmInterface {
 
 GMM_STATUS initialize(GMM_INIT_IN_ARGS *pInArgs, GMM_INIT_OUT_ARGS *pOutArgs) {
     if (!gmmLib) {
-        gmmLib.reset(OsLibrary::load(GMM_UMD_DLL));
+        gmmLib.reset(OsLibrary::loadFunc({GMM_UMD_DLL}));
         UNRECOVERABLE_IF(!gmmLib);
     }
     auto initGmmFunc = reinterpret_cast<decltype(&InitializeGmm)>(gmmLib->getProcAddress(GMM_ADAPTER_INIT_NAME));
