@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2021 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -11,6 +11,8 @@ ThreadWin::ThreadWin(std::thread *thread) {
     this->thread.reset(thread);
 };
 
+decltype(&Thread::create) Thread::createFunc = Thread::create;
+
 std::unique_ptr<Thread> Thread::create(void *(*func)(void *), void *arg) {
     return std::unique_ptr<Thread>(new ThreadWin(new std::thread(func, arg)));
 }
@@ -19,7 +21,12 @@ void ThreadWin::join() {
     thread->join();
 }
 
+void ThreadWin::detach() {
+    thread->detach();
+}
+
 void ThreadWin::yield() {
     std::this_thread::yield();
 }
+
 } // namespace NEO
