@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -11,7 +11,6 @@
 #include "shared/source/helpers/gfx_core_helper.h"
 #include "shared/source/helpers/hw_info.h"
 #include "shared/source/os_interface/os_interface.h"
-#include "shared/source/os_interface/windows/os_time_win.h"
 #include "shared/source/os_interface/windows/wddm/wddm.h"
 
 namespace NEO {
@@ -20,16 +19,18 @@ namespace NEO {
 /////////////////////////////////////////////////////
 std::unique_ptr<PerformanceCounters> PerformanceCounters::create(Device *device) {
     auto counter = std::make_unique<PerformanceCountersWin>();
-    auto wddm = device->getOSTime()->getOSInterface()->getDriverModel()->as<Wddm>();
+    auto wddm = device->getRootDeviceEnvironment().osInterface->getDriverModel()->as<Wddm>();
     auto &gfxCoreHelper = device->getGfxCoreHelper();
     UNRECOVERABLE_IF(counter == nullptr);
 
     counter->clientData.Windows.Adapter = reinterpret_cast<void *>(static_cast<UINT_PTR>(wddm->getAdapter()));
     counter->clientData.Windows.Device = reinterpret_cast<void *>(static_cast<UINT_PTR>(wddm->getDeviceHandle()));
-    counter->clientData.Windows.Escape = wddm->getEscapeHandle();
+    counter->clientData.Windows.Escape = reinterpret_cast<void *>(wddm->getEscapeHandle());
     counter->clientData.Windows.KmdInstrumentationEnabled = device->getHardwareInfo().capabilityTable.instrumentationEnabled;
     counter->contextData.ClientData = &counter->clientData;
     counter->clientType.Gen = static_cast<MetricsLibraryApi::ClientGen>(gfxCoreHelper.getMetricsLibraryGenId());
+    counter->metricsLibrary->api->callbacks.CommandBufferFlush = &PerformanceCounters::flushCommandBufferCallback;
+    counter->clientData.Handle = reinterpret_cast<void *>(device);
 
     return counter;
 }
