@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2022 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -12,4 +12,10 @@ namespace NEO {
 NTSTATUS Wddm::createNTHandle(const D3DKMT_HANDLE *resourceHandle, HANDLE *ntHandle) {
     return getGdi()->shareObjects(1, resourceHandle, nullptr, SHARED_ALLOCATION_WRITE, ntHandle);
 }
+bool Wddm::getReadOnlyFlagValue(const void *cpuPtr) const {
+    return false;
+}
+bool Wddm::isReadOnlyFlagFallbackSupported() const {
+    return false;
+}
 } // namespace NEO
\ No newline at end of file
