@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -16,4 +16,11 @@ NTSTATUS Wddm::createNTHandle(const D3DKMT_HANDLE *resourceHandle, HANDLE *ntHan
 
     return getGdi()->shareObjects(1, resourceHandle, &objAttr, SHARED_ALLOCATION_WRITE, ntHandle);
 }
+
+bool Wddm::getReadOnlyFlagValue(const void *cpuPtr) const {
+    return !isAligned<MemoryConstants::pageSize>(cpuPtr);
+}
+bool Wddm::isReadOnlyFlagFallbackSupported() const {
+    return true;
+}
 } // namespace NEO
