@@ -82,7 +82,7 @@ class Wddm : public DriverModel {
     MOCKABLE_VIRTUAL bool verifyNTHandle(HANDLE handle);
     bool openNTHandle(const MemoryManager::OsHandleData &osHandleData, WddmAllocation *alloc);
     MOCKABLE_VIRTUAL void *lockResource(const D3DKMT_HANDLE &handle, bool applyMakeResidentPriorToLock, size_t size);
-    MOCKABLE_VIRTUAL void unlockResource(const D3DKMT_HANDLE &handle);
+    MOCKABLE_VIRTUAL void unlockResource(const D3DKMT_HANDLE &handle, bool applyMakeResidentPriorToLock);
     MOCKABLE_VIRTUAL void kmDafLock(D3DKMT_HANDLE handle);
     MOCKABLE_VIRTUAL bool isKmDafEnabled() const;
 
@@ -271,6 +271,7 @@ class Wddm : public DriverModel {
 
     uint64_t systemSharedMemory = 0;
     uint64_t dedicatedVideoMemory = 0;
+    uint64_t lmemBarSize = 0;
 
     // Adapter information
     std::unique_ptr<PLATFORM_KMD> gfxPlatform;
@@ -309,6 +310,8 @@ class Wddm : public DriverModel {
     uint32_t additionalAdapterInfoOptions = 0u;
     int32_t forceEvictOnlyIfNecessary = -1;
 
+    uint8_t segmentId[3]{};
+
     unsigned int enablePreemptionRegValue = 1;
 
     bool platformSupportsEvictIfNecessary = false;
