@@ -15,9 +15,6 @@
 
 namespace NEO {
 
-class TbxPageFaultManagerWindows final : public PageFaultManagerWindows, public TbxPageFaultManager {
-  public:
-    TbxPageFaultManagerWindows() : PageFaultManagerWindows(), TbxPageFaultManager() {}
-};
+class TbxPageFaultManagerWindows final : public PageFaultManagerWindows, public TbxPageFaultManager {};
 
 } // namespace NEO
