@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Intel Corporation
+ * Copyright (C) 2023-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -29,6 +29,11 @@ bool ReleaseHelperHw<release>::isPipeControlPriorToPipelineSelectWaRequired() co
     return true;
 }
 
+template <>
+bool ReleaseHelperHw<release>::isDirectSubmissionLightSupported() const {
+    return true;
+}
+
 template <>
 bool ReleaseHelperHw<release>::isDirectSubmissionSupported() const {
     return true;
@@ -39,6 +44,21 @@ bool ReleaseHelperHw<release>::getFtrXe2Compression() const {
     return false;
 }
 
+template <>
+bool ReleaseHelperHw<release>::isBlitImageAllowedForDepthFormat() const {
+    return false;
+}
+
+template <>
+inline bool ReleaseHelperHw<release>::isBindlessAddressingDisabled() const {
+    return false;
+}
+
+template <>
+inline bool ReleaseHelperHw<release>::isGlobalBindlessAllocatorEnabled() const {
+    return true;
+}
+
 template <>
 const SizeToPreferredSlmValueArray &ReleaseHelperHw<release>::getSizeToPreferredSlmValue(bool isHeapless) const {
     using PREFERRED_SLM_ALLOCATION_SIZE = typename XeHpgCoreFamily::INTERFACE_DESCRIPTOR_DATA::PREFERRED_SLM_ALLOCATION_SIZE;
