@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -12,9 +12,13 @@
 #include <intrin.h>
 #pragma intrinsic(__rdtsc)
 #else
+#if defined(__ARM_ARCH)
+extern "C" uint64_t __rdtsc();
+#else
 #include <immintrin.h>
 #include <x86intrin.h>
 #endif
+#endif
 
 #if defined(__ARM_ARCH)
 #include <sse2neon.h>
@@ -41,10 +45,22 @@ void sfence() {
     _mm_sfence();
 }
 
+void mfence() {
+    _mm_mfence();
+}
+
 void pause() {
     _mm_pause();
 }
 
+uint8_t tpause(uint32_t control, uint64_t counter) {
+#ifdef SUPPORTS_WAITPKG
+    return _tpause(control, counter);
+#else
+    return 0;
+#endif
+}
+
 unsigned char umwait(unsigned int ctrl, uint64_t counter) {
 #ifdef SUPPORTS_WAITPKG
     return _umwait(ctrl, counter);
