@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2024 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -25,6 +25,11 @@ FileLogger<globalDebugFunctionalityLevel> &fileLoggerInstance() {
     return fileLoggerInstance;
 }
 
+FileLogger<globalDebugFunctionalityLevel> &usmReusePerfLoggerInstance() {
+    static FileLogger<globalDebugFunctionalityLevel> usmReusePerfLoggerInstance(std::string("usm_reuse_perf.csv"), debugManager.flags);
+    return usmReusePerfLoggerInstance;
+}
+
 template <DebugFunctionalityLevel debugLevel>
 FileLogger<debugLevel>::FileLogger(std::string filename, const DebugVariables &flags) {
     logFileName = std::move(filename);
