@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -31,7 +31,7 @@ class TagNode;
 
 class TagAllocatorBase;
 
-class TagNodeBase : public NonCopyableOrMovableClass {
+class TagNodeBase : public NonCopyableAndNonMovableClass {
   public:
     virtual ~TagNodeBase() = default;
 
@@ -47,6 +47,8 @@ class TagNodeBase : public NonCopyableOrMovableClass {
 
     virtual void initialize() = 0;
 
+    virtual void markAsAborted() = 0;
+
     bool canBeReleased() const;
 
     virtual void *getCpuBase() const = 0;
@@ -58,7 +60,7 @@ class TagNodeBase : public NonCopyableOrMovableClass {
     bool isProfilingCapable() const { return profilingCapable; }
 
     // TagType specific calls
-    virtual void assignDataToAllTimestamps(uint32_t packetIndex, void *source) = 0;
+    virtual void assignDataToAllTimestamps(uint32_t packetIndex, const void *source) = 0;
 
     virtual size_t getGlobalStartOffset() const = 0;
     virtual size_t getContextStartOffset() const = 0;
@@ -115,7 +117,11 @@ class TagNode : public TagNodeBase, public IDNode<TagNode<TagType>> {
 
     void *getCpuBase() const override { return tagForCpuAccess; }
 
-    void assignDataToAllTimestamps(uint32_t packetIndex, void *source) override;
+    void markAsAborted() override {
+        tagForCpuAccess->initialize(0);
+    }
+
+    void assignDataToAllTimestamps(uint32_t packetIndex, const void *source) override;
 
     size_t getGlobalStartOffset() const override;
     size_t getContextStartOffset() const override;
