@@ -67,8 +67,6 @@ const RuntimeCapabilityTable LNL::capabilityTable{
     true,                                                      // supportsIndependentForwardProgress
     true,                                                      // isIntegratedDevice
     false,                                                     // supportsMediaBlock
-    false,                                                     // p2pAccessSupported
-    false,                                                     // p2pAtomicAccessSupported
     false,                                                     // fusedEuEnabled
     true,                                                      // l0DebuggerSupported;
     true,                                                      // supportsFloatAtomics
