@@ -11,7 +11,14 @@ constexpr auto gfxProduct = IGFX_ARROWLAKE;
 
 #include "shared/source/xe_hpg_core/xe_lpg/compiler_product_helper_xe_lpg.inl"
 
+#include "additional_product_config_arl.inl"
+
 namespace NEO {
+template <>
+uint32_t CompilerProductHelperHw<gfxProduct>::getDefaultHwIpVersion() const {
+    return AOT::ARL_H_B0;
+}
+
 template <>
 uint32_t CompilerProductHelperHw<gfxProduct>::getProductConfigFromHwInfo(const HardwareInfo &hwInfo) const {
     if (hwInfo.ipVersion.value) {
@@ -22,10 +29,10 @@ uint32_t CompilerProductHelperHw<gfxProduct>::getProductConfigFromHwInfo(const H
     case 0x7D41: {
         switch (hwInfo.platform.usRevId) {
         case 0x0:
-            return AOT::MTL_M_A0;
+            return AOT::MTL_U_A0;
         case 0x3:
         case 0x6:
-            return AOT::MTL_M_B0;
+            return AOT::MTL_U_B0;
         }
         break;
     }
@@ -34,14 +41,15 @@ uint32_t CompilerProductHelperHw<gfxProduct>::getProductConfigFromHwInfo(const H
         switch (hwInfo.platform.usRevId) {
         case 0x0:
         case 0x3:
-            return AOT::XE_LPGPLUS_A0;
+            return AOT::ARL_H_A0;
         case 0x6:
-            return AOT::XE_LPGPLUS_B0;
+            return AOT::ARL_H_B0;
         }
         break;
     }
     }
-    return getDefaultHwIpVersion();
+    return getProductConfigFromHwInfoAdditionalArl(*this, hwInfo);
 }
+
 } // namespace NEO
 static NEO::EnableCompilerProductHelper<gfxProduct> enableCompilerProductHelperARL;
