@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2022 Intel Corporation
+ * Copyright (C) 2021-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -15,3 +15,7 @@
 #ifdef SUPPORT_MTL
 #include "hw_cmds_mtl.h"
 #endif
+
+#ifdef SUPPORT_ARL
+#include "hw_cmds_arl.h"
+#endif
