@@ -69,8 +69,6 @@ const RuntimeCapabilityTable DG2::capabilityTable{
     false,                                                     // supportsIndependentForwardProgress
     false,                                                     // isIntegratedDevice
     true,                                                      // supportsMediaBlock
-    true,                                                      // p2pAccessSupported
-    false,                                                     // p2pAtomicAccessSupported
     true,                                                      // fusedEuEnabled
     true,                                                      // l0DebuggerSupported
     true,                                                      // supportsFloatAtomics
