@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2023 Intel Corporation
+ * Copyright (C) 2021-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -22,16 +22,6 @@ template <>
 void PreambleHelper<Family>::appendProgramVFEState(const RootDeviceEnvironment &rootDeviceEnvironment, const StreamProperties &streamProperties, void *cmd) {
     auto command = static_cast<typename Family::CFE_STATE *>(cmd);
 
-    command->setComputeOverdispatchDisable(streamProperties.frontEndState.disableOverdispatch.value == 1);
-    command->setSingleSliceDispatchCcsMode(streamProperties.frontEndState.singleSliceDispatchCcsMode.value == 1);
-
-    if (DebugManager.flags.CFEComputeOverdispatchDisable.get() != -1) {
-        command->setComputeOverdispatchDisable(DebugManager.flags.CFEComputeOverdispatchDisable.get());
-    }
-    if (DebugManager.flags.CFESingleSliceDispatchCCSMode.get() != -1) {
-        command->setSingleSliceDispatchCcsMode(DebugManager.flags.CFESingleSliceDispatchCCSMode.get());
-    }
-
     auto &gfxCoreHelper = rootDeviceEnvironment.getHelper<GfxCoreHelper>();
     auto &hwInfo = *rootDeviceEnvironment.getHardwareInfo();
     if (!gfxCoreHelper.isFusedEuDispatchEnabled(hwInfo, streamProperties.frontEndState.disableEUFusion.value == 1)) {
@@ -39,8 +29,11 @@ void PreambleHelper<Family>::appendProgramVFEState(const RootDeviceEnvironment &
     }
 
     command->setNumberOfWalkers(1);
-    if (DebugManager.flags.CFENumberOfWalkers.get() != -1) {
-        command->setNumberOfWalkers(DebugManager.flags.CFENumberOfWalkers.get());
+    if (debugManager.flags.CFENumberOfWalkers.get() != -1) {
+        command->setNumberOfWalkers(debugManager.flags.CFENumberOfWalkers.get());
+    }
+    if (debugManager.flags.CFELargeGRFThreadAdjustDisable.get() != -1) {
+        command->setLargeGRFThreadAdjustDisable(debugManager.flags.CFELargeGRFThreadAdjustDisable.get());
     }
 }
 
