@@ -51,9 +51,8 @@ void BaseUltConfigListener::OnTestEnd(const ::testing::TestInfo &) {
     EXPECT_EQ(debugVarSnapshot.variableName.getRef(), debugManager.flags.variableName.getRef());
 #define DECLARE_DEBUG_SCOPED_V(dataType, variableName, defaultValue, description, ...) \
     DECLARE_DEBUG_VARIABLE(dataType, variableName, defaultValue, description)
-#include "shared/source/debug_settings/release_variables.inl"
-
 #include "debug_variables.inl"
+#include "release_variables.inl"
 #undef DECLARE_DEBUG_SCOPED_V
 #undef DECLARE_DEBUG_VARIABLE
 
