@@ -80,6 +80,8 @@ extern GFXCORE_FAMILY renderCoreFamily;
 void applyWorkarounds();
 void setupTestFiles(std::string testBinaryFiles, int32_t revId);
 std::string getBaseExecutionDir();
+bool isChangeDirectoryRequired();
+
 void addUltListener(::testing::TestEventListeners &listener);
 void cleanTestHelpers();
 
@@ -137,10 +139,11 @@ void applyCommonWorkarounds() {
     // Create FileLogger to prevent false memory leaks
     {
         NEO::fileLoggerInstance();
+        NEO::usmReusePerfLoggerInstance();
     }
 }
 
-bool enableAlarm = true;
+bool enableAlarm = ENABLE_ALARM_DEFAULT;
 int main(int argc, char **argv) {
 #if !defined(__linux__)
     std::regex dummyRegex{"dummyRegex"};   // these dummy objects are neededed to prevent false-positive
@@ -285,6 +288,7 @@ int main(int argc, char **argv) {
             generateRandomInput = true;
         } else if (!strcmp("--read-config", argv[i]) && isAubTestMode(testMode)) {
             if (debugManager.registryReadAvailable()) {
+                ApiSpecificConfig::initPrefixes();
                 debugManager.setReaderImpl(SettingsReader::create(ApiSpecificConfig::getRegistryPath()));
                 debugManager.injectSettingsFromReader();
             }
@@ -350,23 +354,25 @@ int main(int argc, char **argv) {
 
         setupTestFiles(getRunPath(argv[0]), testRevId);
 
-        auto executionDirectory = getBaseExecutionDir();
-        executionDirectory += hardwarePrefix[productFamily];
-        executionDirectory += NEO::executionDirectorySuffix; // _aub for aub_tests, empty otherwise
-        executionDirectory += "/";
-        executionDirectory += std::to_string(testRevId);
+        if (isChangeDirectoryRequired()) {
+            auto executionDirectory = getBaseExecutionDir();
+            executionDirectory += hardwarePrefix[productFamily];
+            executionDirectory += NEO::executionDirectorySuffix; // _aub for aub_tests, empty otherwise
+            executionDirectory += "/";
+            executionDirectory += std::to_string(testRevId);
 
 #ifdef WIN32
 #include <direct.h>
-        if (_chdir(executionDirectory.c_str())) {
-            std::cout << "chdir into " << executionDirectory << " directory failed.\nThis might cause test failures." << std::endl;
-        }
+            if (_chdir(executionDirectory.c_str())) {
+                std::cout << "chdir into " << executionDirectory << " directory failed.\nThis might cause test failures." << std::endl;
+            }
 #elif defined(__linux__)
 #include <unistd.h>
-        if (chdir(executionDirectory.c_str()) != 0) {
-            std::cout << "chdir into " << executionDirectory << " directory failed.\nThis might cause test failures." << std::endl;
-        }
+            if (chdir(executionDirectory.c_str()) != 0) {
+                std::cout << "chdir into " << executionDirectory << " directory failed.\nThis might cause test failures." << std::endl;
+            }
 #endif
+        }
 
         if (!checkAubTestsExecutionPathValidity()) {
             return -1;
