@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2022 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,6 +7,7 @@
 
 #pragma once
 
+#include "shared/source/device/device.h"
 #include "shared/source/gmm_helper/gmm.h"
 #include "shared/source/os_interface/device_factory.h"
 #include "shared/test/common/fixtures/memory_management_fixture.h"
@@ -33,7 +34,7 @@ class MemoryAllocatorMultiDeviceFixture : public MemoryManagementFixture, public
         MemoryManagementFixture::setUp();
 
         isOsAgnosticMemoryManager = GetParam();
-        DebugManager.flags.CreateMultipleRootDevices.set(numRootDevices);
+        debugManager.flags.CreateMultipleRootDevices.set(numRootDevices);
         VariableBackup<UltHwConfig> backup(&ultHwConfig);
         ultHwConfig.useMockedPrepareDeviceEnvironmentsFunc = false;
         ultHwConfig.forceOsAgnosticMemoryManager = isOsAgnosticMemoryManager;
@@ -70,8 +71,8 @@ class MemoryAllocatorMultiDeviceAndMultiTileFixture : public MemoryManagementFix
         MemoryManagementFixture::setUp();
 
         isOsAgnosticMemoryManager = GetParam();
-        DebugManager.flags.CreateMultipleRootDevices.set(numRootDevices);
-        DebugManager.flags.CreateMultipleRootDevices.set(numSubDevices);
+        debugManager.flags.CreateMultipleRootDevices.set(numRootDevices);
+        debugManager.flags.CreateMultipleRootDevices.set(numSubDevices);
         VariableBackup<UltHwConfig> backup(&ultHwConfig);
         ultHwConfig.useMockedPrepareDeviceEnvironmentsFunc = false;
         ultHwConfig.forceOsAgnosticMemoryManager = isOsAgnosticMemoryManager;
