@@ -6,8 +6,9 @@
  */
 
 #include "shared/test/common/helpers/mock_product_helper_hw.h"
-namespace NEO {
+
 constexpr static auto gfxProduct = IGFX_DG1;
+
 #include "shared/test/common/helpers/mock_product_helper_hw.inl"
-template struct MockProductHelperHw<gfxProduct>;
-} // namespace NEO
\ No newline at end of file
+
+template struct NEO::MockProductHelperHw<gfxProduct>;
