@@ -1,11 +1,12 @@
 /*
- * Copyright (C) 2018-2021 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
+#include <memory>
 
 template <typename T>
 class VariableBackup {
@@ -14,15 +15,15 @@ class VariableBackup {
         oldValue = *ptr;
     }
     VariableBackup(T *ptr, T &&newValue) : pValue(ptr) {
-        oldValue = *ptr;
-        *pValue = newValue;
+        oldValue = std::move(*ptr);
+        *pValue = std::move(newValue);
     }
     VariableBackup(T *ptr, T &newValue) : pValue(ptr) {
         oldValue = *ptr;
         *pValue = newValue;
     }
     ~VariableBackup() {
-        *pValue = oldValue;
+        *pValue = std::move(oldValue);
     }
     void operator=(const T &val) {
         *pValue = val;
@@ -36,3 +37,20 @@ class VariableBackup {
     T oldValue;
     T *pValue;
 };
+
+template <typename T>
+class NonCopyableVariableBackup {
+  public:
+    NonCopyableVariableBackup(T *ptr, T &&newValue) : pValue(ptr) {
+        oldValue = std::move(*ptr);
+        *pValue = std::move(newValue);
+    }
+
+    ~NonCopyableVariableBackup() {
+        *pValue = std::move(oldValue);
+    }
+
+  private:
+    T oldValue;
+    T *pValue;
+};
\ No newline at end of file
