@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2023 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -14,15 +14,18 @@
 #include <map>
 
 namespace NEO {
+extern bool returnEmptyFilesVector;
 
 std::string byPathPattern(std::string(NEO_SHARED_TEST_FILES_DIR) + "/linux/by-path");
 std::string deviceDrmPath(std::string(NEO_SHARED_TEST_FILES_DIR) + "/linux/devices/device/drm");
 std::map<std::string, std::vector<std::string>> directoryFilesMap = {};
+int setErrno = 0;
 
 std::vector<std::string> Directory::getFiles(const std::string &path) {
     std::vector<std::string> files;
 
-    if (Directory::returnEmptyFilesVector) {
+    if (returnEmptyFilesVector) {
+        errno = setErrno;
         return files;
     }
 
