@@ -12,6 +12,7 @@
 #include "shared/test/common/helpers/default_hw_info.h"
 #include "shared/test/common/mocks/linux/mock_drm_wrappers.h"
 #include "shared/test/common/os_interface/linux/device_command_stream_fixture.h"
+#include "shared/test/common/test_macros/mock_method_macros.h"
 
 #include <cstdio>
 #include <fstream>
@@ -24,13 +25,16 @@ using namespace NEO;
 
 class DrmMock : public Drm {
   public:
+    using BaseClass = Drm;
     using Drm::adapterBDF;
     using Drm::bindAvailable;
+    using Drm::cacheInfo;
     using Drm::checkQueueSliceSupport;
     using Drm::chunkingAvailable;
     using Drm::chunkingMode;
     using Drm::completionFenceSupported;
     using Drm::contextDebugSupported;
+    using Drm::disableScratch;
     using Drm::engineInfo;
     using Drm::engineInfoQueried;
     using Drm::fenceVal;
@@ -39,7 +43,6 @@ class DrmMock : public Drm {
     using Drm::getQueueSliceCount;
     using Drm::ioctlHelper;
     using Drm::isSharedSystemAllocEnabled;
-    using Drm::l3CacheInfo;
     using Drm::memoryInfo;
     using Drm::memoryInfoQueried;
     using Drm::minimalChunkingSize;
@@ -185,6 +188,12 @@ class DrmMock : public Drm {
         return storedRetValForGetGttSize;
     }
 
+    uint32_t getAggregatedProcessCount() const override {
+        return mockProcessCount;
+    }
+
+    ADDMETHOD_CONST(getDriverModelType, DriverModelType, true, DriverModelType::drm, (), ());
+
     static const int mockFd = 33;
 
     bool failRetTopology = false;
@@ -214,6 +223,8 @@ class DrmMock : public Drm {
     int storedRetValForVmId = 1;
     int storedCsTimestampFrequency = 1000;
     int storedOaTimestampFrequency = 123456;
+    int storedRetValForHasContextFreqHint = 1;
+    uint32_t mockProcessCount = 1;
     bool disableSomeTopology = false;
     bool allowDebugAttach = false;
     bool allowDebugAttachCallBase = false;
@@ -291,6 +302,7 @@ class DrmMock : public Drm {
 
     bool expectIoctlCallsOnDestruction = false;
     uint32_t expectedIoctlCallsOnDestruction = 0u;
+    bool lowLatencyHintRequested = false;
 
     virtual int handleRemainingRequests(DrmIoctl request, void *arg);
 
@@ -303,6 +315,7 @@ class DrmMock : public Drm {
         uint16_t flags;
     };
     StackVec<WaitUserFenceParams, 1> waitUserFenceParams;
+    StackVec<GemVmBind, 1> vmBindInputs;
 
     bool storedGetDeviceMemoryMaxClockRateInMhzStatus = true;
     bool useBaseGetDeviceMemoryMaxClockRateInMhz = true;
