@@ -79,6 +79,7 @@ class UltCommandStreamReceiver : public CommandStreamReceiverHw<GfxFamily> {
     using BaseClass::isBlitterDirectSubmissionEnabled;
     using BaseClass::isDirectSubmissionEnabled;
     using BaseClass::isPerDssBackedBufferSent;
+    using BaseClass::isWalkerWithProfilingEnqueued;
     using BaseClass::makeResident;
     using BaseClass::pageTableManagerInitialized;
     using BaseClass::perDssBackedBuffer;
@@ -139,7 +140,6 @@ class UltCommandStreamReceiver : public CommandStreamReceiverHw<GfxFamily> {
     using BaseClass::CommandStreamReceiver::isStateSipSent;
     using BaseClass::CommandStreamReceiver::lastAdditionalKernelExecInfo;
     using BaseClass::CommandStreamReceiver::lastKernelExecutionType;
-    using BaseClass::CommandStreamReceiver::lastMediaSamplerConfig;
     using BaseClass::CommandStreamReceiver::lastMemoryCompressionState;
     using BaseClass::CommandStreamReceiver::lastPreemptionMode;
     using BaseClass::CommandStreamReceiver::lastSentL3Config;
@@ -193,6 +193,9 @@ class UltCommandStreamReceiver : public CommandStreamReceiverHw<GfxFamily> {
     }
     ~UltCommandStreamReceiver() override {
         this->downloadAllocationImpl = nullptr;
+        if (initialOsContext) {
+            BaseClass::setupContext(*initialOsContext);
+        }
     }
     static CommandStreamReceiver *create(bool withAubDump,
                                          ExecutionEnvironment &executionEnvironment,
@@ -496,6 +499,10 @@ class UltCommandStreamReceiver : public CommandStreamReceiverHw<GfxFamily> {
         return commandStreamReceiverType;
     }
 
+    void setType(CommandStreamReceiverType commandStreamReceiverType) {
+        this->commandStreamReceiverType = commandStreamReceiverType;
+    }
+
     void pollForCompletion(bool skipTaskCountCheck) override {
         pollForCompletionCalled++;
     }
@@ -524,11 +531,21 @@ class UltCommandStreamReceiver : public CommandStreamReceiverHw<GfxFamily> {
     void stopDirectSubmission(bool blocking, bool needsLock) override {
         stopDirectSubmissionCalled = true;
         stopDirectSubmissionCalledBlocking = blocking;
+        if (initialOsContext) {
+            BaseClass::setupContext(*initialOsContext);
+        }
         if (this->callBaseStopDirectSubmission) {
             BaseClass::stopDirectSubmission(blocking, needsLock);
         }
     }
 
+    void setupContext(OsContext &osContext) override {
+        if (!initialOsContext) {
+            initialOsContext = this->osContext;
+        }
+        BaseClass::setupContext(osContext);
+    }
+
     bool waitUserFence(TaskCountType waitValue, uint64_t hostAddress, int64_t timeout, bool userInterrupt, uint32_t externalInterruptId, GraphicsAllocation *allocForInterruptWait) override {
         waitUserFenceParams.callCount++;
         waitUserFenceParams.latestWaitedAddress = hostAddress;
@@ -623,6 +640,7 @@ class UltCommandStreamReceiver : public CommandStreamReceiverHw<GfxFamily> {
     CommandStreamReceiverType commandStreamReceiverType = CommandStreamReceiverType::hardware;
     std::atomic<uint32_t> downloadAllocationsCalledCount = 0;
     std::atomic<bool> latestDownloadAllocationsBlocking = false;
+    OsContext *initialOsContext = nullptr;
 
     bool renderStateCacheFlushed = false;
     bool cpuCopyForHostPtrSurfaceAllowed = false;
