@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -23,12 +23,29 @@ CompletionStamp MockCommandStreamReceiver::flushTask(
     TaskCountType taskLevel,
     DispatchFlags &dispatchFlags,
     Device &device) {
+
+    if (this->getHeaplessStateInitEnabled()) {
+        return flushTaskHeapless(commandStream, commandStreamStart, dsh, ioh, ssh, taskLevel, dispatchFlags, device);
+    } else {
+        return flushTaskHeapful(commandStream, commandStreamStart, dsh, ioh, ssh, taskLevel, dispatchFlags, device);
+    }
+}
+
+CompletionStamp MockCommandStreamReceiver::flushTaskHeapless(
+    LinearStream &commandStream,
+    size_t commandStreamStart,
+    const IndirectHeap *dsh,
+    const IndirectHeap *ioh,
+    const IndirectHeap *ssh,
+    TaskCountType taskLevel,
+    DispatchFlags &dispatchFlags,
+    Device &device) {
     ++taskCount;
     CompletionStamp stamp = {taskCount, taskLevel, flushStamp->peekStamp()};
     return stamp;
 }
 
-CompletionStamp MockCommandStreamReceiver::flushTaskStateless(
+CompletionStamp MockCommandStreamReceiver::flushTaskHeapful(
     LinearStream &commandStream,
     size_t commandStreamStart,
     const IndirectHeap *dsh,
