@@ -7,7 +7,6 @@
 
 #pragma once
 #include "shared/source/direct_submission/direct_submission_hw.h"
-#include "shared/source/direct_submission/direct_submission_hw_diagnostic_mode.h"
 #include "shared/source/memory_manager/graphics_allocation.h"
 #include "shared/test/common/mocks/mock_memory_operations_handler.h"
 namespace NEO {
@@ -27,7 +26,6 @@ struct MockDirectSubmissionHw : public DirectSubmissionHw<GfxFamily, Dispatcher>
     using BaseClass::deallocateResources;
     using BaseClass::deferredTasksListAllocation;
     using BaseClass::detectGpuHang;
-    using BaseClass::diagnostic;
     using BaseClass::DirectSubmissionHw;
     using BaseClass::disableCacheFlush;
     using BaseClass::disableCpuCacheFlush;
@@ -42,7 +40,6 @@ struct MockDirectSubmissionHw : public DirectSubmissionHw<GfxFamily, Dispatcher>
     using BaseClass::dispatchSwitchRingBufferSection;
     using BaseClass::dispatchUllsState;
     using BaseClass::dispatchWorkloadSection;
-    using BaseClass::getDiagnosticModeSection;
     using BaseClass::getSizeDisablePrefetcher;
     using BaseClass::getSizeDispatch;
     using BaseClass::getSizeDispatchRelaxedOrderingQueueStall;
@@ -54,17 +51,19 @@ struct MockDirectSubmissionHw : public DirectSubmissionHw<GfxFamily, Dispatcher>
     using BaseClass::getSizeStartSection;
     using BaseClass::getSizeSwitchRingBufferSection;
     using BaseClass::getSizeSystemMemoryFenceAddress;
+    using BaseClass::getTagAddressValueForRingSwitch;
+    using BaseClass::globalFenceAllocation;
     using BaseClass::hwInfo;
     using BaseClass::immWritePostSyncOffset;
     using BaseClass::inputMonitorFenceDispatchRequirement;
     using BaseClass::isDisablePrefetcherRequired;
     using BaseClass::lastSubmittedThrottle;
     using BaseClass::miMemFenceRequired;
+    using BaseClass::notifyKmdDuringMonitorFence;
     using BaseClass::osContext;
     using BaseClass::partitionConfigSet;
     using BaseClass::partitionedMode;
     using BaseClass::pciBarrierPtr;
-    using BaseClass::performDiagnosticMode;
     using BaseClass::preinitializedRelaxedOrderingScheduler;
     using BaseClass::preinitializedTaskStoreSection;
     using BaseClass::relaxedOrderingEnabled;
@@ -86,9 +85,6 @@ struct MockDirectSubmissionHw : public DirectSubmissionHw<GfxFamily, Dispatcher>
     using BaseClass::switchRingBuffersNeeded;
     using BaseClass::systemMemoryFenceAddressSet;
     using BaseClass::unblockGpu;
-    using BaseClass::workloadMode;
-    using BaseClass::workloadModeOneExpectedValue;
-    using BaseClass::workloadModeOneStoreAddress;
     using BaseClass::workPartitionAllocation;
     using typename BaseClass::RingBufferUse;
 
@@ -141,7 +137,7 @@ struct MockDirectSubmissionHw : public DirectSubmissionHw<GfxFamily, Dispatcher>
         return true;
     }
 
-    bool submit(uint64_t gpuAddress, size_t size) override {
+    bool submit(uint64_t gpuAddress, size_t size, const ResidencyContainer *allocationsForResidency) override {
         submitGpuAddress = gpuAddress;
         submitSize = size;
         submitCount++;
@@ -164,18 +160,6 @@ struct MockDirectSubmissionHw : public DirectSubmissionHw<GfxFamily, Dispatcher>
         tagData.tagValue = tagValueSetValue;
     }
 
-    void performDiagnosticMode() override {
-        if (!NEO::directSubmissionDiagnosticAvailable) {
-            disabledDiagnosticCalled++;
-        }
-        uint32_t add = 1;
-        if (diagnostic.get()) {
-            add += diagnostic->getExecutionsCount();
-        }
-        *static_cast<volatile uint32_t *>(workloadModeOneStoreAddress) = workloadModeOneExpectedValue + add;
-        BaseClass::performDiagnosticMode();
-    }
-
     bool isCompleted(uint32_t ringBufferIndex) override {
         return this->isCompletedReturn;
     }
@@ -183,6 +167,10 @@ struct MockDirectSubmissionHw : public DirectSubmissionHw<GfxFamily, Dispatcher>
     void unblockPagingFenceSemaphore(uint64_t pagingFenceValue) override {
         this->pagingFenceValueToWait = pagingFenceValue;
     }
+    void getTagAddressValueForRingSwitch(TagData &tagData) override {
+        getTagAddressValueForRingSwitchCalled++;
+        getTagAddressValue(tagData);
+    }
 
     uint64_t updateTagValueReturn = 1ull;
     uint64_t tagAddressSetValue = MemoryConstants::pageSize;
@@ -192,13 +180,13 @@ struct MockDirectSubmissionHw : public DirectSubmissionHw<GfxFamily, Dispatcher>
     size_t submitSize = 0u;
     uint32_t submitCount = 0u;
     uint32_t handleResidencyCount = 0u;
-    uint32_t disabledDiagnosticCalled = 0u;
     uint32_t preinitializeRelaxedOrderingSectionsCalled = 0;
     uint32_t dispatchStaticRelaxedOrderingSchedulerCalled = 0;
     uint32_t dispatchRelaxedOrderingSchedulerSectionCalled = 0;
     uint32_t dispatchRelaxedOrderingQueueStallCalled = 0;
     uint32_t dispatchTaskStoreSectionCalled = 0;
     uint32_t ensureRingCompletionCalled = 0;
+    uint32_t getTagAddressValueForRingSwitchCalled = 0;
     uint32_t makeResourcesResidentVectorSize = 0u;
     bool allocateOsResourcesReturn = true;
     bool submitReturn = true;
