@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023 Intel Corporation
+ * Copyright (C) 2023-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -14,4 +14,7 @@ uint64_t MockGmmClientContextBase::mapGpuVirtualAddress(MapGpuVirtualAddressGmm
     mapGpuVirtualAddressCalled++;
     return pMapGpuVa->gdi->mapGpuVirtualAddress(pMapGpuVa->mapGpuVirtualAddressParams);
 }
+long MockGmmClientContextBase::deallocate2(DeallocateGmm *deallocateGmm) {
+    return deallocateGmm->gdi->destroyAllocation2(deallocateGmm->destroyAllocation2);
+}
 } // namespace NEO
