@@ -1,11 +1,12 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
+#include "shared/source/helpers/string.h"
 #include "shared/source/utilities/io_functions.h"
 
 #include <cstdint>
@@ -29,6 +30,8 @@ extern uint32_t mockFreadCalled;
 extern size_t mockFreadReturn;
 extern uint32_t mockFwriteCalled;
 extern size_t mockFwriteReturn;
+extern char *mockFwriteBuffer;
+extern char *mockFreadBuffer;
 extern bool mockVfptrinfUseStdioFunction;
 
 extern std::unordered_map<std::string, std::string> *mockableEnvValues;
@@ -82,11 +85,19 @@ inline void mockRewind(FILE *stream) {
 
 inline size_t mockFread(void *ptr, size_t size, size_t count, FILE *stream) {
     mockFreadCalled++;
+    if (mockFreadBuffer) {
+        memcpy_s(ptr, mockFreadReturn, mockFreadBuffer, size * count);
+    }
     return mockFreadReturn;
 }
 
 inline size_t mockFwrite(const void *ptr, size_t size, size_t nmemb, FILE *stream) {
     mockFwriteCalled++;
+
+    if (mockFwriteBuffer) {
+        memcpy_s(mockFwriteBuffer, mockFwriteReturn, ptr, size * nmemb);
+    }
+
     return mockFwriteReturn;
 }
 
@@ -97,5 +108,9 @@ inline int mockFflush(FILE *stream) {
     return 0;
 }
 
+inline int mockMkdir(const char *filename) {
+    return 0;
+}
+
 } // namespace IoFunctions
-} // namespace NEO
+} // namespace NEO
\ No newline at end of file
