@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -13,7 +13,8 @@ namespace NEO {
 struct MockMigrationSyncDataWithYield : public MigrationSyncData {
     using MigrationSyncData::MigrationSyncData;
     void yield() const override {
-        (*this->tagAddress)++;
+        auto newTag = *this->tagAddress + 1;
+        *this->tagAddress = newTag;
         MigrationSyncData::yield();
     }
 };
@@ -21,11 +22,16 @@ struct MockMigrationSyncData : public MigrationSyncData {
     using MigrationSyncData::latestTaskCountUsed;
     using MigrationSyncData::MigrationSyncData;
     using MigrationSyncData::tagAddress;
+    void signalUsage(volatile TagAddressType *tagAddress, TaskCountType taskCount) override {
+        signalUsageCalled++;
+        MigrationSyncData::signalUsage(tagAddress, taskCount);
+    }
     void waitOnCpu() override {
         waitOnCpuCalled++;
         MigrationSyncData::waitOnCpu();
     }
 
+    uint32_t signalUsageCalled = 0u;
     uint32_t waitOnCpuCalled = 0u;
 };
 
