@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -15,8 +15,9 @@
 std::string lastTest("");
 
 namespace NEO {
-extern const unsigned int ultIterationMaxTime;
+extern const unsigned int ultIterationMaxTimeInS;
 extern const char *executionName;
+extern const char *apiName;
 } // namespace NEO
 
 int newStdOut = -1;
@@ -26,7 +27,7 @@ void handleSIGABRT(int signal) {
     if (newStdOut != -1) {
         dup2(newStdOut, 1);
     }
-    std::cout << "SIGABRT in " << NEO::executionName << ", on: " << lastTest << std::endl;
+    std::cout << "SIGABRT in " << NEO::apiName << " " << NEO::executionName << ", on: " << lastTest << std::endl;
     if (sigaction(SIGABRT, &oldSigAbrt, nullptr) == -1) {
         std::cout << "FATAL: cannot fatal SIGABRT handler" << std::endl;
         std::cout << "FATAL: try SEGV" << std::endl;
@@ -44,7 +45,7 @@ void handleSIGALRM(int signal) {
     if (newStdOut != -1) {
         dup2(newStdOut, 1);
     }
-    std::cout << "Tests timeout in " << NEO::executionName << ", ";
+    std::cout << "Tests timeout in " << NEO::apiName << " " << NEO::executionName << ",";
     if (clock_gettime(CLOCK_MONOTONIC_RAW, &alrmTimeSpec) == 0) {
         auto deltaSec = alrmTimeSpec.tv_sec - startTimeSpec.tv_sec;
         std::cout << " after: " << deltaSec << " seconds";
@@ -57,7 +58,7 @@ void handleSIGSEGV(int signal) {
     if (newStdOut != -1) {
         dup2(newStdOut, 1);
     }
-    std::cout << "SIGSEGV in " << NEO::executionName << ", on: " << lastTest << std::endl;
+    std::cout << "SIGSEGV in " << NEO::apiName << " " << NEO::executionName << ", on: " << lastTest << std::endl;
     abort();
 }
 
@@ -92,12 +93,18 @@ int setAlarm(bool enableAlarm) {
             startTimeSpec.tv_sec = 0;
         }
 
-        auto currentUltIterationMaxTime = NEO::ultIterationMaxTime;
-        auto ultIterationMaxTimeEnv = getenv("NEO_ULT_ITERATION_MAX_TIME");
-        if (ultIterationMaxTimeEnv != nullptr) {
-            currentUltIterationMaxTime = atoi(ultIterationMaxTimeEnv);
+        auto currentUltIterationMaxTimeInS = NEO::ultIterationMaxTimeInS;
+        std::string envVar = std::string("NEO_") + NEO::executionName + "_ITERATION_MAX_TIME";
+        auto ultIterationMaxTimeInSEnv = getenv(envVar.c_str());
+        if (ultIterationMaxTimeInSEnv != nullptr) {
+            currentUltIterationMaxTimeInS = atoi(ultIterationMaxTimeInSEnv);
+        } else {
+            ultIterationMaxTimeInSEnv = getenv("NEO_ULT_ITERATION_MAX_TIME");
+            if (ultIterationMaxTimeInSEnv != nullptr) {
+                currentUltIterationMaxTimeInS = atoi(ultIterationMaxTimeInSEnv);
+            }
         }
-        unsigned int alarmTime = currentUltIterationMaxTime * ::testing::GTEST_FLAG(repeat);
+        unsigned int alarmTime = currentUltIterationMaxTimeInS * ::testing::GTEST_FLAG(repeat);
 
         struct sigaction sa;
         sa.sa_handler = &handleSIGALRM;
@@ -111,7 +118,7 @@ int setAlarm(bool enableAlarm) {
             newStdOut = dup(1);
         }
         alarm(alarmTime);
-        std::cout << "set timeout to: " << alarmTime << std::endl;
+        std::cout << "set timeout to: " << alarmTime << " seconds" << std::endl;
     }
     return 0;
 }
@@ -131,3 +138,5 @@ int setSegv(bool enableSegv) {
     }
     return 0;
 }
+
+void cleanupSignals() {}
