@@ -6,6 +6,7 @@
  */
 
 #pragma once
+#include "shared/test/common/helpers/variable_backup.h"
 
 #include <atomic>
 #include <cstdint>
@@ -14,8 +15,12 @@
 #include <poll.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <unordered_map>
 #include <vector>
 
+extern "C" {
+extern char **environ;
+}
 namespace NEO {
 namespace SysCalls {
 
@@ -103,5 +108,22 @@ extern std::string dlOpenFilePathPassed;
 extern std::string mkfifoPathNamePassed;
 
 extern long sysconfReturn;
+char **getEnviron();
 } // namespace SysCalls
+namespace ULT {
+char **getCurrentEnviron();
+void setMockEnviron(char **mock);
+
+class MockEnvironBackup {
+  public:
+    MockEnvironBackup(char **newEnviron);
+    ~MockEnvironBackup() = default;
+
+    static int defaultStatMock(const std::string &filePath, struct stat *statbuf) noexcept;
+    static std::vector<char *> buildEnvironFromMap(const std::unordered_map<std::string, std::string> &envs, std::vector<std::string> &storage);
+
+  private:
+    VariableBackup<char **> mockEnvironBackup;
+};
+} // namespace ULT
 } // namespace NEO
