@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2024 Intel Corporation
+ * Copyright (C) 2024-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -15,7 +15,10 @@ class MockEuDebugInterface : public EuDebugInterface {
     static constexpr const char *sysFsXeEuDebugFile = "/mock_eudebug";
     static constexpr uintptr_t sysFsFd = 0xE0DEB0;
     static constexpr EuDebugInterfaceType euDebugInterfaceType = EuDebugInterfaceType::upstream;
+    bool isExecQueuePageFaultEnableSupported() override { return pageFaultEnableSupported; };
     uint32_t getParamValue(EuDebugParam param) const override;
+
+    bool pageFaultEnableSupported = false;
 };
 
 } // namespace NEO
