@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2023 Intel Corporation
+ * Copyright (C) 2021-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -55,6 +55,12 @@ struct Test
       public:                                                                                                                                             \
         GTEST_TEST_CLASS_NAME_(test_suite_name, test_name)                                                                                                \
         () {}                                                                                                                                             \
+        GTEST_TEST_CLASS_NAME_(test_suite_name, test_name)                                                                                                \
+        (const GTEST_TEST_CLASS_NAME_(test_suite_name, test_name) &) = delete;                                                                            \
+        GTEST_TEST_CLASS_NAME_(test_suite_name, test_name)                                                                                                \
+        (GTEST_TEST_CLASS_NAME_(test_suite_name, test_name) &&) = delete;                                                                                 \
+        GTEST_TEST_CLASS_NAME_(test_suite_name, test_name) &operator=(const GTEST_TEST_CLASS_NAME_(test_suite_name, test_name) &) = delete;               \
+        GTEST_TEST_CLASS_NAME_(test_suite_name, test_name) &operator=(GTEST_TEST_CLASS_NAME_(test_suite_name, test_name) &&) = delete;                    \
         void TestBody() override;                                                                                                                         \
                                                                                                                                                           \
       private:                                                                                                                                            \
@@ -65,12 +71,11 @@ struct Test
                     #test_suite_name,                                                                                                                     \
                     #test_name,                                                                                                                           \
                     new ::testing::internal::TestMetaFactory<                                                                                             \
-                        GTEST_TEST_CLASS_NAME_(test_suite_name, test_name)>());                                                                           \
+                        GTEST_TEST_CLASS_NAME_(test_suite_name, test_name)>(),                                                                            \
+                    ::testing::internal::CodeLocation(__FILE__, __LINE__));                                                                               \
             return 0;                                                                                                                                     \
         }                                                                                                                                                 \
         static int gtest_registering_dummy_;                                                                                                              \
-        GTEST_DISALLOW_COPY_AND_ASSIGN_(                                                                                                                  \
-            GTEST_TEST_CLASS_NAME_(test_suite_name, test_name));                                                                                          \
     };                                                                                                                                                    \
     int GTEST_TEST_CLASS_NAME_(test_suite_name,                                                                                                           \
                                test_name)::gtest_registering_dummy_ =                                                                                     \
