@@ -1,12 +1,12 @@
 /*
- * Copyright (C) 2024 Intel Corporation
+ * Copyright (C) 2024-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
-#include "platforms.h"
+#include "neo_aot_platforms.h"
 
 namespace AOT_BMG {
 constexpr AOT::PRODUCT_CONFIG productConfigs[] = {AOT::BMG_G21_A0};
