@@ -1,12 +1,12 @@
 /*
- * Copyright (C) 2022 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
-#include "platforms.h"
+#include "neo_aot_platforms.h"
 
 namespace AOT_PVC {
 inline constexpr AOT::PRODUCT_CONFIG productConfigs[] = {
@@ -15,5 +15,6 @@ inline constexpr AOT::PRODUCT_CONFIG productConfigs[] = {
     AOT::PVC_XT_A0,
     AOT::PVC_XT_B0,
     AOT::PVC_XT_B1,
-    AOT::PVC_XT_C0};
+    AOT::PVC_XT_C0,
+    AOT::PVC_XT_C0_VG};
 }
