@@ -49,6 +49,11 @@ bool UnitTestHelper<Family>::requiresTimestampPacketsInSystemMemory(HardwareInfo
     return true;
 }
 
+template <>
+void UnitTestHelper<Family>::skipStatePrefetch(GenCmdList::iterator &iter) {}
+
 template struct UnitTestHelper<Family>;
 template struct UnitTestHelperWithHeap<Family>;
+
+template uint64_t UnitTestHelper<Family>::getWalkerActivePostSyncAddress<Family::COMPUTE_WALKER>(Family::COMPUTE_WALKER *walkerCmd);
 } // namespace NEO
