@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -15,7 +15,7 @@
 #include "shared/test/common/test_macros/test_base.h"
 
 #include "gtest/gtest.h"
-#include "platforms.h"
+#include "neo_aot_platforms.h"
 
 using namespace NEO;
 
@@ -45,4 +45,3 @@ struct ProductConfigHwInfoTests : public ProductConfigTest<::testing::TestWithPa
 };
 
 using ProductConfigTests = ProductConfigTest<::testing::Test>;
-using ProductConfigHwInfoBadArchTests = ProductConfigHwInfoTests;
