@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -20,7 +20,8 @@ TEST(FileIO, GivenNonEmptyFileWhenCheckingIfHasSizeThenReturnTrue) {
 
     ASSERT_FALSE(virtualFileExists(fileName.c_str()));
 
-    writeDataToFile(fileName.c_str(), "TEST", 4);
+    constexpr std::string_view data = "TEST";
+    writeDataToFile(fileName.c_str(), data);
 
     EXPECT_TRUE(virtualFileExists(fileName.c_str()));
     EXPECT_TRUE(fileExistsHasSize(fileName.c_str()));
@@ -35,7 +36,8 @@ TEST(FileIO, GivenEmptyFileWhenCheckingIfHasSizeThenReturnFalse) {
 
     ASSERT_FALSE(virtualFileExists(fileName.c_str()));
 
-    writeDataToFile(fileName.c_str(), "", 0);
+    constexpr std::string_view data = "";
+    writeDataToFile(fileName.c_str(), data);
 
     EXPECT_TRUE(virtualFileExists(fileName.c_str()));
     EXPECT_FALSE(fileExistsHasSize(fileName.c_str()));
