@@ -385,6 +385,38 @@ TEST(MemoryManagerTest, givenEnabled64kbPagesWhenGraphicsMemoryWithoutAllow64kbP
     memoryManager.freeGraphicsMemory(allocation);
 }
 
+TEST(MemoryManagerTest, givenEnabled64kbPagesWhenGraphicsMemoryWith128kbAlignmentCreatedThen64kbAllocationIsReturned) {
+    MockExecutionEnvironment executionEnvironment(defaultHwInfo.get());
+    MockMemoryManager memoryManager(true, false, executionEnvironment);
+    AllocationData allocData;
+    AllocationProperties properties(mockRootDeviceIndex, 10, AllocationType::buffer, mockDeviceBitfield);
+
+    memoryManager.getAllocationData(allocData, properties, nullptr, memoryManager.createStorageInfoFromProperties(properties));
+    allocData.flags.allow64kbPages = true;
+    allocData.alignment = 2 * MemoryConstants::pageSize64k;
+
+    auto allocation = memoryManager.allocateGraphicsMemory(allocData);
+    EXPECT_TRUE(memoryManager.allocation64kbPageCreated);
+
+    memoryManager.freeGraphicsMemory(allocation);
+}
+
+TEST(MemoryManagerTest, givenEnabled64kbPagesWhenGraphicsMemoryWith32kbAlignmentCreatedThen64kbAllocationIsReturned) {
+    MockExecutionEnvironment executionEnvironment(defaultHwInfo.get());
+    MockMemoryManager memoryManager(true, false, executionEnvironment);
+    AllocationData allocData;
+    AllocationProperties properties(mockRootDeviceIndex, 10, AllocationType::buffer, mockDeviceBitfield);
+
+    memoryManager.getAllocationData(allocData, properties, nullptr, memoryManager.createStorageInfoFromProperties(properties));
+    allocData.flags.allow64kbPages = true;
+    allocData.alignment = MemoryConstants::pageSize64k / 2;
+
+    auto allocation = memoryManager.allocateGraphicsMemory(allocData);
+    EXPECT_TRUE(memoryManager.allocation64kbPageCreated);
+
+    memoryManager.freeGraphicsMemory(allocation);
+}
+
 TEST(MemoryManagerTest, givenDisabled64kbPagesWhenGraphicsMemoryMustBeHostMemoryAndIsAllocatedWithNullptrForBufferThenNon64kbAllocationIsReturned) {
     MockExecutionEnvironment executionEnvironment(defaultHwInfo.get());
     MockMemoryManager memoryManager(false, false, executionEnvironment);
@@ -1140,7 +1172,7 @@ TEST(MemoryManagerTest, givenMemoryManagerWhenAllocationIsCommandBufferAndMultiC
     memoryManager.mockGa = &mockGa;
     memoryManager.returnMockGAFromDevicePool = true;
 
-    AllocationProperties properties(mockRootDeviceIndex, MemoryConstants::pageSize, AllocationType::buffer, mockDeviceBitfield);
+    AllocationProperties properties(mockRootDeviceIndex, MemoryConstants::pageSize, AllocationType::commandBuffer, mockDeviceBitfield);
     properties.flags.cantBeReadOnly = false;
     properties.flags.multiOsContextCapable = true;
 
