@@ -245,13 +245,13 @@ TEST_F(CcsModeTest, GivenValidCcsModeAndOpenSysCallFailsWithNoPermissionsWhenCon
 
     StreamCapture capture;
     capture.captureStdout();
-    testing::internal::CaptureStderr();
+    capture.captureStderr();
 
     debugManager.flags.ZEX_NUMBER_OF_CCS.set("2");
     executionEnvironment->configureCcsMode();
 
     std::string stdOutString = capture.getCapturedStdout();
-    std::string stdErrString = testing::internal::GetCapturedStderr();
+    std::string stdErrString = capture.getCapturedStderr();
     std::string expectedOutput = "No read and write permissions for /sys/class/drm/card0/gt/gt0/ccs_mode, System administrator needs to grant permissions to allow modification of this file from user space\n";
 
     EXPECT_EQ(1u, ccsMode);
@@ -285,13 +285,13 @@ TEST_F(CcsModeTest, GivenValidCcsModeAndOpenSysCallFailsWithNoAccessWhenConfigur
 
     StreamCapture capture;
     capture.captureStdout();
-    testing::internal::CaptureStderr();
+    capture.captureStderr();
 
     debugManager.flags.ZEX_NUMBER_OF_CCS.set("2");
     executionEnvironment->configureCcsMode();
 
     std::string stdOutString = capture.getCapturedStdout();
-    std::string stdErrString = testing::internal::GetCapturedStderr();
+    std::string stdErrString = capture.getCapturedStderr();
     std::string expectedOutput = "No read and write permissions for /sys/class/drm/card0/gt/gt0/ccs_mode, System administrator needs to grant permissions to allow modification of this file from user space\n";
 
     EXPECT_EQ(1u, ccsMode);
