@@ -1,12 +1,10 @@
 /*
- * Copyright (C) 2022 Intel Corporation
+ * Copyright (C) 2022-2023 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
-#include "shared/source/os_interface/os_interface.h"
-#include "shared/test/common/libult/linux/drm_mock.h"
 #include "shared/test/common/os_interface/linux/device_command_stream_fixture_prelim.h"
 #include "shared/test/common/os_interface/linux/drm_buffer_object_fixture.h"
 #include "shared/test/common/test_macros/test.h"
@@ -17,8 +15,8 @@ using DrmBufferObjectPrelimFixture = DrmBufferObjectFixture<DrmMockCustomPrelim>
 using DrmBufferObjectPrelimTest = Test<DrmBufferObjectPrelimFixture>;
 
 TEST_F(DrmBufferObjectPrelimTest, GivenCompletionAddressWhenCallingExecThenReturnIsCorrect) {
-    mock->ioctl_expected.total = 1;
-    mock->ioctl_res = 0;
+    mock->ioctlExpected.total = 1;
+    mock->ioctlRes = 0;
 
     constexpr uint64_t completionAddress = 0x1230;
     constexpr uint32_t completionValue = 33;
