@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -22,13 +22,13 @@
 #include "gtest/gtest.h"
 
 TEST_F(DrmMemoryManagerLocalMemoryPrelimTest, givenCreateDebugSurfaceWithUnalignedSizeCalledThenNullptrReturned) {
-    AllocationProperties debugSurfaceProperties{0, true, MemoryConstants::pageSize + 101, NEO::AllocationType::DEBUG_CONTEXT_SAVE_AREA, false, false, 0b1011};
+    AllocationProperties debugSurfaceProperties{0, true, MemoryConstants::pageSize + 101, NEO::AllocationType::debugContextSaveArea, false, false, 0b1011};
     auto debugSurface = memoryManager->allocateGraphicsMemoryWithProperties(debugSurfaceProperties);
     EXPECT_EQ(nullptr, debugSurface);
 }
 
 TEST_F(DrmMemoryManagerLocalMemoryPrelimTest, givenCreateDebugSurfaceAndAlignedMallocFailedThenNullptrReturned) {
-    AllocationProperties debugSurfaceProperties{0, true, MemoryConstants::pageSize, NEO::AllocationType::DEBUG_CONTEXT_SAVE_AREA, false, false, 0b1011};
+    AllocationProperties debugSurfaceProperties{0, true, MemoryConstants::pageSize, NEO::AllocationType::debugContextSaveArea, false, false, 0b1011};
     memoryManager->alignedMallocShouldFail = true;
     auto debugSurface = memoryManager->allocateGraphicsMemoryWithProperties(debugSurfaceProperties);
     memoryManager->alignedMallocShouldFail = false;
@@ -37,7 +37,7 @@ TEST_F(DrmMemoryManagerLocalMemoryPrelimTest, givenCreateDebugSurfaceAndAlignedM
 
 TEST_F(DrmMemoryManagerLocalMemoryWithCustomPrelimMockTest, givenCreateDebugSurfaceAndAllocUserptrFailedThenNullptrReturned) {
     mock->ioctlRes = -1;
-    AllocationProperties debugSurfaceProperties{0, true, MemoryConstants::pageSize, NEO::AllocationType::DEBUG_CONTEXT_SAVE_AREA, false, false, 0b1011};
+    AllocationProperties debugSurfaceProperties{0, true, MemoryConstants::pageSize, NEO::AllocationType::debugContextSaveArea, false, false, 0b1011};
     auto debugSurface = memoryManager->allocateGraphicsMemoryWithProperties(debugSurfaceProperties);
     mock->ioctlRes = 0;
     EXPECT_EQ(1, mock->ioctlCnt.gemUserptr);
@@ -45,12 +45,12 @@ TEST_F(DrmMemoryManagerLocalMemoryWithCustomPrelimMockTest, givenCreateDebugSurf
 }
 
 TEST_F(DrmMemoryManagerLocalMemoryWithCustomPrelimMockTest, givenCreateDebugSurfaceSuccessThenCorrectMultiHostAllocationReturned) {
-    AllocationProperties debugSurfaceProperties{0, true, MemoryConstants::pageSize, NEO::AllocationType::DEBUG_CONTEXT_SAVE_AREA, false, false, 0b1011};
+    AllocationProperties debugSurfaceProperties{0, true, MemoryConstants::pageSize, NEO::AllocationType::debugContextSaveArea, false, false, 0b1011};
     auto debugSurface = static_cast<DrmAllocation *>(memoryManager->allocateGraphicsMemoryWithProperties(debugSurfaceProperties));
 
     EXPECT_NE(nullptr, debugSurface);
 
-    EXPECT_EQ(MemoryPool::System4KBPages, debugSurface->getMemoryPool());
+    EXPECT_EQ(MemoryPool::system4KBPages, debugSurface->getMemoryPool());
     EXPECT_EQ(3u, debugSurface->getNumGmms());
     EXPECT_EQ(3, mock->ioctlCnt.gemUserptr);
 
@@ -63,8 +63,8 @@ TEST_F(DrmMemoryManagerLocalMemoryWithCustomPrelimMockTest, givenCreateDebugSurf
     EXPECT_NE(reinterpret_cast<uint64_t>(debugSurface->getUnderlyingBuffer()), gpuAddress);
 
     auto gmmHelper = device.get()->getGmmHelper();
-    EXPECT_GE(gmmHelper->decanonize(gpuAddress), gfxPartition->getHeapBase(HeapIndex::HEAP_STANDARD));
-    EXPECT_LT(gmmHelper->decanonize(gpuAddress), gfxPartition->getHeapLimit(HeapIndex::HEAP_STANDARD));
+    EXPECT_GE(gmmHelper->decanonize(gpuAddress), gfxPartition->getHeapBase(HeapIndex::heapStandard));
+    EXPECT_LT(gmmHelper->decanonize(gpuAddress), gfxPartition->getHeapLimit(HeapIndex::heapStandard));
 
     auto &storageInfo = debugSurface->storageInfo;
     auto &bos = debugSurface->getBOs();
@@ -84,7 +84,6 @@ TEST_F(DrmMemoryManagerLocalMemoryWithCustomPrelimMockTest, givenCreateDebugSurf
     EXPECT_EQ(0b1011u, storageInfo.pageTablesVisibility.to_ulong());
     EXPECT_FALSE(storageInfo.cloningOfPageTables);
     EXPECT_FALSE(storageInfo.multiStorage);
-    EXPECT_FALSE(storageInfo.readOnlyMultiStorage);
     EXPECT_TRUE(storageInfo.tileInstanced);
     EXPECT_TRUE(storageInfo.cpuVisibleSegment);
     EXPECT_TRUE(storageInfo.isLockable);
