@@ -1,11 +1,12 @@
 /*
- * Copyright (C) 2022-2023 Intel Corporation
+ * Copyright (C) 2022-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #include "shared/source/pin/pin.h"
+#include "shared/test/common/helpers/variable_backup.h"
 #include "shared/test/common/mocks/mock_os_library.h"
 
 #include "gtest/gtest.h"
@@ -15,7 +16,7 @@ namespace ULT {
 TEST(PinInitializationTest, GivenValidLibraryPinContextInitSucceeds) {
     uint32_t (*openPinHandler)(void *) = [](void *arg) -> uint32_t { return 0; };
     MockOsLibrary::loadLibraryNewObject = new MockOsLibrary(reinterpret_cast<void *>(openPinHandler), false);
-    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
+    VariableBackup<decltype(NEO::OsLibrary::loadFunc)> funcBackup{&NEO::OsLibrary::loadFunc, MockOsLibrary::load};
     std::string mockGTPinFunctionName{"aaa"};
     EXPECT_TRUE(NEO::PinContext::init(mockGTPinFunctionName));
 
@@ -24,7 +25,7 @@ TEST(PinInitializationTest, GivenValidLibraryPinContextInitSucceeds) {
 
 TEST(PinInitializationTest, GivenBadLibraryNamePinContextInitFAILS) {
     MockOsLibrary::loadLibraryNewObject = nullptr;
-    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
+    VariableBackup<decltype(NEO::OsLibrary::loadFunc)> funcBackup{&NEO::OsLibrary::loadFunc, MockOsLibrary::load};
     std::string mockGTPinFunctionName{"aaa"};
     EXPECT_FALSE(NEO::PinContext::init(mockGTPinFunctionName));
 
@@ -33,7 +34,7 @@ TEST(PinInitializationTest, GivenBadLibraryNamePinContextInitFAILS) {
 
 TEST(PinInitializationTest, GivenBadProcAddressPinContextInitFAILS) {
     MockOsLibrary::loadLibraryNewObject = new MockOsLibrary(nullptr, false);
-    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
+    VariableBackup<decltype(NEO::OsLibrary::loadFunc)> funcBackup{&NEO::OsLibrary::loadFunc, MockOsLibrary::load};
     std::string mockGTPinFunctionName{"aaa"};
     EXPECT_FALSE(NEO::PinContext::init(mockGTPinFunctionName));
 
@@ -43,7 +44,7 @@ TEST(PinInitializationTest, GivenBadProcAddressPinContextInitFAILS) {
 TEST(PinInitializationTest, GivenBadPinHandlerPinContextInitFAILS) {
     uint32_t (*openPinHandler)(void *) = [](void *arg) -> uint32_t { return 1; };
     MockOsLibrary::loadLibraryNewObject = new MockOsLibrary(reinterpret_cast<void *>(openPinHandler), false);
-    NEO::PinContext::osLibraryLoadFunction = MockOsLibrary::load;
+    VariableBackup<decltype(NEO::OsLibrary::loadFunc)> funcBackup{&NEO::OsLibrary::loadFunc, MockOsLibrary::load};
     std::string mockGTPinFunctionName{"aaa"};
     EXPECT_FALSE(NEO::PinContext::init(mockGTPinFunctionName));
 
