@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,6 +7,7 @@
 
 #include "shared/source/compiler_interface/external_functions.h"
 #include "shared/source/gmm_helper/gmm.h"
+#include "shared/source/helpers/aligned_memory.h"
 #include "shared/source/helpers/blit_helper.h"
 #include "shared/source/helpers/local_memory_access_modes.h"
 #include "shared/source/program/program_initialization.h"
@@ -27,52 +28,53 @@ TEST(AllocateGlobalSurfaceTest, GivenSvmAllocsManagerWhenGlobalsAreNotExportedTh
     MockDevice device{};
     REQUIRE_SVM_OR_SKIP(&device);
     device.injectMemoryManager(new MockMemoryManager());
-    MockSVMAllocsManager svmAllocsManager(device.getMemoryManager(), false);
+    MockSVMAllocsManager svmAllocsManager(device.getMemoryManager());
     WhiteBox<LinkerInput> emptyLinkerInput;
     std::vector<uint8_t> initData;
     initData.resize(64, 7U);
     GraphicsAllocation *alloc = nullptr;
 
+    size_t aligmentSize = alignUp(initData.size(), MemoryConstants::pageSize);
     alloc = allocateGlobalsSurface(&svmAllocsManager, device, initData.size(), 0u, true /* constant */, nullptr /* linker input */, initData.data());
     ASSERT_NE(nullptr, alloc);
-    ASSERT_EQ(initData.size(), alloc->getUnderlyingBufferSize());
+    ASSERT_EQ(aligmentSize, alloc->getUnderlyingBufferSize());
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
     EXPECT_EQ(nullptr, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(alloc->getGpuAddress()))));
-    EXPECT_EQ(AllocationType::CONSTANT_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(AllocationType::constantSurface, alloc->getAllocationType());
     device.getMemoryManager()->freeGraphicsMemory(alloc);
 
     alloc = allocateGlobalsSurface(&svmAllocsManager, device, initData.size(), 0u, false /* constant */, nullptr /* linker input */, initData.data());
     ASSERT_NE(nullptr, alloc);
-    ASSERT_EQ(initData.size(), alloc->getUnderlyingBufferSize());
+    ASSERT_EQ(aligmentSize, alloc->getUnderlyingBufferSize());
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
     EXPECT_EQ(nullptr, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(alloc->getGpuAddress()))));
-    EXPECT_EQ(AllocationType::GLOBAL_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(AllocationType::globalSurface, alloc->getAllocationType());
     device.getMemoryManager()->freeGraphicsMemory(alloc);
 
     alloc = allocateGlobalsSurface(&svmAllocsManager, device, initData.size(), 0u, true /* constant */, &emptyLinkerInput, initData.data());
     ASSERT_NE(nullptr, alloc);
-    ASSERT_EQ(initData.size(), alloc->getUnderlyingBufferSize());
+    ASSERT_EQ(aligmentSize, alloc->getUnderlyingBufferSize());
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
     EXPECT_EQ(nullptr, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(alloc->getGpuAddress()))));
-    EXPECT_EQ(AllocationType::CONSTANT_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(AllocationType::constantSurface, alloc->getAllocationType());
     device.getMemoryManager()->freeGraphicsMemory(alloc);
 
     alloc = allocateGlobalsSurface(&svmAllocsManager, device, initData.size(), 0u, false /* constant */, &emptyLinkerInput, initData.data());
     ASSERT_NE(nullptr, alloc);
-    ASSERT_EQ(initData.size(), alloc->getUnderlyingBufferSize());
+    ASSERT_EQ(aligmentSize, alloc->getUnderlyingBufferSize());
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
     EXPECT_EQ(nullptr, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(alloc->getGpuAddress()))));
-    EXPECT_EQ(AllocationType::GLOBAL_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(AllocationType::globalSurface, alloc->getAllocationType());
     device.getMemoryManager()->freeGraphicsMemory(alloc);
 }
 
 TEST(AllocateGlobalSurfaceTest, GivenSvmAllocsManagerWhenGlobalsAreExportedThenMemoryIsAllocatedAsUsmDeviceAllocation) {
     DebugManagerStateRestore restorer;
-    DebugManager.flags.ForceLocalMemoryAccessMode.set(0);
+    debugManager.flags.ForceLocalMemoryAccessMode.set(0);
     MockDevice device{};
     REQUIRE_SVM_OR_SKIP(&device);
     device.injectMemoryManager(new MockMemoryManager());
-    MockSVMAllocsManager svmAllocsManager(device.getMemoryManager(), false);
+    MockSVMAllocsManager svmAllocsManager(device.getMemoryManager());
     WhiteBox<LinkerInput> linkerInputExportGlobalVariables;
     WhiteBox<LinkerInput> linkerInputExportGlobalConstants;
     linkerInputExportGlobalVariables.traits.exportsGlobalVariables = true;
@@ -80,6 +82,7 @@ TEST(AllocateGlobalSurfaceTest, GivenSvmAllocsManagerWhenGlobalsAreExportedThenM
     std::vector<uint8_t> initData;
     initData.resize(64, 7U);
     GraphicsAllocation *alloc = nullptr;
+    size_t expectedAlignedSize = alignUp(initData.size(), MemoryConstants::pageSize);
 
     alloc = allocateGlobalsSurface(&svmAllocsManager, device, initData.size(), 0u, true /* constant */, &linkerInputExportGlobalConstants, initData.data());
     ASSERT_NE(nullptr, alloc);
@@ -87,25 +90,28 @@ TEST(AllocateGlobalSurfaceTest, GivenSvmAllocsManagerWhenGlobalsAreExportedThenM
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
     ASSERT_NE(nullptr, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(alloc->getGpuAddress()))));
     EXPECT_TRUE(alloc->isMemObjectsAllocationWithWritableFlags());
-    EXPECT_EQ(DEVICE_UNIFIED_MEMORY, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(alloc->getGpuAddress()))->memoryType);
-    EXPECT_EQ(AllocationType::CONSTANT_SURFACE, alloc->getAllocationType());
+    auto svmData = svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(alloc->getGpuAddress()));
+    EXPECT_EQ(InternalMemoryType::deviceUnifiedMemory, svmData->memoryType);
+    EXPECT_TRUE(svmData->isInternalAllocation);
+    EXPECT_EQ(AllocationType::constantSurface, alloc->getAllocationType());
     EXPECT_FALSE(alloc->getDefaultGmm()->resourceParams.Flags.Info.NotLockable);
+    EXPECT_TRUE(svmAllocsManager.requestedZeroedOutAllocation);
     svmAllocsManager.freeSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(alloc->getGpuAddress())));
 
     alloc = allocateGlobalsSurface(&svmAllocsManager, device, initData.size(), 0u, true /* constant */, &linkerInputExportGlobalVariables, initData.data());
     ASSERT_NE(nullptr, alloc);
-    ASSERT_EQ(initData.size(), alloc->getUnderlyingBufferSize());
+    ASSERT_EQ(expectedAlignedSize, alloc->getUnderlyingBufferSize());
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
     EXPECT_EQ(nullptr, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(alloc->getGpuAddress()))));
-    EXPECT_EQ(AllocationType::CONSTANT_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(AllocationType::constantSurface, alloc->getAllocationType());
     device.getMemoryManager()->freeGraphicsMemory(alloc);
 
     alloc = allocateGlobalsSurface(&svmAllocsManager, device, initData.size(), 0u, false /* constant */, &linkerInputExportGlobalConstants, initData.data());
     ASSERT_NE(nullptr, alloc);
-    ASSERT_EQ(initData.size(), alloc->getUnderlyingBufferSize());
+    ASSERT_EQ(expectedAlignedSize, alloc->getUnderlyingBufferSize());
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
     EXPECT_EQ(nullptr, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(alloc->getGpuAddress()))));
-    EXPECT_EQ(AllocationType::GLOBAL_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(AllocationType::globalSurface, alloc->getAllocationType());
     device.getMemoryManager()->freeGraphicsMemory(alloc);
 
     alloc = allocateGlobalsSurface(&svmAllocsManager, device, initData.size(), 0u, false /* constant */, &linkerInputExportGlobalVariables, initData.data());
@@ -114,8 +120,8 @@ TEST(AllocateGlobalSurfaceTest, GivenSvmAllocsManagerWhenGlobalsAreExportedThenM
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
     EXPECT_NE(nullptr, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(alloc->getGpuAddress()))));
     EXPECT_TRUE(alloc->isMemObjectsAllocationWithWritableFlags());
-    EXPECT_EQ(DEVICE_UNIFIED_MEMORY, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(alloc->getGpuAddress()))->memoryType);
-    EXPECT_EQ(AllocationType::GLOBAL_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(InternalMemoryType::deviceUnifiedMemory, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(alloc->getGpuAddress()))->memoryType);
+    EXPECT_EQ(AllocationType::globalSurface, alloc->getAllocationType());
     EXPECT_FALSE(alloc->getDefaultGmm()->resourceParams.Flags.Info.NotLockable);
     svmAllocsManager.freeSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(alloc->getGpuAddress())));
 }
@@ -130,33 +136,34 @@ TEST(AllocateGlobalSurfaceTest, GivenNullSvmAllocsManagerWhenGlobalsAreExportedT
     std::vector<uint8_t> initData;
     initData.resize(64, 7U);
     GraphicsAllocation *alloc = nullptr;
+    size_t expectedAlignedSize = alignUp(initData.size(), MemoryConstants::pageSize);
 
     alloc = allocateGlobalsSurface(nullptr, device, initData.size(), 0u, true /* constant */, &linkerInputExportGlobalConstants, initData.data());
     ASSERT_NE(nullptr, alloc);
-    ASSERT_EQ(initData.size(), alloc->getUnderlyingBufferSize());
+    ASSERT_EQ(expectedAlignedSize, alloc->getUnderlyingBufferSize());
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
-    EXPECT_EQ(AllocationType::CONSTANT_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(AllocationType::constantSurface, alloc->getAllocationType());
     device.getMemoryManager()->freeGraphicsMemory(alloc);
 
     alloc = allocateGlobalsSurface(nullptr, device, initData.size(), 0u, true /* constant */, &linkerInputExportGlobalVariables, initData.data());
     ASSERT_NE(nullptr, alloc);
-    ASSERT_EQ(initData.size(), alloc->getUnderlyingBufferSize());
+    ASSERT_EQ(expectedAlignedSize, alloc->getUnderlyingBufferSize());
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
-    EXPECT_EQ(AllocationType::CONSTANT_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(AllocationType::constantSurface, alloc->getAllocationType());
     device.getMemoryManager()->freeGraphicsMemory(alloc);
 
     alloc = allocateGlobalsSurface(nullptr, device, initData.size(), 0u, false /* constant */, &linkerInputExportGlobalConstants, initData.data());
     ASSERT_NE(nullptr, alloc);
-    ASSERT_EQ(initData.size(), alloc->getUnderlyingBufferSize());
+    ASSERT_EQ(expectedAlignedSize, alloc->getUnderlyingBufferSize());
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
-    EXPECT_EQ(AllocationType::GLOBAL_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(AllocationType::globalSurface, alloc->getAllocationType());
     device.getMemoryManager()->freeGraphicsMemory(alloc);
 
     alloc = allocateGlobalsSurface(nullptr, device, initData.size(), 0u, false /* constant */, &linkerInputExportGlobalVariables, initData.data());
     ASSERT_NE(nullptr, alloc);
-    ASSERT_EQ(initData.size(), alloc->getUnderlyingBufferSize());
+    ASSERT_EQ(expectedAlignedSize, alloc->getUnderlyingBufferSize());
     EXPECT_EQ(0, memcmp(alloc->getUnderlyingBuffer(), initData.data(), initData.size()));
-    EXPECT_EQ(AllocationType::GLOBAL_SURFACE, alloc->getAllocationType());
+    EXPECT_EQ(AllocationType::globalSurface, alloc->getAllocationType());
     device.getMemoryManager()->freeGraphicsMemory(alloc);
 }
 
@@ -165,7 +172,7 @@ TEST(AllocateGlobalSurfaceTest, WhenGlobalsAreNotExportedAndAllocationFailsThenG
     auto memoryManager = std::make_unique<MockMemoryManager>(*device.getExecutionEnvironment());
     memoryManager->failInAllocateWithSizeAndAlignment = true;
     device.injectMemoryManager(memoryManager.release());
-    MockSVMAllocsManager mockSvmAllocsManager(device.getMemoryManager(), false);
+    MockSVMAllocsManager mockSvmAllocsManager(device.getMemoryManager());
     WhiteBox<LinkerInput> emptyLinkerInput;
     std::vector<uint8_t> initData;
     initData.resize(64, 7U);
@@ -205,34 +212,34 @@ TEST(AllocateGlobalSurfaceTest, GivenAllocationInLocalMemoryWhichRequiresBlitter
     auto mockBlitMemoryToAllocation = [&blitsCounter](const Device &device, GraphicsAllocation *memory, size_t offset, const void *hostPtr,
                                                       Vec3<size_t> size) -> BlitOperationResult {
         blitsCounter++;
-        return BlitOperationResult::Success;
+        return BlitOperationResult::success;
     };
     VariableBackup<BlitHelperFunctions::BlitMemoryToAllocationFunc> blitMemoryToAllocationFuncBackup{
         &BlitHelperFunctions::blitMemoryToAllocation, mockBlitMemoryToAllocation};
 
     LocalMemoryAccessMode localMemoryAccessModes[] = {
-        LocalMemoryAccessMode::Default,
-        LocalMemoryAccessMode::CpuAccessAllowed,
-        LocalMemoryAccessMode::CpuAccessDisallowed};
+        LocalMemoryAccessMode::defaultMode,
+        LocalMemoryAccessMode::cpuAccessAllowed,
+        LocalMemoryAccessMode::cpuAccessDisallowed};
 
     std::vector<uint8_t> initData;
     initData.resize(64, 7U);
 
     for (auto localMemoryAccessMode : localMemoryAccessModes) {
-        DebugManager.flags.ForceLocalMemoryAccessMode.set(static_cast<int32_t>(localMemoryAccessMode));
+        debugManager.flags.ForceLocalMemoryAccessMode.set(static_cast<int32_t>(localMemoryAccessMode));
         for (auto isLocalMemorySupported : ::testing::Bool()) {
-            DebugManager.flags.EnableLocalMemory.set(isLocalMemorySupported);
+            debugManager.flags.EnableLocalMemory.set(isLocalMemorySupported);
             MockDevice device;
             device.getExecutionEnvironment()->rootDeviceEnvironments[0]->getMutableHardwareInfo()->capabilityTable.blitterOperationsSupported = true;
-            MockSVMAllocsManager svmAllocsManager(device.getMemoryManager(), false);
+            MockSVMAllocsManager svmAllocsManager(device.getMemoryManager());
 
             auto pAllocation = allocateGlobalsSurface(&svmAllocsManager, device, initData.size(), 0u, true /* constant */,
                                                       nullptr /* linker input */, initData.data());
             ASSERT_NE(nullptr, pAllocation);
             EXPECT_EQ(nullptr, svmAllocsManager.getSVMAlloc(reinterpret_cast<void *>(static_cast<uintptr_t>(pAllocation->getGpuAddress()))));
-            EXPECT_EQ(AllocationType::CONSTANT_SURFACE, pAllocation->getAllocationType());
+            EXPECT_EQ(AllocationType::constantSurface, pAllocation->getAllocationType());
 
-            if (pAllocation->isAllocatedInLocalMemoryPool() && (localMemoryAccessMode == LocalMemoryAccessMode::CpuAccessDisallowed)) {
+            if (pAllocation->isAllocatedInLocalMemoryPool() && (localMemoryAccessMode == LocalMemoryAccessMode::cpuAccessDisallowed)) {
                 expectedBlitsCount++;
             }
             EXPECT_EQ(expectedBlitsCount, blitsCounter);
@@ -251,10 +258,10 @@ TEST(AllocateGlobalSurfaceTest, whenAllocatingGlobalSurfaceWithNonZeroZeroInitSi
     std::fill(initData.begin() + 32, initData.end(), 16u); // this data should not be transfered
     GraphicsAllocation *alloc = nullptr;
     size_t zeroInitSize = 32u;
-
+    size_t expectedAlignedSize = alignUp(initData.size(), MemoryConstants::pageSize);
     alloc = allocateGlobalsSurface(nullptr, device, initData.size(), zeroInitSize, true, &emptyLinkerInput, initData.data());
     ASSERT_NE(nullptr, alloc);
-    EXPECT_EQ(64u, alloc->getUnderlyingBufferSize());
+    EXPECT_EQ(expectedAlignedSize, alloc->getUnderlyingBufferSize());
 
     auto dataPtr = reinterpret_cast<uint8_t *>(alloc->getUnderlyingBuffer());
     EXPECT_EQ(0, memcmp(dataPtr, initData.data(), 32u));
@@ -275,4 +282,4 @@ TEST(AllocateGlobalSurfaceTest, whenAllocatingGlobalSurfaceWithZeroInitSizeGreat
     EXPECT_EQ(0u, static_cast<MockMemoryManager *>(device.getMemoryManager())->copyMemoryToAllocationBanksCalled);
 
     device.getMemoryManager()->freeGraphicsMemory(alloc);
-}
\ No newline at end of file
+}
