@@ -115,19 +115,6 @@ void ReleaseHelperTestsBase::whenGettingSupportedNumGrfsThenValuesUpTo256Returne
     }
 }
 
-void ReleaseHelperTestsBase::whenGettingNumThreadsPerEuThenCorrectValueIsReturnedBasedOnEnable10ThreadsPerEuDebugKey() {
-    DebugManagerStateRestore restorer;
-    for (auto &revision : getRevisions()) {
-        ipVersion.revision = revision;
-        releaseHelper = ReleaseHelper::create(ipVersion);
-        ASSERT_NE(nullptr, releaseHelper);
-        debugManager.flags.Enable10ThreadsPerEu.set(0);
-        EXPECT_EQ(8u, releaseHelper->getNumThreadsPerEu());
-        debugManager.flags.Enable10ThreadsPerEu.set(1);
-        EXPECT_EQ(10u, releaseHelper->getNumThreadsPerEu());
-    }
-}
-
 void ReleaseHelperTestsBase::whenGettingNumThreadsPerEuThenCorrectValueIsReturnedBasedOnOverrideNumThreadsPerEuDebugKey() {
     DebugManagerStateRestore restorer;
     for (auto &revision : getRevisions()) {
@@ -193,4 +180,22 @@ void ReleaseHelperTestsBase::whenIsBlitImageAllowedForDepthFormatCalledThenTrueR
         ASSERT_NE(nullptr, releaseHelper);
         EXPECT_TRUE(releaseHelper->isBlitImageAllowedForDepthFormat());
     }
+}
+
+void ReleaseHelperTestsBase::whenProgrammAdditionalStallPriorToBarrierWithTimestampCalledThenFalseReturned() {
+    for (auto &revision : getRevisions()) {
+        ipVersion.revision = revision;
+        releaseHelper = ReleaseHelper::create(ipVersion);
+        ASSERT_NE(nullptr, releaseHelper);
+        EXPECT_FALSE(releaseHelper->programmAdditionalStallPriorToBarrierWithTimestamp());
+    }
+}
+
+void ReleaseHelperTestsBase::whenIsPostImageWriteFlushRequiredCalledThenFalseReturned() {
+    for (auto &revision : getRevisions()) {
+        ipVersion.revision = revision;
+        releaseHelper = ReleaseHelper::create(ipVersion);
+        ASSERT_NE(nullptr, releaseHelper);
+        EXPECT_FALSE(releaseHelper->isPostImageWriteFlushRequired());
+    }
 }
\ No newline at end of file
