@@ -10,7 +10,6 @@
 #include "shared/source/utilities/idlist.h"
 #include "shared/source/utilities/iflist.h"
 #include "shared/source/utilities/lookup_array.h"
-#include "shared/source/utilities/range.h"
 #include "shared/source/utilities/stackvec.h"
 #include "shared/test/unit_test/utilities/containers_tests_helpers.h"
 
@@ -21,6 +20,7 @@
 #include <memory>
 #include <numeric>
 #include <ranges>
+#include <span>
 #include <type_traits>
 #include <vector>
 
@@ -1495,6 +1495,26 @@ TEST(StackVec, WhenResizingThenElementsAreCorrectlyManaged) {
     EXPECT_FALSE(contains(&vec, &*vec.begin()));
 }
 
+TEST(StackVec, GivenNoDefaultValueWhenResizingThenDontUseCopyAssignment) {
+    struct Element {
+        Element() = default;
+
+        Element(Element &&rhs) = default;
+        Element &operator=(Element &&rhs) = default;
+
+        Element(const Element &rhs) = delete;
+        Element &operator=(const Element &rhs) = delete;
+
+        int v = 9;
+    };
+
+    StackVec<Element, 5> vec;
+    vec.resize(3);
+    EXPECT_EQ(9, vec[0].v);
+    EXPECT_EQ(9, vec[1].v);
+    EXPECT_EQ(9, vec[2].v);
+}
+
 TEST(StackVec, WhenIteratingThenCorrectElementsAreReturned) {
     using Type = int;
     StackVec<Type, 5> v;
@@ -1894,48 +1914,6 @@ TEST(ArrayRef, GivenArraysContainingSameDataWhenComparingThenEqualReturnsTrue) {
     EXPECT_TRUE(arrayA == arrayB);
 }
 
-TEST(Range, GivenRangeThenValidStandardIteratorsAreAvailable) {
-    int tab[10] = {2, 3, 5, 7, 11, 13, 17, 19, 23, 29};
-    Range<int> range = tab;
-    const Range<int> &constantRange = range;
-    Range<int> emptyRange{nullptr, 0};
-    EXPECT_EQ(0U, emptyRange.size());
-    EXPECT_TRUE(emptyRange.empty());
-    EXPECT_EQ(10U, constantRange.size());
-    EXPECT_FALSE(constantRange.empty());
-
-    auto rangeFwdIt = range.begin();
-    auto rangeFwdEnd = range.end();
-    auto rangeBackIt = range.rbegin();
-    auto rangeBackEnd = range.rend();
-
-    auto constantRangeFwdIt = constantRange.begin();
-    auto constantRangeFwdEnd = constantRange.end();
-    auto constantRangeBackIt = constantRange.rbegin();
-    auto constantRangeBackEnd = constantRange.rend();
-    for (int i = 0; i < 10; ++i, ++rangeFwdIt, ++rangeBackIt, ++constantRangeFwdIt, ++constantRangeBackIt) {
-        EXPECT_EQ(tab[i], *rangeFwdIt) << " it : " << i;
-        EXPECT_EQ(tab[i], *constantRangeFwdIt) << " it : " << i;
-        EXPECT_NE(rangeFwdEnd, rangeFwdIt) << " it : " << i;
-        EXPECT_NE(constantRangeFwdEnd, constantRangeFwdIt) << " it : " << i;
-
-        EXPECT_EQ(tab[10 - 1 - i], *rangeBackIt) << " it : " << i;
-        EXPECT_EQ(tab[10 - 1 - i], *constantRangeBackIt) << " it : " << i;
-        EXPECT_NE(rangeBackEnd, rangeBackIt) << " it : " << i;
-        EXPECT_NE(constantRangeBackEnd, constantRangeBackIt) << " it : " << i;
-    }
-
-    EXPECT_EQ(rangeFwdEnd, rangeFwdIt);
-    EXPECT_EQ(constantRangeFwdEnd, constantRangeFwdIt);
-    EXPECT_EQ(rangeBackEnd, rangeBackIt);
-    EXPECT_EQ(constantRangeBackEnd, constantRangeBackIt);
-
-    std::vector<int> vec(&tab[0], &tab[10]);
-    Range<int> rangeFromVec = vec;
-    EXPECT_EQ(&*vec.begin(), &*rangeFromVec.begin());
-    EXPECT_EQ(&*vec.rbegin(), &*rangeFromVec.rbegin());
-}
-
 TEST(ArrayRef, WhenFromAnyIsCalledThenPointerIsReinterpretedAndSizeIsAdjusted) {
     uint32_t x[2] = {};
     auto arrayRefU8 = ArrayRef<const uint8_t>::fromAny(x, 2);
