@@ -9,7 +9,6 @@
 #include "shared/source/os_interface/product_helper.h"
 #include "shared/source/xe2_hpg_core/hw_cmds_lnl.h"
 #include "shared/source/xe2_hpg_core/hw_info_lnl.h"
-#include "shared/test/common/helpers/debug_manager_state_restore.h"
 #include "shared/test/common/helpers/default_hw_info.h"
 #include "shared/test/common/helpers/gfx_core_helper_tests.h"
 #include "shared/test/common/mocks/mock_device.h"
@@ -28,13 +27,3 @@ LNLTEST_F(GfxCoreHelperTestsLnl, givenCommandBufferAllocationTypeWhenGetAllocati
 
     EXPECT_TRUE(allocData.flags.useSystemMemory);
 }
-
-LNLTEST_F(GfxCoreHelperTestsLnl, givenGetDeviceTimestampWidthCalledThenReturnCorrectValue) {
-    DebugManagerStateRestore restore;
-
-    auto &helper = this->pDevice->getGfxCoreHelper();
-    EXPECT_EQ(64u, helper.getDeviceTimestampWidth());
-
-    debugManager.flags.OverrideTimestampWidth.set(36);
-    EXPECT_EQ(36u, helper.getDeviceTimestampWidth());
-}
\ No newline at end of file
